/*
	Balance Stats on Staff
	
	Summary: Generates 2 variables that are used in balance checks --
				1) NumStaff = number of staff in the circles. Inspectors, constables, clerks all get equal weight here
				2) PosFilled = 1 if circle has inspector & constable & clerk, and 0 if any one of those positions are missing
				
			This is in terms of HR at the time of randomization (baseline).
			
			The globals used here are defined in Master Pakistan Tax Analysis.do.
*/


version 12
clear all
pr drop _all
cap log close
set more off
set mem 300m
pause off

cap cd "${PAPER_ANALYSIS}"

*****************************************************************************************************************************

* CODE VARIABLES
insheet using "${DATA}/Raw Data/Current HR Confirmation/110709 Final Director Verified Master Punjab Current HR Data.csv", comma clear

keep circle_id inspector_name1 inspector_name2 constable_name1 constable_name2 constable_name3 clerk_name

foreach v of varlist *name* {
	replace `v' = "" if `v'=="VACANT"
	g has`v' = `v'!=""
	}

egen NumStaff = rowtotal(has*)
g PosFilled = ((inspector_name1!="")|(inspector_name2!=""))&((constable_name1!="")|(constable_name2!=""))&clerk_name!=""

keep circle_id NumStaff PosFilled


* FIX SOME CIRCLE CODES
recode circle_id (302300=302210) (306000=306010) (306100=306011) (306200=306020) (508901=508910) (611100=613101) (611800=613102) (611300=611301) (611400=611302)(611700=613103)

saveold "Coded Data/Staff Stats.dta", replace
