******** Re-randomize everything to do the randomization inference

clear all
pr drop _all
cap log close
set more off
set mem 600m
*set maxvar 32767
pause on
set seed 9015

set trace off

cap cd "${PAPER_ANALYSIS}"

*************************

/*
if "$iter" == "" {
	display "Enter the number of iterations (presumably 1000): " _request(iter)
	}
*/
local iter = $iter	

timer clear
timer on 1
*** Prepare the base (circle_id and original randomization)
u "Coded Data/Phase III Analysis Data.dta", clear
isid circle_id fyear qtr
sort circle_id fyear qtr

keep if fyear == 2013 & qtr==1
keep circle_id _select_c1 _select_c2  infotreat2 _select_s subtreatment1 subtreatment2 _impl_c _impl_c1 _impl_c2 _impl_s
ren subtreatment1 subtreat
ren subtreatment2 subtreatment_p3
ren infotreat2 infotreat
foreach v of var _select_c1 _select_c2 infotreat _select_s subtreat subtreatment_p3 _impl_c _impl_c1 _impl_c2 _impl_s {
	ren `v' `v'_0
}
tempfile base tempuse
qui sa `base', replace

keep circle_id _select_s_0
tempfile orig
sa `orig', replace // will use later in implementation


****************************
* Phase II Randomization
****************************

u `base', clear
local i = 1
while `i' <= `iter' {
	dis "Phase II - Starting loop number `i'"
	local fail = 0
	
	*** First Stage (for first 150)

	quietly {

	local numtoselect = 150

	***** Copied from...
	* First round randomization
	* June 30, 2011
	* Jon Hill
	* This is version 2.1 -- no pure controls
	*****

	*********
	* Randomization protocol is as follows
	* We stratify by division * quartiles of net demand in 2010, which is what is used for the bins for the revenue treatment
	**********
	 
		u "${PAKTAX_RANDOMIZATION}/Phase II/Randomization/110708 Punjab for Randomization FINAL.dta", clear
		
		compress division_name circle_name inspector_name? constable_name? clerk_name
		sort division_name circle_name
		/*
		noisily display "List of all circles to be included in ballot:"
		noisily list division_name circle_name inspector_name? constable_name? clerk_name, str(25)
		
		local correct = 0
		while `correct' == 0 {
			noisily display as text "Is the list of all circles and postings to be included in ballot correct? (Y/N): " _request(CORRECT)
			if "$CORRECT" == "Y" {
				local ++correct
			}
			else if "$CORRECT" == "N" {
				noisily display as error "Please note any corrections, then re-run the program."
				error 1
				stop
			}
			else {
			noisily display as error "Incorrect response. Try again."
			}
		}
		*/

		* Generate bins based on 2011 net demand
		xtile demandbin = lagdemand,n(4)
		g rewardrate = 4 if demandbin == 1 | demandbin == 2
		replace rewardrate = 3 if demandbin == 3 | demandbin == .
		replace rewardrate = 2 if demandbin == 4

		pctile pdemandbin = lagdemand,n(4)
		list pdemandbin in 1/3
		summ lagdemand,d

		count
		local obs = r(N)
		local percenttoselect =`numtoselect' / `obs'

		display `percenttoselect'
		*set seed 99000
		
		sort division_id demandbin circle_id

		* If a stratum by division_id and rewardratre has <= 9 circles in it
		* We combine them within divisions

		* If a stratum by division_id and rewardratre has fewer than 4 circles in it, we combine it with the next nearest reward rate in its divsion
		sort division_id rewardrate
		by division_id rewardrate: g numingroup = _N
		g rewardrateforstratum = rewardrate
		tab numingroup
		
		replace rewardrateforstratum = 3 if numingroup <= 9 & rewardrateforstratum == 2

		sort division_id rewardrateforstratum
		by division_id rewardrateforstratum: replace numingroup = _N
		tab numingroup
		
		replace rewardrateforstratum = 4 if numingroup <= 9 & rewardrateforstratum == 3

		sort division_id rewardrateforstratum
		by division_id rewardrateforstratum: replace numingroup = _N
		tab numingroup
		
		replace rewardrateforstratum = 3 if numingroup <= 9 & rewardrateforstratum == 4
		
		sort division_id rewardrateforstratum
		by division_id rewardrateforstratum: replace numingroup = _N
		tab numingroup
		assert numingroup > 9

		egen stratum = group(division_id rewardrateforstratum) 
		sort stratum circle_id

		tab stratum
		
		isid stratum circle_id
		sort stratum circle_id

		g rand1 = runiform()
		bys stratum (rand1): gen rank1 = _n
		by stratum: egen count1 = count(rand1) 

		g double numtoselect1 = count1*`percenttoselect'
		* round probabilstically
		sort stratum circle_id
		g rand2 = runiform()
		g double probleft2 = mod(numtoselect1,1)
		 
		g treatment = 1 if rank1 <= floor(numtoselect1) & rank1 != . & numtoselect1 != .
		replace treatment = 0 if rank1 > floor(numtoselect1) & rank1 != . & numtoselect1 != .

		**** Now, do the rounding errors
		g double probleft3 = probleft2 if rank1 == count1

		sort stratum circle_id

		g rand3 = uniform()
		sort rand3
		g obsnum = _n
		foreach X of num 1/`obs' {
				quietly  {
					replace treatment = 1 if probleft3 >= rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					
					g tempchangemade = 1 if probleft3 >= rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					replace tempchangemade = 0 if probleft3 < rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					egen tempchangemade2 = max(tempchangemade)
											
					**Now, adjust remaining probabilities
					egen tempoldtoallocate = total(probleft3)
					replace probleft3 = 0 if probleft3 != . & rank1 == count1 & _n == `X'
					egen tempnewtoallocate = total(probleft3)
					
					replace probleft3 = probleft3 * (tempoldtoallocate - 1) / tempnewtoallocate if tempchangemade2 == 1 
					replace probleft3 = probleft3 * (tempoldtoallocate) / tempnewtoallocate if tempchangemade2 == 0
					drop temp*
				}
		}
	} 
	qui count if treatment == 1
	if r(N)!=150 local fail = 1

	sort division_name circle_name
	qui sa `tempuse', replace

	*** First Stage II (10 more treatments)

	if `fail' == 0 {
	quietly {

	local numtoselect = 10


	***** 
	* First round randomization
	* To select additional circles
	*****

	*********
	* Randomization protocol is as follows
	* We stratify by division * quartiles of net demand in 2010, which is what isused for the bins for the revenue treatment
	* We use the input ballot file from the first round
	**********
	 
		u `tempuse', clear
		
		* Save treatments from first ballot for use later
		preserve
		keep if treatment == 1
		tempfile temptreats
		save `temptreats', replace
		restore
		
		* Drop those circles selected in stage 1
		drop if treatment == 1
		drop treatment
		drop rand* rank* count* numto* prob* obs*
		
		sort division_name circle_name
		
		count
		local obs = r(N)
		local percenttoselect =`numtoselect' / `obs'

		display `percenttoselect'
		*set seed 999

		sort division_id demandbin circle_id

		tab stratum
		
		isid stratum circle_id
		sort stratum circle_id

		g rand1 = runiform()
		by stratum: egen rank1 = rank(rand1), unique
		by stratum: egen count1 = count(rand1) 

		g double numtoselect1 = count1*`percenttoselect'
		* round probabilstically
		sort stratum circle_id
		g rand2 = runiform()
		g double probleft2 = mod(numtoselect1,1)
		 
		g treatment = 1 if rank1 <= floor(numtoselect1) & rank1 != . & numtoselect1 != .
		replace treatment = 0 if rank1 > floor(numtoselect1) & rank1 != . & numtoselect1 != .

		**** Now, do the rounding errors
		g double probleft3 = probleft2 if rank1 == count1
		
		*** Go through them in order from highest probability to lowest probability
		gsort -probleft3 + circle_id
		
		g obsnum = _n
		foreach X of num 1/`obs' {
				quietly  {
					replace treatment = 1 if probleft3 >= rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					
					g tempchangemade = 1 if probleft3 >= rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					replace tempchangemade = 0 if probleft3 < rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					egen tempchangemade2 = max(tempchangemade)
											
					**Now, adjust remaining probabilities
					egen tempoldtoallocate = total(probleft3)
					replace probleft3 = 0 if probleft3 != . & rank1 == count1 & _n == `X'
					egen tempnewtoallocate = total(probleft3)
					
					replace probleft3 = probleft3 * (tempoldtoallocate - 1) / tempnewtoallocate if tempchangemade2 == 1 
					replace probleft3 = probleft3 * (tempoldtoallocate) / tempnewtoallocate if tempchangemade2 == 0
					
					
					drop temp*
				}
		}
	} 
	g treatment_newballot = treatment
	append using `temptreats'

	qui count if treatment == 1
	if r(N)!=160 local fail = 1
	sort division_name circle_name
	sa `tempuse', replace
	}

	*** Subtreatments
	
	if `fail' == 0 {
	quietly {
		
		use `tempuse', clear
		keep if treatment == 1
		sort circle_id // should be erased after test
		gen id = _n

		****
		*** Merge in the consent information
		****
		preserve
		clear
		set obs 160
		gen circle_in = 1
		replace circle_in = 0 in 1/8 // 8 non-consenting circles
		gen rank = runiform()	//shuffle the consenting circles
		sort rank
		keep circle_in
		gen id = _n
		sort id
		tempfile temp1
		save `temp1', replace
		

		restore
		sort id
		merge 1:1 id using `temp1'
		tab _merge
		keep if _merge == 3
		drop _merge
		
		g consentingcircle = 1 if circle_in == 1
		
		* Randomize 3 treatments 
		*set seed 7861 //quoted out
		
		* random order within strata
		sort stratum circle_id
		g rand10 = uniform()
		sort stratum circle_id
		by stratum: egen rank10 = rank(rand10) if consentingcircle == 1 , unique
			
		* random order of strata
		sort stratum circle_id
		by stratum: g rand11 = uniform() if _n == 1
		egen temprank11 = rank(rand11) 
		by stratum: egen rank11 = mean(temprank11)
		
		* random starting value
		sort stratum circle_id
		g temprand12 = floor(3*runiform()) if _n == 1
		egen rand12 = mean(temprand12)
		
		* random order, by stratum
		g randomorder = rank11*100 + rank10
		egen rankrandomorder = rank(randomorder) if consentingcircle == 1
		replace rankrandomorder= rankrandomorder+ rand12 if consentingcircle == 1
		
		g subtreatment = mod(rankrandomorder,3) + 1 if consentingcircle == 1 
		tab subtreatment
		

		label define subtreat 1 "Revenue" 2 "Revenue PLUS" 3 "Cond. Fixed Wage"
		label values subtreatment subtreat
		assert !mi(subtreatment) if circle_in == 1
		sort division_name subtreatment circle_name  
		sort circle_id
	}
	}
	
	if `fail'==0 {
		*keep circle_id treatment subtreatment
		ren treatment _select_c1_`i'
		ren subtreatment subtreat_`i'
		sort circle_id
		qui sa `tempuse', replace
		u `base', clear
		qui merge m:1 circle_id using `tempuse'
		drop _merge
		replace _select_c1_`i' = 0 if mi(_select_c1_`i')
		replace subtreat_`i' = 0 if mi(subtreat_`i')
		qui sa `base', replace
	}
	if `fail'==0 local ++i
}

****************************
* Phase III Randomization
****************************

forvalues i = 1/`iter' {

	dis "Phase III(c) - Starting loop number `i'"
	
	quietly {

	local numtoselect = 60
	local numtoselect_info = 70

	clear
		
		* Bring treatment data
		u `base', clear
		keep circle_id _select_c1_`i'
		ren _select_c1_`i' treatment
		sort circle_id
		save `tempuse', replace
		
		use "${PAKTAX_RANDOMIZATION}/Phase III/130503 Additional Needed Documents/Crosswalk between Phase II and Phase III.dta",clear 
		cap drop rand* rank* count* numto* problef* obsnum
		drop treatment*
		sort circle_id
		merge 1:1 circle_id using `tempuse'
		drop if _merge != 3
		drop _merge
		
		drop if treatment == 1 /*drop those originally selected*/
		
		*** Basic plan
		*** Restrict to the circles that have not already been included
		*** Use same strata to pick 60 new circles. Then use the old randomization code to randomize them into treatments
		*** Then take the leftovers and randomly pick XXX consenting circles
		
		* Select circles for treatment using old code
		* Randomize in subtreatments using old code
		* Then do the inspector
		
		compress division_name circle_name inspector_name? constable_name? clerk_name
		sort division_name circle_name

		count
		local obs = r(N)
		local percenttoselect =`numtoselect' / `obs'
		
		tab stratum
		
		sort stratum circle_id

		g rand1 = runiform()
		by stratum: egen rank1 = rank(rand1), unique
		by stratum: egen count1 = count(rand1) 

		g double numtoselect1 = count1*`percenttoselect'
		* round probabilstically
		sort stratum circle_id
		g rand2 = runiform()
		g double probleft2 = mod(numtoselect1,1)
		 
		g treatment_p3 = 1 if rank1 <= floor(numtoselect1) & rank1 != . & numtoselect1 != .
		replace treatment_p3 = 0 if rank1 > floor(numtoselect1) & rank1 != . & numtoselect1 != .

		**** Now, do the rounding errors
		g double probleft3 = probleft2 if rank1 == count1

		g rand3 = uniform()
		sort rand3
		g obsnum = _n
		foreach X of num 1/`obs' {
				quietly  {
					replace treatment_p3 = 1 if probleft3 >= rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					
					g tempchangemade = 1 if probleft3 >= rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					replace tempchangemade = 0 if probleft3 < rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					egen tempchangemade2 = max(tempchangemade)
											
					**Now, adjust remaining probabilities
					egen tempoldtoallocate = total(probleft3)
					replace probleft3 = 0 if probleft3 != . & rank1 == count1 & _n == `X'
					egen tempnewtoallocate = total(probleft3)
					
					replace probleft3 = probleft3 * (tempoldtoallocate - 1) / tempnewtoallocate if tempchangemade2 == 1 
					replace probleft3 = probleft3 * (tempoldtoallocate) / tempnewtoallocate if tempchangemade2 == 0
					
					drop temp*
				}
		}

		***
		* In very rare circumstances, we'll be missing one due to the above algorithm assigning 2 to the last place
		* In such a case, I'm just going to randomly pick one more of controls
		*** 
		egen temptotalpicked = total(treatment_p3)
		summ temptotalpicked 
		local temptotalpicked = r(mean)
		if `temptotalpicked' < `numtoselect' {
			* too few due to round errors
			* randomly add a few to fix this
			local numaddl = `numtoselect' - `temptotalpicked'
			g rand8 = uniform() if treatment_p3 == 0
			egen rankrand8 = rank(rand8)
			replace treatment_p3 = 1 if rankrand8 <= `numaddl'
			drop rand8		
		}
		
		****
		*
		* Next, we need to count the actual number selected, and deselect a few to get to exactly numtoselect 
		* Dealing with splits and merges
		* 
		****
		** Count selected circles
		g tempcount = treatment_p3
		
		* If there are multiple treatment circles that merged with other treatment circles, count them as one
		bys q3_2012_circle_id: egen tempcountcirclelevel = total(tempcount)
		replace tempcount = tempcount / tempcountcirclelevel if tempcountcirclelevel >= 1 & tempcountcirclelevel != . & merge == 1
			
		* Count splits as 2
		replace tempcount = 2 if split == 1 & treatment_p3 == 1
			
		egen temptotalselected = total(tempcount)
		summ temptotalselected
		local totalselected = r(mean)
		local numtodeselect = `totalselected' - `numtoselect'
		
		** randomly order
		** do running sum
		** randomly order by 2012 circles so merged ones get treated the same
		** deselect
		bys q3_2012_circle_id: g temprand7 = uniform() if _n == 1
		bys q3_2012_circle_id: egen rand7 = mean(temprand7)
		sort rand7
		g temprunningsum = sum(tempcount)
		g flag = 1 if temprunningsum <= `numtodeselect' & treatment_p3 == 1
		replace treatment_p3 = 0 if flag == 1
		replace tempcount = 0 if flag == 1
			
		**
		* It is possible we'll have one more to deselect, in which case we need to deselect a non-split circle
		* Check with Asim
		**
		* recheck total
		drop temptotalselected  flag temprunningsum
		egen temptotalselected = total(tempcount)
		summ temptotalselected
		local totalselected = r(mean)
		local numtodeselect = `totalselected' - `numtoselect'
		if `numtodeselect' == 1 {
			bys q3_2012_circle_id: g temprand8 = uniform() if _n == 1 & split != 1
			bys q3_2012_circle_id: egen rand8 = mean(temprand8)
			g temprunningsum = sum(tempcount)
			g flag = 1 if temprunningsum <= `numtodeselect' & treatment_p3 == 1
			replace treatment_p3 = 0 if flag == 1
			replace tempcount = 0 if flag == 1
			
		}
		
		**XXXXadded 7/7
		* It is possible that we will have to add one, if, for example, we selected only merged circles and no splits
		* do that
		* recheck total
		cap drop temptotalselected 
		cap drop flag 
		cap drop temprunningsum
		egen temptotalselected = total(tempcount)
		summ temptotalselected
		local totalselected = r(mean)
		local numtodeselect = `totalselected' - `numtoselect'
		if `numtodeselect' < 0 {
			local numaddltoselect =   `numtoselect' - `totalselected'

			bys q3_2012_circle_id: g temprand9 = uniform() if _n == 1 & split != 1
			bys q3_2012_circle_id: egen rand89 = mean(temprand9)
			g tempcountcontrols = 1  & treatment_p3 == 0
			replace tempcountcontrols = 2 if split == 1 & treatment_p3 == 0
			replace tempcountcontrols = tempcountcontrols / tempcountcirclelevel if tempcountcirclelevel >= 1 & tempcountcirclelevel != . & merge == 1
			g temprunningsum = sum(tempcountcontrols) if split != 1
			g flag = 1 if temprunningsum <= `numaddltoselect' & treatment_p3 == 0 & temprunningsum != .
			
			replace treatment_p3 = 1 if flag == 1	
		}
		
		****subtreatments
		
		* random order within strata, but splits first
		sort stratum circle_id
		g rand10 = uniform()
		replace rand10 = rand10 - 1 if split == 1 /*so splits go first*/
		sort stratum circle_id
		by stratum: egen rank10 = rank(rand10) if treatment_p3 == 1 , unique
				
		* random order of strata
		sort stratum circle_id
		by stratum: g rand11 = uniform() if _n == 1
		egen temprank11 = rank(rand11) 
		by stratum: egen rank11 = mean(temprank11)

		* random starting value
		g temprand12 = floor(3*runiform()) if _n == 1
		egen rand12 = mean(temprand12)

		* random order, by stratum
		g randomorder = rank11*100 + rank10
		egen rankrandomorder = rank(randomorder) if treatment_p3 == 1
		replace rankrandomorder= rankrandomorder+ rand12 if treatment_p3== 1

		
		****if two are merged they need the same value in the random rank order
		egen q3_num = group(q3_2012_circle_id) if merge == 1
		summ q3_num
		local numcirc = r(max)
		foreach X of num 1/`numcirc' {
			summ rankrandomorder if q3_num == `X' & treatment_p3 == 1
			local max = r(max)
			local min = r(min)
			if `max' != `min' {
				assert merge == 1 if q3_num == `X' & treatment_p3 == 1
				replace rankrandomorder= `min' if q3_num == `X'
				replace rankrandomorder = rankrandomorder- 1 if rankrandomorder > `max' & rankrandomorder!= .
				
			}
		}
		
		
		* for splits, we replace the randomrankorder of the next one that would have gotten it
		* of the same treatment by 1 to account for the fact that splits count twice!!
		* that is if it is 1 2 3 4 5 6 so treatments would be 1 2 3 1 2 3, and the first 3 is a split, so ounts twice, we want
		* 1 2 3 4 5 7 so treatments will be 1 2 3 1 2 1
		count
		local numcircles = r(N)
		sort rankrandomorder
		foreach X of num 1/`numcircles' {
			replace rankrandomorder = rankrandomorder + 1 if split[`X'] == 1 & treatment_p3[`X'] == 1 & rankrandomorder  >= rankrandomorder[`X'] + 3
		
		}
		
		
		g subtreatment_p3 = mod(rankrandomorder,3) + 1 if treatment_p3 == 1 
		tab subtreatment_p3 if treatment_p3 == 1
		
		
		
		sort division_name circle_name
		tempfile tempfile1
		save `tempfile1', replace
		
		
		
		****
		* Finally, do the first randomization again on non-chosen circles to choose monitoring treatment
		****
		cap drop rand* rank* count* numto* problef* obsnum
		
			
		* keep those not already selected
		* generate a version that deals with merges
		bys q3_2012_circle_id: egen treatinclmerge = max(treatment_p3)
		
		drop if treatment_p3 == 1 | (treatinclmerge == 1 & merge == 1)
		*** Basic plan
		*** Restrict to the circles that have not already been included
		*** Use same strata to pick 60 new circles. Then use the old randomization code to randomize them into treatments
		*** Then take the leftovers and randomly pick XXX consenting circles
		
		* Select circles for treatment using old code
		* Randomize in subtreatments using old code
		* Then do the inspector
		
		compress division_name circle_name inspector_name? constable_name? clerk_name
		sort division_name circle_name
		
		count
		local obs = r(N)
		local percenttoselect =`numtoselect_info' / `obs'

		
		tab stratum
		
		sort stratum circle_id

		g rand1 = runiform()
		by stratum: egen rank1 = rank(rand1), unique
		by stratum: egen count1 = count(rand1) 

		g double numtoselect1 = count1*`percenttoselect'
		* round probabilstically
		sort stratum circle_id
		g rand2 = runiform()
		g double probleft2 = mod(numtoselect1,1)
		 
		g treatment_p3_info = 1 if rank1 <= floor(numtoselect1) & rank1 != . & numtoselect1 != .
		replace treatment_p3_info = 0 if rank1 > floor(numtoselect1) & rank1 != . & numtoselect1 != .

		**** Now, do the rounding errors
		g double probleft3 = probleft2 if rank1 == count1

		g rand3 = uniform()
		sort rand3
		g obsnum = _n
		foreach X of num 1/`obs' {
				quietly  {
					replace treatment_p3_info = 1 if probleft3 >= rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					
					g tempchangemade = 1 if probleft3 >= rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					replace tempchangemade = 0 if probleft3 < rand2 & probleft3 != . & rank1 == count1 & obsnum == `X'
					egen tempchangemade2 = max(tempchangemade)
											
					**Now, adjust remaining probabilities
					egen tempoldtoallocate = total(probleft3)
					replace probleft3 = 0 if probleft3 != . & rank1 == count1 & _n == `X'
					egen tempnewtoallocate = total(probleft3)
					
					replace probleft3 = probleft3 * (tempoldtoallocate - 1) / tempnewtoallocate if tempchangemade2 == 1 
					replace probleft3 = probleft3 * (tempoldtoallocate) / tempnewtoallocate if tempchangemade2 == 0
					drop temp*
				}
		}
		sort division_name circle_name
		tempfile tempfile2
		save `tempfile2', replace
		
		*** 
		* *Merge up final results
		****
		
		
		preserve
		use `tempfile2', clear
		keep circle_id treatment_p3_info
		ren treatment_p3_info infotreat_`i'
		tempfile temp1
		sort circle_id 
		save `temp1'
		restore
		
		preserve
		use `tempfile1', clear
		keep circle_id treatment_p3 subtreatment_p3
		label define subtreatment_p3 1 "Revenue" 2 "Revenue PLUS" 3 "Cond. Fixed Wage"
		label values subtreatment_p3 subtreatment_p3 
		ren treatment_p3 _select_c2_`i'
		ren subtreatment_p3 subtreatment_p3_`i'
		tempfile temp2
		sort circle_id 
		save `temp2'
		restore

		u `base', clear
		sort circle_id 
		merge 1:1 circle_id using `temp1'
		tab _merge
		assert _merge != 2
		drop _merge
		
		sort circle_id 
		merge 1:1 circle_id using `temp2'
		tab _merge
		assert _merge != 2
		drop _merge
		
		replace _select_c2_`i' = 0 if _select_c2_`i' == .
		replace infotreat_`i' = 0 if infotreat_`i' == .
		replace subtreatment_p3_`i' = 0 if subtreatment_p3_`i' == .
		
		sort circle_id
		save `base', replace
	} 
}

****************************
* Supervisor randomization
****************************

forvalues i = 1/`iter' {

	dis "Phase III(s) - Starting loop number `i'"
	
	qui {
	****
	* Do the prediction regressions
	****
	*****Crosswalk*****
	insheet using "${DATA}/Raw Data/Administrative Data/Crosswalk to Randomization_ETO ballot.csv", clear
	drop if rand_circle_id==.
	keep rand_circle_id q3_2012_circle_id
	duplicates drop rand_circle_id q3_2012_circle_id, force
	tempfile crosswalk
	sa `crosswalk', replace


	*****AETO list as of July 5th, 2012*****
	insheet using "${DATA}/Raw Data/Current HR Confirmation/120711 Randomization HR corrected.csv", clear
	keep circle_id aeto_name eto_name
	drop if circle_id ==407500 | circle_id==407600    /*don't adjust this in ETO ballot*/
	tempfile aeto_eto
	sa `aeto_eto', replace

	*****Merge with current circle data*****
	use  "${DATA}/Cleaned Data/Administrative Data/Punjab Crosswalked - Current Circles.dta", clear
	drop aeto* eto* 
	merge m:1 circle_id using `aeto_eto'
	*assert _merge!=2 // DJ
							 
	*have 403901 in master data, need to adjust so that 403902 is one circe all along; only need to adjust net demand and recovery total for now!*
	preserve
		keep if circle_id==403901 | circle_id==403902
		foreach var in net_dem_c net_dem_t net_dem_a recov_tot_c recov_tot_a recov_tot_t {
		
			rename `var' temp
			bys fyear qtr: egen `var'=sum(temp)
			drop temp
		
		}
		drop if circle_id==403901    /*we only had one circe in ALI PUR CHATHA!*/
		
		tempfile 4039
		sa `4039', replace
	restore

	drop if circle_id==403901 | circle_id==403902
	drop _merge
	append using `4039'
	sort circle_id fyear qtr

	gen ln_recov_tot_c = ln(recov_tot_c)
	gen ln_recov_tot_t = ln(recov_tot_t)

	*clean for division_id, if missing*
	replace division_id = floor(circle_id/100000) if division_id==.
	*clean for AETO and ETO name
	replace aeto_name = upper(aeto_name)
	replace eto_name = upper(eto_name)
	replace aeto_name = rtrim(aeto_name)
	replace eto_name = rtrim(eto_name)
	replace aeto_name = ltrim(aeto_name)
	replace eto_name = ltrim(eto_name)
	*assert we don't have any additional charge displayed in names*
	foreach var in eto_name aeto_name {
		assert strpos(`var', "ADDL")==0
	}
	*crosswalk aeto and eto names to randomization circles*
	keep division_id circle_id aeto_name eto_name
	duplicates drop circle_id, force
	rename circle_id q3_2012_circle_id
	merge 1:m q3_2012_circle_id using `crosswalk'
	keep if _merge==3
	drop _merge

	rename rand_circle_id circle_id
	duplicates drop circle_id, force
	merge 1:m circle_id using "${DATA}/Cleaned Data/Administrative Data/Punjab Crosswalked - Randomization Circles.dta"
	assert _merge==3
	drop _merge

	gen ln_recov_tot_c = ln(recov_tot_c)
	gen ln_recov_tot_t = ln(recov_tot_t)

	*clean for division_id, if missing*
	replace division_id = floor(circle_id/100000) if division_id==.

	tempfile merged
	sa `merged', replace

	*eto*
	u `merged', clear
	drop if eto_name==""
	drop if eto_name=="UNKNOWN"
	drop if eto_name=="VACANT"

	cap drop fyearqtr
	egen fyear_qtr = group(fyear qtr)
	tsset circle_id fyear_qtr

	tempfile b
	sa `b', replace

	gen delta_ln_recov_c = ln_recov_tot_c - L4.ln_recov_tot_c
	gen delta_ln_recov_t = ln_recov_tot_t - L4.ln_recov_tot_t
	gen ln_net_dem_c = ln(net_dem_c)
	gen ln_net_dem_t = ln(net_dem_t)
	gen delta_ln_dem_c = ln_net_dem_c  - L4.ln_net_dem_c 
	gen delta_ln_dem_t = ln_net_dem_t  - L4.ln_net_dem_t

	for any ln_recov_tot_c  delta_ln_recov_c ln_recov_tot_t delta_ln_recov_t ln_net_dem_c ln_net_dem_t : g L4X = L4.X \ g L8X = L8.X 

	xi i.division_id


	reg delta_ln_recov_c L4ln_recov_tot_c  L4delta_ln_recov_c L8delta_ln_recov_c L4ln_recov_tot_t  L4delta_ln_recov_t L8delta_ln_recov_t L4ln_net_dem_c L4ln_net_dem_c _I* if fyear==2011 & qtr == 3, robust

	predict predicted_change_c

	reg delta_ln_recov_t L4ln_recov_tot_c  L4delta_ln_recov_c L8delta_ln_recov_c L4ln_recov_tot_t  L4delta_ln_recov_t L8delta_ln_recov_t L4ln_net_dem_c L4ln_net_dem_c _I* if fyear==2011 & qtr == 3, robust

	predict predicted_change_t

	drop if predicted_change_t == .

	keep if fyear == 2012
	collapse (mean) predicted_change_?, by(eto_name)

	sort eto_name
	tempfile b1
	sa `b1', replace



	*****AETO/ETO list as of July 5th, 2012*****
	clear
	insheet using "${DATA}/Raw Data/Current HR Confirmation/120711 Randomization HR corrected.csv", clear
	keep circle_id aeto* eto* division*
	drop if circle_id ==407500 | circle_id==407600    /*don't adjust this in ETO ballot*/

	** Clean ETO names
	*clean for AETO and ETO name
	replace aeto_name = upper(aeto_name)
	replace eto_name = upper(eto_name)
	replace aeto_name = rtrim(aeto_name)
	replace eto_name = rtrim(eto_name)
	replace aeto_name = ltrim(aeto_name)
	replace eto_name = ltrim(eto_name)
	replace eto_name = "" if eto_name == "UNKNOWN" | eto_name=="VACANT"
	replace aeto_name = "" if aeto_name == "UNKNOWN" | aeto_name=="VACANT"

	*****

	preserve
	tab eto_name if eto_name != "" & eto_name != "UNKNOWN"
	local numeto = r(N)
	bys eto_name: keep if _n == 1
	keep division* eto_name

	** merge in predicted change
	sort eto_name
	merge 1:1 eto_name using `b1'
	assert _merge == 3 if eto_name != "UNKNOWN" & eto_name != ""
	drop _merge

	** generate strata
	** division by randgroup
	bys division_id: egen rankpredict = rank(predicted_change_t)

	*exit
	bys division_id: egen maxrankpredict = max(rankpredict )
	replace rankpredict = rankpredict - 1 if mod(maxrankpredict,2) == 1 & rankpredict == maxrankpredict

	replace rankpredict = rankpredict + 1 if mod(rankpredict ,2)==1
	** If there is an odd number, lump it together with previous one
	egen stratumeto = group(division_id rankpredict)


	** randomly sort within strata
	sort division_id stratumeto eto_name
	g rand10 = uniform()
	sort division_id stratumeto eto_name
	by division_id stratumeto : egen rank10 = rank(rand10) if eto_name != "" & eto_name != "UNKNOWN"
			
	* random order of strata within divisions
	sort division_id stratumeto
	by division_id stratumeto: g rand11 = uniform() if _n == 1
	by division_id: egen temprank11 = rank(rand11) 
	by division_id stratumeto: egen rank11 = mean(temprank11)

	* random order of divisions
	sort division_id eto_name
	by division_id: g rand12 = uniform() if _n == 1
	egen temprank12 = rank(rand12) 
	by division_id: egen rank12 = mean(temprank12)


	* random starting value
	g temprand13 = floor(2*runiform()) if _n == 1
	egen rand13 = mean(temprand13)

	g randomorder = rank12 * 1000 + rank11*100 + rank10
	egen rankrandomorder = rank(randomorder) 
	replace rankrandomorder= rankrandomorder+ rand13

	g treat_eto = mod(rankrandomorder,2)

	keep division_id division_name eto_name treat_eto stratumeto
	sort division_id eto_name treat_eto 
	tempfile temp1
	save `temp1'

	restore

	sort division_id eto_name 
	merge m:1 division_id eto_name using `temp1'
	assert _merge == 3 if eto_name != ""
	drop _merge

	************************************
	*** Conversion to the circle data***
	************************************

	keep  division*  eto_name  treat_eto
	collapse (mean) treat_eto, by(eto_name)
	assert treat_eto==1 | treat_eto==0 if eto_name!=""

	***merge with the new list***
	merge 1:m eto_name using "${DATA}/Raw Data/For Rerandomization/new_list.dta"
	assert _merge==3
	drop _merge

	rename circle_id q3_2012_circle_id
	merge 1:m q3_2012_circle_id using "${DATA}/Raw Data/For Rerandomization/crosswalk.dta"
	assert _merge!=2                  /*the crosswalk contains new circles formed after Phase II randomization*/
	keep if _merge==3
	drop _merge

	***assert that each randomization circle has only one unique ETO***
	bys rand_circle_id: gen temp1=_N
	bys rand_circle_id: gen temp2=_n
	drop q3_2012*
	preserve
		keep if temp1!=1
		assert temp1==2  /*2 is max*/
		drop aeto_name
		reshape wide eto_name, i(rand_circle_id) j(temp2)
		assert eto_name1==eto_name2
	restore	

	***deal with the cases where each randomization circle has two AETOs***
	preserve
		keep if temp1!=1
		assert temp1==2  /*2 is max*/	
		reshape wide aeto_name, i(rand_circle_id) j(temp2)
		tempfile aeto_dup
		sa `aeto_dup', replace
	restore

	drop if temp1!=1
	rename aeto_name aeto_name1
	append using `aeto_dup'
	drop temp*
	replace aeto_name2="" if aeto_name1==aeto_name2    /*if they're the same, then don't need to keep both*/
	
	keep rand_circle_id treat_eto
	ren rand_circle_id circle_id
	ren treat_eto _select_s_`i'
	sort circle_id
	sa `tempuse', replace
	u `base', clear
	sort circle_id
	merge 1:1 circle_id using `tempuse'
	assert _merge == 3
	drop _merge
	sort circle_id
	sa `base', replace
	}
}


****************************
* Implementation
****************************

// Basic strategy: shuffle implementation time series (not each cross-section)
// shuffle within each group first four groups: (select_c1 = 1 / select_c2 = 1 / info = 1 / nothing) then two groups: (select_s = 1 / select_s = 0)
// Main obstacle is that _select_c2 and _select_s are different for each iteration
// If # of treated circles is bigger than original, will duplicate randomly chosen circles
// If # of treated circles is smaller than original, will drop randomly chosen circles

*** record number of circles in each group in original randomization data - main treatment


qui {
	u `base', clear
	gen group_0 = 0
	replace group_0 = 1 if _select_c1_0 == 1
	replace group_0 = 2 if _select_c2_0 == 1
	replace group_0 = 3 if infotreat_0 == 1
	forvalues k = 0/3 {
		qui count if group_0 == `k'
		local group`k'_0 = r(N) // record number of circles in each group in original randomization data
	}

	forvalues i = 1/`iter' {
		noisily dis "grouping for implmerger loop `i'"

		* Divide group
		gen group = 0
		replace group = 1 if _select_c1_`i' == 1
		replace group = 2 if _select_c2_`i' == 1
		replace group = 3 if infotreat_`i' == 1
		forvalues k = 0/3 {
			qui count if group == `k'
			local group`k' = r(N)
		}
		
		gen implmerger_`i' = 0 //merger that I am going to use to apply implementation data
		forvalues g = 0/3 {
			if `group`g''>`group`g'_0' { // If original has less circles in the group, repeat first few ranks
				gen rand = runiform() if group == `g'
				egen rank = rank(rand) if group == `g', unique
				replace implmerger_`i' = rank if group == `g'
				replace implmerger_`i' = ceil(`group`g'_0'*runiform()) if group == `g' & rank > `group`g'_0'
				drop rand rank
			}
			else if `group`g''<`group`g'_0' { // If original has more circles in the group, randomly drop the appropriate number of ranks
				gen rand = runiform() if group == `g'
				egen rank = rank(rand) if group == `g', unique
				preserve
				clear
				set ob `group`g'_0'
				gen rank2 = _n
				gen rand2 = runiform()
				sort rand2
				keep in 1/`group`g'' //drop randomly chosen overflous observations
				sort rank2
				gen rank = _n
				gen group = `g'
				keep group rank rank2
				sort group rank
				save `tempuse', replace
				restore
				replace rank = 8000 + _n if mi(rank) // without this, we encounter uniqueness problem in the merge below
				sort group rank
				merge 1:1 group rank using `tempuse'
				tab _merge
				replace implmerger_`i' = rank2 if group == `g'
				drop _merge rand rank rank2
			}	
			else {
				gen rand = runiform() if group == `g'
				egen rank = rank(rand) if group == `g', unique
				replace implmerger_`i' = rank if group == `g'
				drop rand rank
			}
		sort circle_id
		}
		drop group
		save `base', replace
	}

	*** record number of circles in each group in original randomization data - supervisory treatment

	gen groups_0 = 0 //groups = group for supervisor
	replace groups_0 = 1 if _select_s_0 == 1
	forvalues k = 0/1 {
		qui count if groups_0 == `k'
		local groups`k'_0 = r(N) // record number of circles in each group in original randomization data
	}

	forvalues i = 1/`iter' {
		noisily dis "grouping for supervisor merger loop `i'"
		* Divide group
		gen groups = 0
		replace groups = 1 if _select_s_`i' == 1
		forvalues k = 0/1 {
			qui count if groups == `k'
			local groups`k' = r(N) // record number of circles in each group in original randomization data
		}
		
		gen supermerger_`i' = 0 //merger that I am going to use to apply implementation data
		forvalues g = 0/1 {
			if `groups`g''>`groups`g'_0' { // If original has less circles in the groups, repeat randomly chosen circles.
				gen rand = runiform() if groups == `g'
				egen rank = rank(rand) if groups == `g', unique
				replace supermerger_`i' = rank if groups == `g'
				replace supermerger_`i' = ceil(`groups`g'_0'*runiform()) if groups == `g' & rank > `groups`g'_0'
				drop rand rank
			}
			else if `groups`g''<`groups`g'_0' { // If original has more circles in the groups, randomly drop the appropriate number of ranks
				gen rand = runiform() if groups == `g'
				egen rank = rank(rand) if groups == `g', unique
				preserve
				clear
				set ob `groups`g'_0'
				gen rank2 = _n
				gen rand2 = runiform()
				sort rand2
				keep in 1/`groups`g'' //drop randomly chosen overflous observations
				sort rank2
				gen rank = _n
				gen groups = `g'
				keep groups rank rank2
				sort groups rank
				save `tempuse', replace
				restore
				replace rank = 8000 + _n if mi(rank) // without this, we encounter uniqueness problem in the merge below
				sort groups rank
				merge 1:1 groups rank using `tempuse'
				tab _merge
				replace supermerger_`i' = rank2 if groups == `g'
				drop _merge rand rank rank2
			}	
			else {
				gen rand = runiform() if groups == `g'
				egen rank = rank(rand) if groups == `g', unique
				replace supermerger_`i' = rank if groups == `g'
				drop rand rank
			}
		sort circle_id
		}
		drop groups
		save `base', replace
	}
}

*** make dataset time series (long type)
u "Coded Data/Phase III Analysis Data.dta", clear
keep circle_id fyear qtr
sort circle_id
merge m:1 circle_id using `base'
drop _merge
save `base', replace

*** Bring implementation data

// prepare implmerger
u "Coded Data/Phase III Analysis Data.dta", clear
keep  fyear qtr circle_id _select_c1 _select_c2 infotreat2 _select_s _impl* INFO_impl
sort fyear qtr circle_id
gen group = 0
replace group = 1 if _select_c1 == 1
replace group = 2 if _select_c2 == 1
replace group = 3 if infotreat2 == 1
merge m:1 circle_id using `orig'
drop _merge
gen groups = 0
replace groups = 1 if _select_s_0 == 1
sort fyear qtr group circle_id
by fyear qtr group: gen implmerger = _n
sort fyear qtr groups circle_id
by fyear qtr groups: gen supermerger = _n
tempfile temp
save `temp', replace

qui{
forvalues i = 1/`iter' {
	if mod(`i',100)==0 noisily dis "implementation merging: loop `i'"
	u `temp', clear
	keep fyear qtr group implmerger _impl_c _impl_c1 _impl_c2 INFO_impl
	foreach v of var implmerger _impl_c _impl_c1 _impl_c2 INFO_impl {
		ren `v' `v'_`i'
	}
	sort fyear qtr group implmerger_`i'
	sa `tempuse', replace
	u `base', clear
	gen group = 0
	replace group = 1 if _select_c1_`i' == 1
	replace group = 2 if _select_c2_`i' == 1
	replace group = 3 if infotreat_`i' == 1
	sort fyear qtr group implmerger_`i'
	merge m:1 fyear qtr group implmerger_`i' using `tempuse'
	drop if _merge == 2
	drop _merge implmerger_`i' group
	sa `base', replace
	u `temp', clear
	keep fyear qtr groups supermerger _impl_s
	ren supermerger supermerger_`i'
	ren _impl_s _impl_s_`i'
	sort fyear qtr groups supermerger_`i'
	sa `tempuse', replace
	u `base', clear
	gen groups = 0
	replace groups = 1 if _select_s_`i' == 1
	sort fyear qtr groups supermerger_`i'
	merge m:1 fyear qtr groups supermerger_`i' using `tempuse'
	drop if _merge == 2
	drop _merge supermerger_`i' groups
	sa `base', replace
}
}

timer off 1
timer list 1

saveold "Coded Data/Rerandomization.dta", replace


** Bring _impl_??_0 to the data (need this for smoother looping in the final section)
u "Coded Data/Phase III Analysis Data.dta", clear
keep fyear qtr circle_id _impl* INFO_impl
foreach v of var _impl* INFO_impl{
	ren `v' `v'_0
}
sort fyear qtr circle_id
tempfile tempuse
sa `tempuse', replace
u "Coded Data/Rerandomization.dta", clear
sort fyear qtr circle_id
merge 1:1 fyear qtr circle_id using `tempuse'
drop _merge
saveold "Coded Data/Rerandomization.dta", replace



****************************
* Final touch
****************************
// Prepare variables so that the data has the same format as "Phase III analysis data.dta"
// There are too many variables to put all the rerandomization at the same file
// will devide into rerand_balance / rerand_balance_SUR / rerand_circle / rerand_subtreat / rerand_supervisor

** for balance analysis
u "Coded Data/Rerandomization.dta", clear
drop *impl*
forvalues i = 0/`iter' {
	gen REV_sel1_`i'=(subtreat_`i'==1)
	gen REVPLS_sel1_`i'=(subtreat_`i'==2)
	gen CFW_sel1_`i'=(subtreat_`i'==3)
	gen REV_sel2_`i'=(subtreatment_p3_`i'==1)
	gen REVPLS_sel2_`i'=(subtreatment_p3_`i'==2)
	gen CFW_sel2_`i'=(subtreatment_p3_`i'==3)
	g _select_c2all_`i' = _select_c1_`i'==1 | _select_c2_`i'==1
	g REV_sel2all_`i' = REV_sel1_`i'==1 | REV_sel2_`i'==1
	g REVPLS_sel2all_`i' = REVPLS_sel1_`i'==1 | REVPLS_sel2_`i'==1
	g CFW_sel2all_`i' = CFW_sel1_`i'==1 | CFW_sel2_`i'==1
	ren infotreat_`i' INFO_sel2_`i'
	g flag = REV_sel1_`i'+REVPLS_sel1_`i'+CFW_sel1_`i'==0 & _select_c1_`i'==1  // In order to take care of non-consenting circles
	foreach a in REV REVPLS CFW {
		replace `a'_sel1_`i' = .333 if flag
		replace `a'_sel2all_`i' = .333 if flag & fyear == 2013
		}
	drop flag
	g flag = REV_sel2_`i'+REVPLS_sel2_`i'+CFW_sel2_`i'==0 & _select_c2_`i'==1
	foreach a in REV REVPLS CFW {
		replace `a'_sel2_`i' = .333 if flag
		replace `a'_sel2all_`i' = .333 if flag & fyear == 2013
		}
	drop flag
	drop REV_sel2_`i' REVPLS_sel2_`i' CFW_sel2_`i'
}
keep if fyear==2012 & qtr==4
gen infosample = (_select_c2_0==0 | INFO_sel2_0==1)
sort circle_id
saveold "Coded Data/rerand_balance.dta", replace

set more off 
** for manual SUR
u "Coded Data/rerand_balance.dta", clear
local N = _N
keep circle_id _select_c1_* REV_sel1_* REVPLS_sel1_* CFW_sel1_*
tempfile tempuse
sa `tempuse', replace
forv r = 1/6 {
append using `tempuse'
}
gen eq = 1
forvalues k = 2/7 {
	local lb = `N'*(`k'-1)+1
	local ub = `N'*`k'
	replace eq = `k' in `lb'/`ub'
}
forvalues i = 0/`iter' {
	foreach v in _select_c1 REV_sel1 REVPLS_sel1 CFW_sel1 {
		forvalues r = 1/7 {
			gen `v'_`r'_`i' = `v'_`i'
			replace `v'_`r'_`i' = 0 if eq != `r'
		}
		drop `v'_`i'
	}
}
saveold "Coded Data/rerand_SUR1.dta", replace
u "Coded Data/rerand_balance.dta", clear
local N = _N
keep circle_id _select_c2all_* REV_sel2all_* REVPLS_sel2all_* CFW_sel2all_*
tempfile tempuse
sa `tempuse', replace
forv r = 1/6 {
append using `tempuse'
}
gen eq = 1
forvalues k = 2/7 {
	local lb = `N'*(`k'-1)+1
	local ub = `N'*`k'
	replace eq = `k' in `lb'/`ub'
}
forvalues i = 0/`iter' {
	foreach v in _select_c2all REV_sel2all REVPLS_sel2all CFW_sel2all {
		forvalues r = 1/7 {
			gen `v'_`r'_`i' = `v'_`i'
			replace `v'_`r'_`i' = 0 if eq != `r'
		}
		drop `v'_`i'
	}
}
saveold "Coded Data/rerand_SUR2.dta", replace
u "Coded Data/rerand_balance.dta", clear
local N = _N
keep circle_id INFO_sel2_* _select_s_* infosample
tempfile tempuse
sa `tempuse', replace
forv r = 1/6 {
append using `tempuse'
}
gen eq = 1
forvalues k = 2/7 {
	local lb = `N'*(`k'-1)+1
	local ub = `N'*`k'
	replace eq = `k' in `lb'/`ub'
}
forvalues i = 0/`iter' {
	foreach v in INFO_sel2 _select_s {
		forvalues r = 1/7 {
			gen `v'_`r'_`i' = `v'_`i'
			replace `v'_`r'_`i' = 0 if eq != `r'
		}
		drop `v'_`i'
	}
}
saveold "Coded Data/rerand_SUR3.dta", replace

** for circle treatment
u "Coded Data/Rerandomization.dta", clear
keep fyear qtr circle_id _select_c?_* _impl_c?_* _impl_c_*
forvalues i = 0/`iter' {
	g _select_c_`i' = _select_c1_`i'
	replace _select_c_`i' = 1 if _select_c2_`i'==1 & fyear==2013
}
sort fyear qtr circle_id
saveold "Coded Data/rerand_circle.dta", replace

** for subtreatment (and also for incentiveinfo)
u "Coded Data/Rerandomization.dta", clear
forvalues i = 0/`iter' {
	g _select_c_`i' = _select_c1_`i'
	replace _select_c_`i' = 1 if _select_c2_`i'==1 & fyear==2013
	forvalues z = 1/3 {
		local a : word `z' of REV REVPLS CFW
		g `a'_impl_`i' = 0
		replace `a'_impl_`i' = _impl_c_`i' if subtreat_`i' == `z'
		replace `a'_impl_`i' = _impl_c_`i' if subtreatment_p3_`i' == `z' & fyear == 2013
		g `a'_sel_`i' = 0
		replace `a'_sel_`i' = _select_c_`i' if subtreat_`i' == `z'
		replace `a'_sel_`i' = _select_c_`i' if subtreatment_p3_`i' == `z'
	}
	g flag = REV_sel_`i'+REVPLS_sel_`i'+CFW_sel_`i'==0 & _select_c_`i'==1
	foreach a in REV REVPLS CFW { // patch for non-consenting circles
		replace `a'_sel_`i' = .333 if flag
	}
	drop flag
	ren infotreat_`i' INFO_sel_`i'
	replace INFO_sel_`i' = 0 if fyear == 2012
	forvalues z = 1/4 {
		local a : word `z' of REV REVPLS CFW INFO
		g `a'_sel1all_`i' = `a'_sel_`i'
		replace `a'_sel1all_`i' = 0 if fyear == 2013
		g `a'_sel2all_`i' = `a'_sel_`i'
		replace `a'_sel2all_`i' = 0 if fyear == 2012
	}
}
drop subtreat*
** For multitasking (table 2c, Revenue_subtreatments)
forvalue i = 0/`iter'{
	gen multitasking_sel_`i' = 0
	replace multitasking_sel_`i' = 1 if REV_sel_`i' == 1
	replace multitasking_sel_`i' = 0 if REVPLS_sel_`i' == 1
	replace multitasking_sel_`i' = -1 if CFW_sel_`i' == 1
	replace multitasking_sel_`i' = 0 if ///
		(REV_sel_`i' == .333 | CFW_sel_`i' == .333 | REVPLS_sel_`i' == .333)
		
	gen multitasking_impl_`i' = 0
	replace multitasking_impl_`i' = 1 + REV_sel_`i' if REV_sel_`i' == 1
	replace multitasking_impl_`i' = 0 + REVPLS_sel_`i' if REVPLS_sel_`i' == 1
	replace multitasking_impl_`i' = -1 + CFW_sel_`i' if CFW_sel_`i' == 1
}
sort circle_id fyear qtr
saveold "Coded Data/rerand_subtreat.dta", replace

** for supervisor
u "Coded Data/rerand_subtreat.dta", clear
drop *all*
forvalues i = 0/`iter' {
	replace _select_s_`i' = 0 if fyear == 2012
	foreach v in REV_sel REVPLS_sel CFW_sel INFO_sel _select_c {
		g sup`v'_`i' = _select_s_`i'*`v'_`i'
	}
	foreach v in REV_impl REVPLS_impl CFW_impl INFO_impl _impl_c  {
		g sup`v'_`i' = _impl_s_`i'*`v'_`i'
	}
}
sort circle_id fyear qtr
saveold "Coded Data/rerand_supervisor.dta", replace
