
****** Circle Clusterings ******

* The globals used here are defined in Master Pakistan Tax Analysis.do.

version 12
clear all
pr drop _all
cap log close
set more off
set mem 300m
pause on

cap cd "${PAPER_ANALYSIS}"

// OVERVIEW
* ------------------------
// We cluster at the level of the robust partition, i.e. 
// the maximum set of circles that have been involved in any merges or 
// splits throughout the course of the experiment. The only circles that
// aren't clustered are those that are completely untouched since randomization.

insheet using "${DATA}/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep q4_2011_circle_id rand_circle_id - q4_2013_circle_id

drop if q4_2011_circle_id == .
tempfile xw
save `xw'

forv y = 2012/2013 {
	forv q = 1/4 {
	
		use "${DATA}/Cleaned Data/Administrative Data/Crosswalk/Keys/`y'_q`q'_keys", clear
		keep key2 robust_partition
		rename key2 key
		split key, p(",") destring
		drop key

		gen i = _n
		reshape long key, i(i) j(j)	
		drop if key == .
		
		rename robust_partition q`q'_`y'_rp
		
		keep key q`q'_`y'_rp
		ren key q`q'_`y'_circle_id
		
		merge 1:m q`q'_`y'_circle_id using `xw', nogenerate
		save `xw', replace
	}
}

drop if missing(rand_circle_id)

gen maxcircle0 = rand_circle_id

forv y = 2012/2013 {
	forv q = 1/4 {
		egen maxcircle1 = rowmax(maxcircle*)
		egen maxcircle2 = max(maxcircle1), by(q`q'_`y'_rp)
		egen maxcircle3 = max(maxcircle2), by(rand_circle_id)
		gen maxcircle_q`q'_`y' = maxcircle3
		
		egen cluster`y'q`q' = group(maxcircle_q`q'_`y')
		drop maxcircle1 maxcircle2 maxcircle3
	}
}

keep rand_circle_id cluster*
duplicates drop

isid rand_circle_id

collapse (max) cluster*, by(rand_circle_id)

reshape long cluster, i(rand_circle_id) j(qtr_string) string
split qtr_string, parse("q") destring
drop qtr_string

rename qtr_string1 fyear
rename qtr_string2 qtr

ren cluster cluster_c
ren rand_circle_id circle_id

label var circle_id "Circle ID (At randomization)"

order circle_id fyear qtr cluster_c
saveold "Coded Data/Circle Clusters.dta", replace
