/*
	Survey Analysis Coding
	
	Put together various components into main survey data analysis file.
	Main ingredients = cleaned survey data, circle clusters, and treatment variables

*/

clear all
set more off

cap cd "${PAPER_ANALYSIS}"

** COMPILE SURVEY DATA FOR ANALYSIS. *******************************************
********************************************************************************

use "${PAKTAX_ANALYSIS}/Data/Cleaned Data/Field Survey/Round 3/survey_cleaned_data", clear

* Merge in clusters
merge m:1 circle_id using "Coded Data/Survey Circle Clusters.dta"
assert _merge == 3
drop _merge

* Survey ID incorporates merge in FY 13 Q3, but we want to stick to Q2 circle IDs for
* consistency
replace circle_id = 612200 if circle_id == 612210 & cluster_id < 7
replace circle_id = 612300 if circle_id == 612210 & cluster_id > 6

* Merge in Treatment Variables
merge m:1 circle_id using "Coded Data/Survey Treatment Variables"
assert _merge == 3
drop _merge

********* Label Variables *********
label var _impl_c_xw "Any Treatment"
label var REV_impl_xw "Revenue"
label var REVPLS_impl_xw "Revenue Plus"
label var CFW_impl_xw "Flexible Bonus"

gen short_dummy = source == "short"
gen land_area_sqft = land_area* 9

qui tab circle_id, generate(circlefe)

gen SEC9_impl_c_xw = SEC9 * _impl_c_xw
gen SEC9_select_c_xw = SEC9 * _select_c_xw

label var _impl_c_xw "Treatment"
label var SEC9_impl_c_xw "Re-assessed * Treatment"
label var SEC9 "Re-assessed"

foreach var of varlist REV_impl_xw REVPLS_impl_xw CFW_impl_xw INFO_impl_xw {
	gen SEC9`var' = SEC9 * `var'
}

foreach var of varlist REV_sel_xw REVPLS_sel_xw CFW_sel_xw INFO_sel_xw {
	gen SEC9`var' = SEC9 * `var'
}

label var SEC9REV_impl_xw "Re-assessed * Revenue"
label var SEC9REVPLS_impl_xw "Re-assessed * Revenue Plus"
label var SEC9CFW_impl_xw "Re-assessed * Flexible Bonus"
label var SEC9INFO_impl_xw "Re-assessed * Information"

saveold "Coded Data/survey_coded_data", replace


*******************************
** REPEAT ABOVE, FOR ONLY ADDRESS PROPERTIES
*******************************

use "${PAKTAX_ANALYSIS}/Data/Cleaned Data/Field Survey/Round 3/survey_cleaned_data_with_address_only", clear

* Merge in clusters
merge m:1 circle_id using "Coded Data/Survey Circle Clusters.dta"
assert _merge == 3
drop _merge

* Survey ID incorporates merge in FY 13 Q3, but we want to stick to Q2 circle IDs for
* consistency
replace circle_id = 612200 if circle_id == 612210 & cluster_id < 7
replace circle_id = 612300 if circle_id == 612210 & cluster_id > 6

* Merge in Treatment Variables
merge m:1 circle_id using "Coded Data/Survey Treatment Variables"
assert _merge == 3
drop _merge

********* Label Variables *********
label var _impl_c_xw "Any Treatment"
label var REV_impl_xw "Revenue"
label var REVPLS_impl_xw "Revenue Plus"
label var CFW_impl_xw "Flexible Bonus"

gen short_dummy = source == "short"
gen land_area_sqft = land_area* 9

saveold "Coded Data/survey_coded_data_with_address_only", replace
