clear all
set more off

set matsize 800

cap cd "${PAKTAX_ANALYSIS}"

*******************************************************************

***********************
* Data Prep

u "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Sec9_Title_Count.dta", clear

** GENERATE NEW VARIABLES
gen new_y2 = S9TITLE_q4a + S9TITLE_q5a
gen new_y1 = S9TITLE_q6a + S9TITLE_q7a
gen new_y0 = S9TITLE_q9a + S9TITLE_q10a

gen new = new_y2 + new_y1

gen reassess_y2 = S9TITLE_q4b + S9TITLE_q5b
gen reassess_y1 = S9TITLE_q6b + S9TITLE_q7b
gen reassess_y0 = S9TITLE_q9b + S9TITLE_q10b

gen reassess = reassess_y2 + reassess_y1

gen total_y2 = new_y2 + reassess_y2
gen total_y1 = new_y1 + reassess_y1
gen total_y0 = new_y0 + reassess_y0

gen total = total_y2 + total_y1

* Fixing the circle coding problem
replace circle_id = 612200 if circle_name == "MODEL TOWN-EXT-I"
replace circle_id = 612300 if circle_name == "MODEL TOWN-EXT-II"

drop if circle_id == .
isid circle_id

gen fy2012s2 = S9TITLE_q4c
gen fy2012s1 = S9TITLE_q5c
gen fy2011s2 = S9TITLE_q6c
gen fy2011s1 = S9TITLE_q7c

assert fy2012s2 != . if phase == 2
assert fy2012s1 != .
assert fy2011s2 != .
assert fy2011s1 != .

tempfile n
save `n'

***********************
* Estimate

use "Tax Farming Redux/Coded Data/survey_coded_data", clear

merge m:1 circle_id using `n'
*keep if _merge == 3
*drop _merge

* Weights
gen w = .

// Phase 2
replace w = fy2012s2 / 3 if SEC9 == 1 & phase == 2 & inrange(register_added_date_1, mdy(1,1,2013), mdy(6,30,2013))
replace w = fy2012s1 / 3 if SEC9 == 1 & phase == 2 & inrange(register_added_date_1, mdy(7,1,2012), mdy(12,31,2012))
replace w = fy2011s2 / 2 if SEC9 == 1 & phase == 2 & inrange(register_added_date_1, mdy(1,1,2012), mdy(6,30,2012))
replace w = fy2011s1 / 2 if SEC9 == 1 & phase == 2 & inrange(register_added_date_1, mdy(7,1,2011), mdy(12,31,2011))

// Phase 1
replace w = fy2012s1 / 3 if SEC9 == 1 & phase == 1 & inrange(register_added_date_1, mdy(7,1,2012), mdy(12,31,2012))
replace w = fy2011s2 / 2 if SEC9 == 1 & phase == 1 & inrange(register_added_date_1, mdy(1,1,2012), mdy(6,30,2012))
replace w = fy2011s1 / 2 if SEC9 == 1 & phase == 1 & inrange(register_added_date_1, mdy(7,1,2011), mdy(12,31,2011))

* Fixes for missing data
replace w = fy2012s2 / 3 if SEC9 == 1 & tax_liable_date_1 == mdy(7, 1, 2013) & w == .
replace w = fy2012s1 / 3 if SEC9 == 1 & tax_liable_date_1 == mdy(1, 1, 2013) & w == .
replace w = fy2011s2 / 2 if SEC9 == 1 & tax_liable_date_1 == mdy(7, 1, 2012) & w == .
replace w = fy2011s1 / 2 if SEC9 == 1 & tax_liable_date_1 == mdy(1, 1, 2012) & w == .
replace w = fy2011s1 / 2 if SEC9 == 1 & tax_liable_date_1 == mdy(7, 1, 2011) & w == .

egen w_category = mean(w), by(SEC9 category_scale)
replace w = w_category if SEC9 == 1 & (w == . | w == 0)

assert w != . & w != 0 if SEC9 == 1

egen w_total = total(w), by(circle_id SEC9)
gen w2 = w / w_total if SEC9 == 1

sum w if SEC9 == 1
replace w  = `r(mean)' if SEC9 == 0

sum w2 if SEC9 == 1
replace w2  = `r(mean)' if SEC9 == 0

keep prop_id w w2 S9TITLE_q4 S9TITLE_q3

save "Tax Farming Redux/Coded Data/survey/weights.dta", replace
 
