****** Randomization Balance ******
****** Randomization Balance ******
****** Randomization Balance ******
****** Randomization Balance ******

clear all
pr drop _all
cap log close
set more off
set mem 500m
set matsize 800
*set matsize 4000
*set maxvar 32767

cap cd "${PAPER_ANALYSIS}"
adopath ++ "Do Files/Ado Files"

local rerand = "Coded Data/rerand_balance.dta" // Fake randomization data for the rireg (Randomization Inference)
local iter = 1000 	// Number of iteration for RI

*************
* 1. Coding
*************

* GET DATA
u "Coded Data/Phase III Analysis Data.dta", clear

* RECODE _SELECT VARIABLES FOR THIS PURPOSE: supervisors
foreach v of varlist _select_s ETO_clus_rand stratdum_s* {		// they're not selected in fy2012, but we want to use that data
	bys circle_id: egen temp = max(`v')
	replace `v' = temp
	drop temp
	}

* circles
drop *2all
g _select_c2all = _select_c1==1 | _select_c2==1		// we want _select_c2all to be all treated in year 2, not just year 2 circles!
g REV_sel2all = REV_sel1==1 | REV_sel2==1
g REVPLS_sel2all = REVPLS_sel1==1 | REVPLS_sel2==1
g CFW_sel2all = CFW_sel1==1 | CFW_sel2==1

* KEEP WHAT WE NEED
keep fyear qtr circle_id ETO_clus_rand _select_c1 _select_c2 *2all _select_s INFO_sel2 REV_sel? REVPLS_sel? CFW_sel? base_ln_recov_tot_t base_ln_nonexemptrate_t base_ln_recoveryrate_t base_ln_growthrate_t NumStaff PosFilled bench stratum_c stratum_s stratdum_c* stratdum_s*	// note that NumStaff and PosFilled are only defined at baseline
keep if fyear==2012 & qtr==4
replace bench = ln(bench)


* SET UP TABLE
g count = _n in 1/15
foreach v in Variables Control_C  Control_I  Control_S Treatment_S {
	if substr("`v'",1,7)=="Control" g `v' = .
	else g `v' = ""
	}

* RENAME
ren base_ln_recov_tot_t recov_tot_t
ren base_ln_nonexemptrate_t nonexemptrate
ren base_ln_recoveryrate_t recovrate
ren base_ln_growthrate_t growthrate
	
tempfile data
sa `data'


********************
* 2. BALANCE TABLE
********************

* KEEP RELEVANT QUARTERS
u `data', clear

* CONTROL VALUES AND VARIABLE NAMES
forv x = 1/7 {
	local row1 = 2*`x'-1
	local row2 = 2*`x'
	local var : word `x' of recov_tot_t recovrate nonexemptrate NumStaff PosFilled bench growthrate
	replace Variables = "`x'" if count==`row1'
	sum `var' if _select_c2==0
	replace Control_C = round(`r(mean)',.001) if count==`row1'
	sum `var' if _select_c2==0 & INFO_sel2==0
	replace Control_I = round(`r(mean)',.001) if count==`row1'
	sum `var' if _select_s==0
	replace Control_S = round(`r(mean)',.001) if count==`row1'
	}
replace Variables = "P-Value" if count==15

*** TESTS FOR CIRCLE TREATMENTS

gen infosample = (_select_c2==0 | INFO_sel2==1)
* First, circle treatments
forv y = 1/2 {
	local a : word `y' of _select_c2all INFO_sel2
	local b : word `y' of Treatment_C Information
	g `b' = ""
	cap drop count
	g count = _n in 1/15
	forv x = 1/7 {								// Loop over variables = rows of table
		local row1 = 2*`x'-1
		local row2 = 2*`x'
		local var : word `x' of recov_tot_t recovrate nonexemptrate NumStaff PosFilled bench growthrate
		if `y'==2 rireg using "`rerand'" if infosample==1, y(`var') x(`a') z(`a') control(stratdum_c*) iter(`iter')
		else rireg using "`rerand'", y(`var') x(`a') z(`a') control(stratdum_c*) iter(`iter')					// Regress overall treatment with FE
		* Coefficient
		matrix tmat = e(coef)
		local d = tmat[1,1]
		local d = round(`d',.001)
		replace `b' = "`d'" if count==`row1'
		matrix tmat = e(pval)
		local e = tmat[1, 1]
		local e = round(`e',.001)
		replace `b' = "["+substr("`e'",1,4)+"]" if count==`row2'
		* Significance
		if `e' < .1 replace `b' = `b'+"*" if count==`row1'
		if `e' < .05 replace `b' = `b'+"*" if count==`row1'
		if `e' < .01 replace `b' = `b'+"*" if count==`row1'
	}
}

* Second, subtreatments
foreach b in Revenue RevPlus CFW {
	gen `b' = ""
}
forv x = 1/7 {								// Loop over variables = rows of table
	local var : word `x' of recov_tot_t recovrate nonexemptrate NumStaff PosFilled bench growthrate
	rireg using "`rerand'", y(`var') x(REV_sel2all REVPLS_sel2all CFW_sel2all) z(REV_sel2all REVPLS_sel2all CFW_sel2all) control(stratdum_c*) iter(`iter')	// Regress subtreatments with FE
	matrix coef`x' = e(coef)
	matrix pval`x' = e(pval)
}
forv x = 1/7 {
	local row1 = 2*`x'-1
	local row2 = 2*`x'
	forv y = 1/3 {									// Loop over treatments = columns of table
	local a : word `y' of REV_sel2all REVPLS_sel2all CFW_sel2all
	local b : word `y' of Revenue RevPlus CFW
	* Coefficient
	local d = coef`x'[1,`y']
	local d = round(`d',.001)
	replace `b' = "`d'" if count==`row1'
	local e = pval`x'[1, `y']
	local e = round(`e',.001)
	replace `b' = "["+substr("`e'",1,4)+"]" if count==`row2'
	* Significance
	if `e' < .1 replace `b' = `b'+"*" if count==`row1'
	if `e' < .05 replace `b' = `b'+"*" if count==`row1'
	if `e' < .01 replace `b' = `b'+"*" if count==`row1'
	}
}

* Third, supervisor treatment

local a = "_select_s"
local b = "Treatment_S"
cap drop count
g count = _n in 1/15
forv x = 1/7 {								// Loop over variables = rows of table
	local row1 = 2*`x'-1
	local row2 = 2*`x'
	local var : word `x' of recov_tot_t recovrate nonexemptrate NumStaff PosFilled bench growthrate
	rireg using "`rerand'", y(`var') x(`a') z(`a') control(stratdum_s*) iter(`iter')					// Regress overall treatment with FE
	* Coefficient
	matrix tmat = e(coef)
	local d = tmat[1,1]
	local d = round(`d',.001)
	replace `b' = "`d'" if count==`row1'
	matrix tmat = e(pval)
	local e = tmat[1, 1]
	local e = round(`e',.001)
	replace `b' = "["+substr("`e'",1,4)+"]" if count==`row2'
	* Significance
	if `e' < .1 replace `b' = `b'+"*" if count==`row1'
	if `e' < .05 replace `b' = `b'+"*" if count==`row1'
	if `e' < .01 replace `b' = `b'+"*" if count==`row1'
}

*** SUR (Joint significance)

* First for circle treatment, info treatment
forv r = 1/2 {
	local v : word `r' of _select_c2all INFO_sel2
	local b : word `r' of Treatment_C Information
	preserve
	ren recov_tot_t y1 // Log revenue
	ren recovrate y2 // Log recovery rate
	ren nonexemptrate y3 // Log non-exempt rate
	ren NumStaff y4 // # of people posted
	ren PosFilled y5 // All positions filled
	gen y6 = ln(bench) // Log benchmark
	ren growthrate y7 // FY 10-11 log growth rate
	reshape long y, i(circle_id) j(eq)
	sort eq circle_id
	forvalues k = 1/7 {
		gen `v'_`k' = `v' if eq == `k'
		replace `v'_`k' = 0 if mi(`v'_`k')
		gen eq`k' = (eq==`k')
			forvalues l = 2(1)19 {
				gen str`l'_eq`k' = stratdum_c`l'*eq`k'
			}
	}
	local s = `r'+1
	if `r'==2 rireg using "Coded Data/rerand_SUR`s'.dta" if infosample == 1, y(y) x(`v'_?) z(`v'_?) control(stratdum_c? eq? str*_eq*) iter(`iter') test(`v'_1=`v'_2=`v'_3=`v'_4=`v'_5=`v'_6=`v'_7=0) cl(circle_id)
	else rireg using "Coded Data/rerand_SUR`s'.dta", y(y) x(`v'_?) z(`v'_?) control(stratdum_c? eq? str*_eq*) iter(`iter') test(`v'_1=`v'_2=`v'_3=`v'_4=`v'_5=`v'_6=`v'_7=0) cl(circle_id)
	matrix temp = e(test)
	restore
	local d = round(temp[1,1], .0001)
	replace `b' = "`d'" in 15
}

* Second for subtreatment
preserve
ren recov_tot_t y1 // Log revenue
ren recovrate y2 // Log recovery rate
ren nonexemptrate y3 // Log non-exempt rate
ren NumStaff y4 // # of people posted
ren PosFilled y5 // All positions filled
gen y6 = ln(bench) // Log benchmark
ren growthrate y7 // FY 10-11 log growth rate
reshape long y, i(circle_id) j(eq)
sort eq circle_id
forvalues k = 1/7 {
	foreach v in REV_sel2all REVPLS_sel2all CFW_sel2all {
		gen `v'_`k' = `v' if eq == `k'
		replace `v'_`k' = 0 if mi(`v'_`k')
	}
	gen eq`k' = (eq==`k')
	forvalues l = 2(1)19 {
		gen str`l'_eq`k' = stratdum_c`l'*eq`k'
	}
}
rireg using "Coded Data/rerand_SUR2.dta", y(y) x(REV_sel2all_? REVPLS_sel2all_? CFW_sel2all_?) z(REV_sel2all_? REVPLS_sel2all_? CFW_sel2all_?) control(stratdum_c? eq? str*_eq*) iter(`iter') cl(circle_id) ///
	  test(REV_sel2all_1=REV_sel2all_2=REV_sel2all_3=REV_sel2all_4=REV_sel2all_5=REV_sel2all_6=REV_sel2all_7=0 REVPLS_sel2all_1=REVPLS_sel2all_2=REVPLS_sel2all_3=REVPLS_sel2all_4=REVPLS_sel2all_5=REVPLS_sel2all_6=REVPLS_sel2all_7=0 CFW_sel2all_1=CFW_sel2all_2=CFW_sel2all_3=CFW_sel2all_4=CFW_sel2all_5=CFW_sel2all_6=CFW_sel2all_7=0)
matrix temp = e(test) 
restore
forvalues r= 1/3 {
	local b : word `r' of Revenue RevPlus CFW
	local d = round(temp[1,`r'], .0001)
	replace `b' = "`d'" in 15
}

* Third for supervisor treatment
local v = "_select_s"
local b = "Treatment_S"
local iter = 1000 //temporary
preserve
ren recov_tot_t y1 // Log revenue
ren recovrate y2 // Log recovery rate
ren nonexemptrate y3 // Log non-exempt rate
ren NumStaff y4 // # of people posted
ren PosFilled y5 // All positions filled
gen y6 = ln(bench) // Log benchmark
ren growthrate y7 // FY 10-11 log growth rate
reshape long y, i(circle_id) j(eq)
sort eq circle_id
forvalues k = 1/7 {
	gen `v'_`k' = `v' if eq == `k'
	replace `v'_`k' = 0 if mi(`v'_`k')
	gen eq`k' = (eq==`k')
		forvalues l = 2(1)19 {
			gen str`l'_eq`k' = stratdum_s`l'*eq`k'
		}
}
rireg using "Coded Data/rerand_SUR3.dta", y(y) x(`v'_?) z(`v'_?) control(stratdum_s? eq? str*_eq*) iter(`iter') ///
	test(`v'_1=`v'_2=`v'_3=`v'_4=`v'_5=`v'_6=`v'_7=0) cl(ETO_clus_rand)
matrix temp = e(test)
restore
local d = round(temp[1,1], .0001)
replace `b' = "`d'" in 15

outsheet Variables Control_C Treatment_C Revenue RevPlus CFW Information Control_I Information Control_S Treatment_S in 1/15 using "${RI_OUTPUT}/Randomization Balance Year 2_RI.csv", comma replace

*log close



