/*******************************************************************************
2014 PAPER TABLES - MARGINS - MAIN - DROP REV+

Wayne Aaron Sandholtz
24 January 2014
SUMMARY: 
OUTLINE:

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Coded Data/Phase III Analysis Data.dta", clear

drop if REVPLS_sel == 1

forv z = 1/3 {
	local x : word `z' of t c a
	local y : word `z' of Total Current Arrears
	
	gen _impl_c_`x' = _impl_c
	gen INFO_impl_`x' = INFO_impl
	label var _impl_c_`x' "Any Treatment"
	label var INFO_impl_`x' "Information"
	
	label var ln_gross_dem_`x' "Gross Demand"
	label var ln_nonexemptrate_`x' "Non-exemption Rate"
	label var ln_net_dem_`x' "Net Demand"
	label var ln_recoveryrate_`x' "Recovery Rate"
	label var ln_recov_tot_`x' "Revenue"
}


forv y = 1/2 {

	local year : word `y' of 2012 2013
	local phase : word `y' of II III
	
	forv z = 1/4 {
		local yvar : word `z' of ln_recov_tot_ ln_gross_dem_ ln_nonexemptrate_ ln_recoveryrate_ 
		local w : word `z' of Recovery GrossDemand NonExempt RecoveryRate
		
		* Regress
		foreach x in t c a {

	
			eststo `x' : ivreg `yvar'`x' base_ln_gross_dem_`x' base_ln_net_dem_`x' ///
				base_ln_recov_tot_`x' (_impl_c_`x' =_select_c) stratdum_c* ///
				if fyear == `year' & qtr == 4, cl(cluster_c)
		
			qui sum `yvar'`x' if e(sample) == 1 & _select_c == 0
			estadd scalar ymean = `r(mean)'		
		}
		eststo `phase'_`w' : combine_models2 t c a, headings(A B C)	
		*eststo `phase'_`w' : appendmodels t c a
	}
}

** TeX OUTPUT ******************************************************************

# delimit ;
esttab II_Recovery II_GrossDemand II_NonExempt II_RecoveryRate III_Recovery III_GrossDemand III_NonExempt III_RecoveryRate
	using "${TABLE_OUTPUT}/tex/input/margins_main_droprevplus_input.tex" , 
	keep(_impl_c_t _impl_c_c _impl_c_a)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
			
	mtitles(
	  "Revenue"
	  "Tax Base"
	  "\specialcell{Non- \\ Exemption \\ Rate}"
	  "\specialcell{Recovery \\ Rate}"
	  "Revenue"
	  "Tax Base"
	  "\specialcell{Non- \\ Exemption \\ Rate}"
	  "\specialcell{Recovery \\ Rate}"
	) // Column headings

	mgroups("Year 1" "Year 2", pattern(1 0 0 0 1 0 0 0)
		prefix(\multicolumn{@span}{c}{) suffix(}) span
		erepeat(\cmidrule(lr){@span})
	)

	
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Total}"
			"\emph{Curent}"
			"\emph{Arrears}"
			
			//prefix is added before every eqlabel, and suffix after every exlabel. 
			//Span forces column to span across rows, and @span is the width of the table
			// \addlinespace[1mm] adds extra space before table row. 
			prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
		)

	
	stats(
		N1 ymean1,
		  labels("N (Total)" "Mean of control group (Total)")	
		fmt("%12.0f" "%12.3f")
	)
	
	label // Use Variable Labels
	
	nonotes
	  
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

local file margins_main_droprevplus

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table re-estimates Appendix Table 14, dropping Revenue Plus circles. See Notes to Appendix Table 14 for additional information."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
cap log close
