/*******************************************************************************
BRIBE PAYMENT
INTENSIVE VS. EXTENSIVE MARGIN

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Coded Data/survey_coded_data.dta", clear

label var _impl_c_xw "Treatment"
label var SEC9_impl_c_xw "Re-assessed * Treatment"
label var SEC9 "Re-assessed"

** REGRESSIONS *****************************************************************

gen zerobribe = tax_payment_total == 0
replace zerobribe = . if tax_payment_total == .

* Regress
eststo col1 : ivreg tax_payment_total (_impl_c_xw =_select_c_xw) short_dummy stratdum_c* if SEC9 == 0 & phase == 1, cluster(cluster_c)

qui sum tax_payment_total if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
estadd scalar ysumm = `r(mean)'

estadd local restrict = "No"

eststo col2 : ivreg tax_payment_total (_impl_c_xw =_select_c_xw) short_dummy stratdum_c* if SEC9 == 0 & phase == 1 & tax_payment_total > 0, cluster(cluster_c)

qui sum tax_payment_total if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
estadd scalar ysumm = `r(mean)'

estadd local restrict = "Yes"

eststo col3 : ivreg zerobribe (_impl_c_xw =_select_c_xw) short_dummy stratdum_c* if SEC9 == 0 & phase == 1, cluster(cluster_c)

qui sum zerobribe if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
estadd scalar ysumm = `r(mean)'

estadd local restrict = "N/A"


# delimit ;
esttab col1 col2 col3 
	using "${TABLE_OUTPUT}\tex\input\bribe_intensive_input.tex" , 
	keep(_impl_c_xw)
	
	b(%6.0g)
	se(%6.0g)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("\specialcell{Bribe Payment}"
	  "\specialcell{Bribe Payment}"
	  "\specialcell{Bribe Payment $= 0$}") // Column headings

	stats(N ysumm restrict,
	  labels("N" "Mean of control group" "Restricted to positive bribe payments")
	  fmt("%12.0f" "%12.3f")
	)
	//nonumbers // No column numbers
	label // Use Variable Labels	
	nonotes
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;
# delimit cr



set more off
local file bribe_intensive


** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table separates the impact of performance pay schemes on bribe payments into 1) the amount of bribe paid and 2) the likelihood of paying any bribe."
file write tablenote " Column 1 replicates Column 2 of Table 6 of the main text."
file write tablenote " Column 2 repeats the same specification, restricting to taxpayers that report positive bribe payments."
file write tablenote " Column 3 uses as a dependent variable a dummy equal to 1 if the taxpayer reports 0 bribe payments."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
