
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Coded Data/survey_coded_data", clear

gen randomnew = SEC4_q9 >= 2010 & SEC4_q9 < . & SEC9 == 0 // constructed in 2010 or afterwards in the gen. pop. sample
gen new = S9LOG_q4_1 == 1 // Section 9 new
gen allnew = new == 1 | randomnew == 1

keep if SEC9 == 0 | allnew == 1

** PANEL A **

foreach v of varlist pctcom tot_cov_area floors  {
	eststo `v' : areg `v' randomnew new, absorb(circle_id) cluster(cluster_c)

	test randomnew = new
	estadd scalar testeq = `r(p)'
	
	qui sum `v' if SEC9 == 0 & allnew != 1
	estadd scalar r = `r(mean)'
	
}

label var new "Newly Assessed" 
label var randomnew "\specialcellleft{Newly Constructed Properties \\ in gen. pop. sample}" 

# delimit ;
esttab pctcom tot_cov_area floors 
	using "${TABLE_OUTPUT}/tex/input/new_vs_randomnew_a_input.tex", 
	keep(new randomnew)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{Percent Area \\ Commercial}"
		"\specialcell{Total Covered \\ Area}"
		"\specialcell{Number of \\ Floors}") // Column headings
	
	//nonumbers // No column numbers
	
	stats(N r testeq,
		labels(
			"N"
			"Mean of non-new properties in gen. pop. sample"
			"Newly Constructed $=$ Reassessed New"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	nonotes
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	replace
	;

# delimit cr
eststo clear


** PANEL B **

foreach v of varlist pctrent yrs_occupy {

eststo `v' : areg `v' randomnew new, absorb(circle_id) cluster(cluster_c)
	test randomnew = new
	estadd scalar testeq = `r(p)'
	
	qui sum `v' if SEC9 == 0 & allnew != 1
	estadd scalar r = `r(mean)'
	
	estadd local controls = "No"
	
eststo `v'_control : areg `v' randomnew new pctcom tot_cov_area floors, absorb(circle_id) cluster(cluster_c)
	test randomnew = new
	estadd scalar testeq = `r(p)'
	
	qui sum `v' if SEC9 == 0 & allnew != 1
	estadd scalar r = `r(mean)'
	
	estadd local controls = "Yes"	
}


# delimit ;
esttab pctrent pctrent_control yrs_occupy yrs_occupy_control 
	using "${TABLE_OUTPUT}/tex/input/new_vs_randomnew_b_input.tex", 
	keep(new randomnew)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{Percent Area \\ Rented}"
		"\specialcell{Percent Area \\ Rented}"
		"\specialcell{Number of Years \\ Occupying Property}"
		"\specialcell{Number of Years \\ Occupying Property}") // Column headings
	
	//nonumbers // No column numbers
	
	stats(N r testeq controls,
		labels(
			"N"
			"Mean of non-new properties in gen. pop. sample"
			"Newly Constructed $=$ Reassessed New"
			"Controls for Panel A characteristics"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	nonotes
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

*****************************

set more off
local file new_vs_randomnew

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table compares properties in the general population sample constructed before 2010 with 1) properties built in or after 2010;"
file write tablenote " and 2) properties marked as newly assessed in the Section 9 register."
file write tablenote " 'Newly constructed properties' refers to the former and 'Newly Assessed' refers to the latter."
file write tablenote " Specification includes circle fixed effects."
file write tablenote " Panel A uses easily observable characteristics as dependent variables."
file write tablenote " Panel B uses harder to observe charateristics as dependent variables, also including variables from Panel A as controls."
file write tablenote " Standard errors are clustered by robust partition of circles,"
file write tablenote " the group of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote


file open tablenotefile using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", read
file read tablenotefile noteline


** Write the file **********************************************************
# delimit ;
cap file close x;
file open x using "${TABLE_OUTPUT}/tex/`file'.tex" ///
  , write replace;
foreach thing in 
`"\documentclass[preview, varwidth=7in, border=10pt]{standalone} 	"'
`"\usepackage{amsmath}                                                  "'
`"\usepackage{amsfonts}                                                 "'
`"\usepackage{booktabs}                                                 "'
`"\usepackage{threeparttable}                                           "'
`"\usepackage{titlesec}                                                 "'
`"                                                                      "'
`"% This is for word wrap in cells in tables.                           "'
`"\newcommand{\specialcellleft}[2][l]{%                                 "'
`"\begin{tabular}[#1]{@{}l@{}}#2\end{tabular}}                          "'
`"\newcommand{\specialcell}[2][l]{%                                     "'
`"\begin{tabular}[#1]{@{}c@{}}#2\end{tabular}}                          "'
`"                                                                      "'
`"\titleformat{\section}                                                "'
`"  {\normalfont\scshape}{\thesection}{1em}{}                           "'
`"                                                                      "'
`"\begin{document}                                                      "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel A: Easy to observe characteristics}\\"'
`"\input{"input/`file'_a_input.tex"}		                           	"'
`"\end{table}                                                           "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel B: Harder to observe characteristics}\\"'
`"\begin{threeparttable}												"'
`"\begin{tabular}{l*{4}{c}}									            "'
`"\toprule																"'
`"\input{"input/`file'_b_input.tex"}		                          	"'
`"\bottomrule															"'
`"\end{tabular}														    "'
`"\end{threeparttable} \\													"'
`"\scriptsize \emph{Notes}: `noteline'							"'
`"\end{table}                                                           "'
`"\end{document}                                                        "'{;
	file write x `"`thing'"' _n;
};
file close x;
# delimit cr
****************************************************************************

file close tablenotefile

** COMPILE *********************************************************************

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
	
cap log close
