clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

***********************************************************

use "Coded Data\Phase III Analysis Data.dta", clear
keep if fyear == 2013 & qtr == 4
gen newtreat = _select_c1 == 0 & _select_c2 > 0

keep circle_id _select_c REV_sel REVPLS_sel CFW_sel stratdum_c* cluster_c newtreat

tempfile treat
save `treat'

use "Coded Data\Staff Transfers Long", clear

merge m:1 circle_id using `treat', assert(match) nogen

label var _select_c "Any treatment"
label var REV_sel "Revenue"
label var REVPLS_sel "Revenue Plus"
label var CFW_sel "Flexible Bonus"

drop if newtreat == 1

* Column 1
eststo col1_A : reg transfer _select_c stratdum_c* if inspector == 1, cluster(cluster_c)
eststo col1_B : reg transfer REV_sel REVPLS_sel CFW_sel stratdum_c* if inspector == 1, cluster(cluster_c)

qui sum transfer if e(sample) == 1 & _select_c == 0
estadd scalar ymean = `r(mean)'	

* Column 2
eststo col2_A : reg transfer _select_c stratdum_c* if constable == 1, cluster(cluster_c)
eststo col2_B : reg transfer REV_sel REVPLS_sel CFW_sel stratdum_c* if constable == 1, cluster(cluster_c)

qui sum transfer if e(sample) == 1 & _select_c == 0
estadd scalar ymean = `r(mean)'	

* Column 3
eststo col3_A : reg transfer _select_c stratdum_c* if clerk == 1, cluster(cluster_c)
eststo col3_B : reg transfer REV_sel REVPLS_sel CFW_sel stratdum_c* if clerk == 1, cluster(cluster_c)

qui sum transfer if e(sample) == 1 & _select_c == 0
estadd scalar ymean = `r(mean)'	
				
* Column 4
eststo col4_A : reg transfer _select_c constable clerk stratdum_c*, cluster(cluster_c)
eststo col4_B : reg transfer REV_sel REVPLS_sel CFW_sel constable clerk stratdum_c*, cluster(cluster_c)
	
qui sum transfer if e(sample) == 1 & _select_c == 0
estadd scalar ymean = `r(mean)'	

forval i = 1/4 {
	eststo col`i' : combine_models2 col`i'_A col`i'_B, headings(A B)
}

# delimit ;
esttab col1 col2 col3 col4
	using "${TABLE_OUTPUT}\tex\input\transfers_long_input.tex", 
	keep(_select_c REV_sel REVPLS_sel CFW_sel)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Inspector"
	"Constable"
	"Clerk"
	"All"
	)
	
	eqlabels(
		//Embed latex code into the labels (emphasis)
		"\emph{Panel A: Main Treatment}"
		"\emph{Panel B: Subtreatments}"
		
		//prefix is added before every eqlabel, and suffix after every exlabel. 
		//Span forces column to span across rows, and @span is the width of the table
		// \addlinespace[1mm] adds extra space before table row. 
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
			
	stats(N2 ymean2,
		labels(
			"N"
			"Mean of control group"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file transfers_long

** WRITE TABLE NOTE

file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "OLS regressions of transfer probability on randomization status."
file write tablenote " Columns separate effects by staff type."
file write tablenote " Unit of observation is a staff members."
file write tablenote " Sample restricted to circles that remained in treatment or control for two years."
file write tablenote " Specification includes strata fixed effects. Column 4 also includes staff type fixed effects."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by a robust partition of circles,"
file write tablenote " the group of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

cap log close
