****** Additional Channels ***********

clear all
set more off

pr drop _all
cap log close
set mem 300m

cap cd "${PAPER_ANALYSIS}"
do "Do Files/Paper/programs/all_programs.do"

************************************************************************

* Panel A -- INFO

use "Coded Data/Phase III Analysis Data.dta", clear

label var REV_impl "Revenue"
label var REVPLS_impl "Revenue Plus"
label var CFW_impl "Flexible Bonus"
label var INFO_impl "Information                    "

forv z = 1/3 {
	local x : word `z' of t c a
		
	* Regress
	eststo `x' : ///
	  ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' (REV_impl REVPLS_impl ///
		CFW_impl INFO_impl = REV_sel REVPLS_sel CFW_sel INFO_sel) ///
		stratdum_c* if fyear== 2013 & qtr == 4, cluster(cluster_c)
			
	qui sum ln_recov_tot_`x' if e(sample) == 1 & subtreatment == . & INFO_sel != 1
	estadd scalar ymean = `r(mean)'
	
}


# delimit ;
esttab t c a
	using "${TABLE_OUTPUT}/tex/input/additional_channels_a_input.tex", 
	keep(INFO_impl)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Total" "Current" "Arrears") // Column headings
			
	stats(N ymean,
		labels(
			"N"
			"Mean of control group"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$" "l*{3}{c}" "L{4.5cm} C{1cm} C{1cm} C{1cm}")
	replace
	;

# delimit cr
eststo clear

************************************************************

* Panel B -- Income Effects

u "Coded Data/calculations/income_effect_infocontrol_standarderror", clear
keep if model == 2

gen beta = .
gen tstat = .
gen p = .

tempfile coefs
save `coefs'

u "Coded Data/Phase III Analysis Data.dta", clear
keep if qtr == 4 & fyear == 2012

sort circle_id qtr
merge m:1 circle_id using "Coded Data/Benchmarks/120410 Phase II Benchmarks - Full Sample"
assert _merge == 3
drop _merge

foreach var of varlist bench* {
	gen ln_`var' = ln(`var')
}

foreach X in c a {
	reg ln_recov_tot_`X' base_ln_recov_tot_`X' ln_bench_q4_`X' if _select_c == 0, robust
	predict p_recov_tot_`X'
	g income_shock_`X' = (exp(p_recov_tot_`X') - bench_q4_`X')
}

g incomeshock = rewardrate * (income_shock_c + income_shock_a)

g incomeshock2 = incomeshock + (12 * (20000 + 15000 + 15000))
g lnincomeshock = ln(incomeshock2)

foreach var of varlist REV_sel REV_impl REVPLS_sel REVPLS_impl CFW_sel CFW_impl {
	g lnincomeshock_`var' = `var' * lnincomeshock 
}


*****
* Regressions
******

gen is = lnincomeshock
gen is_REV_impl = lnincomeshock_REV_impl
gen is_REVPLS_impl = lnincomeshock_REVPLS_impl
gen is_CFW_impl = lnincomeshock_CFW_impl

gen is_REV_sel = lnincomeshock_REV_sel
gen is_REVPLS_sel = lnincomeshock_REVPLS_sel
gen is_CFW_sel = lnincomeshock_CFW_sel

forval z = 1/3 {
		
	local x : word `z' of t c a
	
	eststo mod_`x' : ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' ln_bench_q4_c ln_bench_q4_a is (REV_impl is_REV_impl REVPLS_impl is_REVPLS_impl CFW_impl is_CFW_impl = REV_sel is_REV_sel REVPLS_sel is_REVPLS_sel CFW_sel is_CFW_sel) stratdum_c*, cluster(cluster_c)

	local rev_beta = _b[is_REV_impl]
	local revpls_beta = _b[is_REVPLS_impl]
	local cfw_beta = _b[is_CFW_impl]
	local is_beta = _b[is]
		
	preserve
		u `coefs', clear

		replace beta = `rev_beta' if t == `z' & variable == 2
		replace beta = `revpls_beta' if t == `z' & variable == 3
		replace beta = `cfw_beta' if t == `z' & variable == 4
		replace beta = `is_beta' if t == `z' & variable == 5
		
		replace tstat = beta / d
		replace p = 2 * (1 - normal(tstat))
		save `coefs', replace
	restore
	
	preserve
		u `coefs', clear

		keep if t == `z'
		keep if inlist(variable, 2, 3, 4, 5)
		sort t variable
		
		mkmat d, matrix(a)
		matrix a = a'
		matrix colnames a = is_REV_impl is_REVPLS_impl is_CFW_impl is

		mkmat p, matrix(b)
		matrix b = b'
		matrix colnames b = is_REV_impl is_REVPLS_impl is_CFW_impl is

	restore

	estadd matrix bs_se = a
	estadd matrix bs_p = b

}

label var is_REV_impl "Revenue * Income Shock"
label var is_REVPLS_impl "\addlinespace Revenue Plus * Income Shock"

label var is_CFW_impl "\addlinespace Flexible Bonus * Income Shock"


label var is "\addlinespace Income Shock"

# delimit ;
esttab mod_t mod_c mod_a
	using "${TABLE_OUTPUT}/tex/input/additional_channels_b_input.tex", 
	keep(is_REV_impl is_REVPLS_impl is)
	order(is_REV_impl is_REVPLS_impl is)
	
	cells(b(star fmt(a3) pval(bs_p)) bs_se(par fmt(a3)))
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Total" "Current" "Arrears")
		
	//nonumbers // No column numbers
	
	stats(N,
		labels(
			"N"
		)	
		fmt(
			"%12.0f"
		)
	)
	
	label // Use Variable Labels
	nonotes
	
	booktabs // a nicer version of tables
	substitute("                    &     b/bs_se   &     b/bs_se   &     b/bs_se   \\" " " "l*{3}{c}" "L{4.5cm} C{1cm} C{1cm} C{1cm}")
	replace
	;

# delimit cr
eststo clear


************************************************************

* Panel C -- Supervisory Treatment

* RI P values
insheet using "${RI_OUTPUT}/Revenue_Supervisors_RI.csv", comma clear
keep if v1 == "" // standard errors on blank rows
drop v1
keep v5
destring v5, ignore("[]") replace

mkmat v5 , matrix(RI_se)

use "Coded Data/Phase III Analysis Data.dta", clear
keep if fyear == 2013
keep if qtr == 4
label var _impl_s "Supervisory treatment                           "

forval z = 1/3 {

	local x : word `z' of t c a
	
	eststo `x' : ///
		ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' (_impl_s = _select_s) ///
		stratdum_s*, cluster(ETO_clus)

	qui sum ln_recov_tot_`x' if e(sample) == 1 & _select_s == 0
	estadd scalar ymean = `r(mean)'
	
	matrix A = RI_se[`z', 1]
	matrix colnames A = _impl_s
	estadd matrix RIse = A , replace	
}

# delimit ;
esttab t c a
	using "${TABLE_OUTPUT}/tex/input/additional_channels_c_input.tex", 
	keep(_impl_s)
	
	cells(b(fmt(3) star pval(RIse)) RIse(vacant("") par([ ])))
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Total" "Current" "Arrears")

	//nonumbers // No column numbers
	
	stats(N ymean,
		labels(
			"N"
			"Mean of control group"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	
	booktabs // a nicer version of tables
	fragment
	substitute("                    &      b/RIse   &      b/RIse   &      b/RIse   \\" "")
	replace
	;

# delimit cr
eststo clear



** WRITE LaTeX WRAPPER *********************************************************

set more off
local file additional_channels
/*
** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "Panels A and B are circle-level 2SLS regressions with FY 2013 log total revenue as the dependent variable."
file write tablenote " Panel A re-estimates main revenue outcomes separating the Information Treatment from the controls (main coefficients are not shown)."
file write tablenote " Panel B estimates income effects. Income Shock is calculated as the amount circle staff team would have earned under the scheme"
file write tablenote " due to business-as-usual, plus their combined base salary (i.e. adding Rs. 20,000 for inspectors and Rs. 15,000 for clerks), and is measured in logs."

file write tablenote " Robust standard errors in parentheses (Panels A and B), and randomization-inference based p-values in brackets (Panel C)."
file write tablenote " For Panels A and B, standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " For Panel C, standard errors are calculated by bootstrapping with 1000 iterations over the two-step procedure (i.e. first estimating the income shock, and then estimating the model)."
file write tablenote " The bootstrap is clustered by robust partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote
*/

file open tablenotefile using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", read
file read tablenotefile noteline


** Write the file **********************************************************
# delimit ;
cap file close x;
file open x using "${TABLE_OUTPUT}/tex/`file'.tex" ///
  , write replace;
foreach thing in 
`"\documentclass[preview, varwidth=\maxdimen, border=10pt]{standalone} 	"'
`"\usepackage{amsmath}                                                  "'
`"\usepackage{amsfonts}                                                 "'
`"\usepackage{booktabs}                                                 "'
`"\usepackage{threeparttable}                                           "'
`"\usepackage{titlesec}                                                 "'
`"\usepackage{tabularx}                                                 "'
`"                                                                      "'
`"% This is for word wrap in cells in tables.                           "'
`"\newcommand{\specialcell}[2][c]{%                                     "'
`"\begin{tabular}[#1]{@{}c@{}}#2\end{tabular}}                          "'
`"                                                                      "'
`"\usepackage{array}													"'
`"\newcolumntype{L}[1]{>{\raggedright\let\newline\\\arraybackslash\hspace{0pt}}m{#1}}"'
`"\newcolumntype{C}[1]{>{\centering\let\newline\\\arraybackslash\hspace{0pt}}m{#1}}"'
`"\newcolumntype{R}[1]{>{\raggedleft\let\newline\\\arraybackslash\hspace{0pt}}m{#1}}"'
`"                                                                      "'
`"\titleformat{\section}                                                "'
`"  {\normalfont\scshape}{\thesection}{1em}{}                           "'
`"                                                                      "'
`"\begin{document}                                                      "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel A}\\"'
`"\input{"input/`file'_a_input.tex"}		                           	"'
`"\end{table}                                                           "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel B}\\"'
`"\input{"input/`file'_b_input.tex"}		                           	"'
`"\end{table}                                                           "'
`"\begin{table}[htp]  													"'
`"\scriptsize                                                           "'
`"\emph{Panel C}\\"'
`"\begin{threeparttable}												"'
`"\begin{tabular}{{L{4.5cm} C{1cm} C{1cm} C{1cm}}}	"'
`"\toprule																"'
`"\input{"input/`file'_c_input.tex"}		                          	"'
`"\bottomrule															"'
`"\end{tabular}														    "'
`"\begin{tablenotes}													"'
`"\item \scriptsize \emph{Notes}: `noteline'							"'
`"\end{tablenotes}														"'
`"\end{threeparttable}													"'
`"\end{table}                                                           "'
`"\end{document}                                                        "'{;
	file write x `"`thing'"' _n;
};
file close x;
# delimit cr
****************************************************************************

file close tablenotefile

** COMPILE *********************************************************************

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
	

cap log close
