* INCOME EFFECT, STANDARD ERRORS
* Bootstrap standard errors

clear all
set more off

cap cd "${PAPER_ANALYSIS}"

**************************************************

* First make a dataset to save out the results. We'll pull directly
* from these numbers later when we make the table.
set obs 2
gen model = _n

expand 5
bys model : gen variable = _n

expand 3

bys model variable : gen t = _n

expand 1000

bys model variable t : gen iter = _n

gen beta = .

tempfile logfile
save `logfile'

set seed 234235

* 1000 iterations of calculating the impact
forval iter=1/1000 {

	u "Coded Data/Phase III Analysis Data.dta", clear
	keep if qtr == 4 & fyear == 2012
	
	* Bootstrap sample does not break clusters
	bsample , cluster(cluster_c)

	sort circle_id qtr
	merge m:1 circle_id using "Coded Data/Benchmarks/120410 Phase II Benchmarks - Full Sample"
	keep if _merge == 3
	drop _merge

	foreach var of varlist bench* {
		gen ln_`var' = ln(`var')
	}

	foreach X in c a {
		reg ln_recov_tot_`X' base_ln_recov_tot_`X' ln_bench_q4_`X' if _select_c == 0, robust
		predict p_recov_tot_`X'
		g income_shock_`X' = (exp(p_recov_tot_`X') - bench_q4_`X')
	}

	g incomeshock = rewardrate * (income_shock_c + income_shock_a)

	g incomeshock2 = incomeshock + (12 * (20000 + 15000 + 15000))
	g lnincomeshock = ln(incomeshock2)

	g OBJ_impl = REV_impl + REVPLS_impl
	g OBJ_sel = REV_sel + REVPLS_sel

	foreach var of varlist REV_sel REV_impl REVPLS_sel REVPLS_impl CFW_sel CFW_impl OBJ_impl OBJ_sel {
		g lnincomeshock_`var' = `var' * lnincomeshock 
	}


	gen is = .
	gen is_OBJ_impl = .
	gen is_CFW_impl = .
	gen is_REV_impl = .
	gen is_REVPLS_impl = .

	gen is_OBJ_sel = .
	gen is_CFW_sel = .
	gen is_REV_sel = .
	gen is_REVPLS_sel = .

	replace is = lnincomeshock

	replace is_OBJ_impl = lnincomeshock_OBJ_impl
	replace is_CFW_impl = lnincomeshock_CFW_impl
	replace is_REV_impl = lnincomeshock_REV_impl
	replace is_REVPLS_impl = lnincomeshock_REVPLS_impl

	replace is_OBJ_sel = lnincomeshock_OBJ_sel
	replace is_CFW_sel = lnincomeshock_CFW_sel
	replace is_REV_sel = lnincomeshock_REV_sel
	replace is_REVPLS_sel = lnincomeshock_REVPLS_sel
	
	forval x=1/3 {
		local X : word `x' of t c a

		ivreg ln_recov_tot_`X' base_ln_recov_tot_`X' ln_bench_q4_c ln_bench_q4_a is (OBJ_impl is_OBJ_impl CFW_impl is_CFW_impl= OBJ_sel is_OBJ_sel CFW_sel is_CFW_sel) stratdum_c*, cluster(cluster_c)
		
		preserve
			use `logfile', clear
			replace beta = _b[is_OBJ_impl] if iter == `iter' & t == `x' & variable == 1 & model == 1
			replace beta = _b[is_CFW_impl] if iter == `iter' & t == `x' & variable == 2 & model == 1
			replace beta = _b[is] if iter == `iter' & t == `x' & variable == 5 & model == 1
			save `logfile', replace
		restore
		
		ivreg ln_recov_tot_`X' base_ln_recov_tot_`X' ln_bench_q4_c ln_bench_q4_a is (REV_impl is_REV_impl REVPLS_impl is_REVPLS_impl CFW_impl is_CFW_impl = REV_sel is_REV_sel REVPLS_sel is_REVPLS_sel CFW_sel is_CFW_sel) stratdum_c*, cluster(cluster_c)

		preserve
			use `logfile', clear
			replace beta = _b[is_REV_impl] if iter == `iter' & t == `x' & variable == 2 & model == 2
			replace beta = _b[is_REVPLS_impl] if iter == `iter' & t == `x' & variable == 3 & model == 2
			replace beta = _b[is_CFW_impl] if iter == `iter' & t == `x' & variable == 4 & model == 2
			replace beta = _b[is] if iter == `iter' & t == `x' & variable == 5 & model == 2
			save `logfile', replace
		restore
		
	}

}

use `logfile', clear

drop if beta == .
egen vargroup = group(model variable t)

egen m = mean(beta), by(vargroup)
gen d = (beta - m)^2

collapse (sum) d (first) model variable t, by(vargroup)

replace d = d / 999
replace d = sqrt(d)

label var d "Bootstrapped Standard Error"
label var t "Margin of Collection"
label var variable "Independent Variable"
label var model "Column"
label var vargroup "Variable ID"

label define margin 1 "Total" 2 "Current" 3 "Arrears"
label values t margin

label define variable 1 "OBJ * Income Shock" 2 "REV * Income Shock" 3 "REVPLS * Income Shock" 4 "CFW * Income Shock" 5 "Income Shock"
label values variable variable

saveold "Coded Data/calculations/income_effect_infocontrol_standarderror", replace
