/*******************************************************************************
NON-REVENUE - WITH BALANCE CONTROL
Impacts on Non-Revenue Outcomes, Controlling for Balance Check Variables

Controls for the same variables that are used in the randomization balance check

Wayne Aaron Sandholtz
24 January 2014

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

insheet using "${DATA}/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear

* Need to adjust for the fact that these survey circles were done
* in terms of Q3 instead of Q2
replace q2_2013_circle_id = 612200 if q2_2013_circle_id == 612210 ///
	& q3_2013_circle_id == 612200
replace q2_2013_circle_id = 612300 if q2_2013_circle_id == 612210 ///
	& q3_2013_circle_id == 612300
	
keep rand_circle_id q2_2013_circle_id 

drop if rand_circle_id == .
duplicates drop

tempfile xw
save `xw'

use "Coded Data/Phase III Analysis Data.dta", clear

keep if fyear == 2012 & qtr == 4

keep circle_id NumStaff PosFilled bench
isid circle_id

ren circle_id rand_circle_id

merge 1:m rand_circle_id using `xw'
assert _merge == 3
drop _merge

foreach var of varlist NumStaff PosFilled bench {
	ren `var' `var'_temp
	egen `var' = mean(`var'_temp), by(q2_2013_circle_id)
	drop `var'_temp
}

replace bench = . if inlist(rand_circle_id, 611900 611902) // These values are missing

keep q2_2013_circle_id NumStaff PosFilled bench
duplicates drop
isid q2_2013_circle_id

ren q2_2013_circle_id circle_id

tempfile baselinevars
save `baselinevars'

***** YEAR 2 *****
use "Coded Data/survey_coded_data.dta", clear
keep if SEC9 == 0

merge m:1 circle_id using "${DATA}/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q2_crosswalk.dta"
drop if _merge == 2
drop _merge

merge m:1 circle_id using "${DATA}/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q3_crosswalk.dta", update
drop if _merge == 2
drop _merge

merge m:1 circle_id using `baselinevars'
assert _merge == 3
drop _merge

gen base_ln_recov_tot_t = log(q4_2011_recov_tot_c + q4_2011_recov_tot_a)
gen base_ln_recoveryrate_t = log((q4_2011_recov_tot_c + q4_2011_recov_tot_a) / (q4_2011_net_dem_c + q4_2011_net_dem_a))
gen base_ln_nonexemptrate_t = log((q4_2011_net_dem_c + q4_2011_net_dem_a) / (q4_2011_gross_dem_c + q4_2011_gross_dem_a))
gen base_ln_growthrate_t = log((q4_2011_recov_tot_c + q4_2011_recov_tot_a) / (q4_2010_recov_tot_c + q4_2010_recov_tot_a))


local baseline_controls base_ln_recov_tot_t base_ln_recoveryrate_t base_ln_nonexemptrate_t NumStaff PosFilled bench base_ln_growthrate_t

label var _impl_c_xw "Any treatment"

label var REV_impl_xw "Revenue"
label var REVPLS_impl_xw "Revenue Plus"
label var CFW_impl_xw "Flexible Bonus"
label var INFO_impl_xw "Information"

// Phase 1 Only - Subjective Variables
foreach yvar of varlist tax_quality tax_satisfied {
		
	* Regress - Main Treatment - Part A
	eststo `yvar'_A : ///
	  ivreg `yvar' (_impl_c_xw =_select_c_xw) short_dummy `baseline_controls' stratdum_c* if phase == 1, ///
	    cluster(cluster_c)
		
	* Regress - Subtreatments - Panel B
	eststo `yvar'_B : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw = ///
	    REV_sel_xw REVPLS_sel_xw CFW_sel_xw) ///
		short_dummy `baseline_controls' stratdum_c* if phase == 1, cluster(cluster_c)
		  
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0
	estadd scalar ysumm	= `r(mean)'
	estadd local samp = "Phase 1"
	
	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'_B 
	estadd equivalence REV_impl REVPLS_impl CFW_impl: `yvar'_B
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_): `yvar'_B
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_): `yvar'_B
	
	eststo `yvar' : combine_models2 `yvar'_A `yvar'_B, headings(A B)
		
}

// Full Sample - Objective Variables
foreach yvar of varlist diff_pct_GARV diff_GARV {
		
	* Regress - Main Treatment - Part A
	eststo `yvar'_A : ///
	  ivreg `yvar' (_impl_c_xw =_select_c_xw) short_dummy phase2 `baseline_controls' stratdum_c*, ///
	    cluster(cluster_c)
	
	* Regress - Subtreatments - Panel B
	eststo `yvar'_B : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw = ///
	    REV_sel_xw REVPLS_sel_xw CFW_sel_xw) ///
		short_dummy phase2 `baseline_controls' stratdum_c*, cluster(cluster_c)
		  
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0
	estadd scalar ysumm	= `r(mean)'
	estadd local samp = "Full"
	
	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'_B 
	estadd equivalence REV_impl REVPLS_impl CFW_impl: `yvar'_B
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_): `yvar'_B
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_): `yvar'_B
	
	eststo `yvar' : combine_models2 `yvar'_A `yvar'_B, headings(A B)
		
}

** TeX OUTPUT ******************************************************************

# delimit ;
esttab tax_quality tax_satisfied diff_GARV diff_pct_GARV
	using "${TABLE_OUTPUT}/tex/input/nonrevenue_baselinecontrol_infocontrol_input.tex", 
	keep(_impl_c_xw REV_impl_xw REVPLS_impl_xw CFW_impl_xw)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Quality" "Satisfaction" "Inaccuracy" "Tax Gap") // Column headings
	
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Main Treatment}"
			"\emph{Panel B: Subtreatments}"
			
			//prefix is added before every eqlabel, and suffix after every exlabel. 
			//Span forces column to span across rows, and @span is the width of the table
			// \addlinespace[1mm] adds extra space before table row. 
			prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
		)
		
	//nonumbers // No column numbers
	
	stats(N2 samp2 ysumm2 rvm_eqavg2 ovs_eqavg2 equivalence2 joint2,
		labels(
			"N"
			"Sample"
			"Mean of control group"
			"Rev. vs. Multitasking p."
			"Objective vs. Subjective p."
			"Equality of Schemes"
			"Joint significance"
		)	
		fmt(
			"%12.0f" "a3" "%12.3f" "%12.3f" "%12.3f" "%12.3f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

local file nonrevenue_baselinecontrol_infocontrol

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table re-estimates Table 4 from the main text, controlling for variables included in the balance checks (see Appendix Table 11 for details). See Notes to Table 4 for additional information."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
cap log close
