/*******************************************************************************
2014 PAPER TABLES - NON-REVENUE - ORDERED PROBIT

SUMMARY: 
OUTLINE:
NOTES:  This file should produce each table in LaTeX, .csv, .rtf, and .txt.

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

***** YEAR 2 *****

use "Coded Data/survey_coded_data.dta", clear
keep if SEC9 == 0

label var _select_c_xw "Any treatment"

label var REV_sel_xw "Revenue"
label var REVPLS_sel_xw "Revenue Plus"
label var CFW_sel_xw "Flexible Bonus"

replace tax_quality = 4 * tax_quality + 1
replace tax_satisfied = 4 * tax_satisfied + 1

// Phase 1 Only - Subjective Variables
foreach yvar of varlist tax_quality tax_satisfied {
		
	* Regress - Main Treatment - Part A
	eststo `yvar'1_A : ///
	  oprobit `yvar' _select_c_xw short_dummy if phase == 1, ///
	    cluster(cluster_c)
		
	* Regress - Subtreatments - Panel B
	eststo `yvar'1_B : ///
	  oprobit `yvar' REV_sel_xw REVPLS_sel_xw CFW_sel_xw ///
		short_dummy if phase == 1, cluster(cluster_c)
		  
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0
	estadd scalar ysumm	= `r(mean)'
	estadd local samp = "Phase 1"
	
	estadd joint REV_sel REVPLS_sel CFW_sel : `yvar'1_B 
	estadd equivalence REV_sel REVPLS_sel CFW_sel: `yvar'1_B
	estadd eqavg REV_sel REVPLS_sel CFW_sel, prefix(rvm_): `yvar'1_B
	estadd eqavg CFW_sel REV_sel REVPLS_sel, prefix(ovs_): `yvar'1_B
	
	eststo `yvar'1 : combine_models2 `yvar'1_A `yvar'1_B, headings(A B)
		
}


** TeX OUTPUT ******************************************************************

# delimit ;
esttab tax_quality1 tax_satisfied1
	using "${TABLE_OUTPUT}/tex/input/nonrevenue_infocontrol_orderprobit_input.tex", 
	keep(_select_c_xw REV_sel_xw REVPLS_sel_xw CFW_sel_xw)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Quality" "Satisfaction") // Column headings
	
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Main Treatment}"
			"\emph{Panel B: Subtreatments}"
			
			//prefix is added before every eqlabel, and suffix after every exlabel. 
			//Span forces column to span across rows, and @span is the width of the table
			// \addlinespace[1mm] adds extra space before table row. 
			prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
		)
		
	//nonumbers // No column numbers
	
	stats(N2 samp2 ysumm2 rvm_eqavg2 ovs_eqavg2 equivalence2 joint2,
		labels(
			"N"
			"Sample"
			"Mean of control group"
			"Rev. vs. Multitasking p."
			"Objective vs. Subjective p."
			"Equality of Schemes"
			"Joint significance"
		)	
		fmt(
			"%12.0f" "a3" "%12.3f" "%12.3f" "%12.3f" "%12.3f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file nonrevenue_infocontrol_orderprobit

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table re-estimates columns 1 and 2 of Table 4 from the main text, using ordered probit regressions instead."
file write tablenote " See Notes to Table 4 for additional information."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
cap log close
