/*******************************************************************************
SECTION 9 NON-REVENUE OUTCOMES
Impacts on Satisfaction and Accuracy, by Reassessed Status

Treatment impacts on non-revenue outcomes in the Seciton 9 / Reassessed sample
based on data from the property survey

Kunal Mangal
July 10 2014

***********************************************************************************/

set more off
clear all

cap cd "${PAPER_ANALYSIS}"
do "Do Files/Paper/programs/all_programs.do"

********************************************************************************

set matsize 800

use "Coded Data/survey_coded_data.dta", clear

label var _impl_c_xw "Any treatment"
label var SEC9 "Re-assessed"
label var SEC9_impl_c_xw "Re-assessed * Treatment"

#delimit ;
local vars
	tax_quality
	tax_satisfied
	;
#delimit cr
	
foreach yvar of varlist `vars' {

	* Regress
	eststo `yvar' : ivreg `yvar' (SEC9_impl_c_xw = SEC9_select_c_xw) SEC9 short_dummy circlefe* if phase == 1, ///
	    cluster(cluster_c)
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar meany = `r(mean)'

	estadd local samp = "Phase 1"
	
}

foreach yvar of varlist diff_GARV diff_pct_GARV {

	* Regress
	eststo `yvar' : ivreg `yvar' (SEC9_impl_c_xw = SEC9_select_c_xw) SEC9 short_dummy circlefe*, ///
	    cluster(cluster_c)
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar meany = `r(mean)'

	estadd local samp = "Full"
	
}

# delimit ;
esttab `vars' diff_GARV diff_pct_GARV
	using "${TABLE_OUTPUT}/tex/input/sec9_nonrevenue_infocontrol_input.tex",
	keep(SEC9_impl_c_xw SEC9)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Quality"
	"Satisfaction" 
	"Inaccuracy"
	"Tax Gap"
	)
		
	stats(N samp meany,
		labels(
			"N" "Sample" "Mean of control group in gen. pop. sample"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)

	label // Use Variable Labels
	
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file sec9_nonrevenue_infocontrol

/*
** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Circle-level 2SLS regressions. Specification follows Equation 5.6 of the main text,"
file write tablenote " and controls for whether the response came from the short version of the survey."
file write tablenote " Columns (1) and (2) restrict the sample to Phase 1."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
