/*******************************************************************************
2014 PAPER TABLES - SUPERVISORY OUTCOMES

Kunal Mangal
April 23 2014
SUMMARY: 
OUTLINE:

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************


* RI P values
insheet using "${RI_OUTPUT}\Revenue_Supervisors_RI.csv", comma clear
keep if v1 == "" // standard errors on blank rows
drop v1
keep v5
destring v5, ignore("[]") replace

mkmat v5 , matrix(RI_se)

matrix RIse1 = RI_se[1,1], 0, 0, RI_se[2,1], 0, 0, RI_se[3,1], 0, 0


insheet using "${RI_OUTPUT}\Supervisor_Interactions_t_RI.txt", clear
keep if v1 == "" // standard errors on blank rows
keep in 3/6
keep v5
destring v5, ignore("()") replace
mkmat v5 , matrix(RI_se)

matrix RIse2 = RI_se[1,1], RI_se[2,1], RI_se[3,1], 0, 0, 0, 0, 0, 0


insheet using "${RI_OUTPUT}\Supervisor_Interactions_c_RI.txt", clear
keep if v1 == "" // standard errors on blank rows
keep in 3/6
keep v5
destring v5, ignore("()") replace
mkmat v5 , matrix(RI_se)

matrix RIse2[1,4] = RI_se[1,1]
matrix RIse2[1,5] = RI_se[2,1]
matrix RIse2[1,6] = RI_se[3,1]

insheet using "${RI_OUTPUT}\Supervisor_Interactions_a_RI.txt", clear
keep if v1 == "" // standard errors on blank rows
keep in 3/6
keep v5
destring v5, ignore("()") replace
mkmat v5 , matrix(RI_se)

matrix RIse2[1,7] = RI_se[1,1]
matrix RIse2[1,8] = RI_se[2,1]
matrix RIse2[1,9] = RI_se[3,1]

matrix colnames RIse1 = _impl_s_t _impl_c_t _impl_cs_t _impl_s_c _impl_c_c _impl_cs_c _impl_s_a _impl_c_a _impl_cs_a
matrix colnames RIse2 = _impl_s_t _impl_c_t _impl_cs_t _impl_s_c _impl_c_c _impl_cs_c _impl_s_a _impl_c_a _impl_cs_a

 
use "Coded Data/Phase III Analysis Data.dta", clear
keep if fyear == 2013
keep if qtr == 4

label var _impl_c "Circle treatment"
label var _impl_s "Supervisory treatment"

label var REV_impl "Revenue"
label var REVPLS_impl "Revenue Plus"
label var CFW_impl "Flexible Bonus"
label var INFO_impl "Information"

gen _select_cs = _select_c * _select_s
gen _impl_cs = _impl_c * _impl_s

label var _impl_cs "Circle Treatment * Supervisory Treatment"

forv z = 1/3 {
	local x : word `z' of t c a
	
	gen _impl_s_`x' = _impl_s
	label var _impl_s_`x' "Supervisory treatment"

	* Regress - Main Treatment - Panel A
	eststo main1_`x' : ///
	  ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' (_impl_s_`x' = _select_s) ///
		stratdum_s*, cluster(ETO_clus)
			
}
	
eststo main1 : combine_models2 main1_t main1_c main1_a, headings(A B C)
estadd matrix RIse = RIse1


forv z = 1/3 {
	local x : word `z' of t c a
	
	gen _impl_cs_`x' = _impl_cs
	label var _impl_cs_`x' "Circle Treatment * Supervisory Treatment"
	
	gen _impl_c_`x' = _impl_c
	label var _impl_c_`x' "Circle treatment"
	
	* Regress - Main Treatment - Panel A
	eststo main2_`x' : ///
	  ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' (_impl_cs_`x' _impl_s_`x' _impl_c_`x' = _select_cs _select_s _select_c) ///
		divdum*, cluster(ETO_clus)
}
	
eststo main2 : combine_models2 main2_t main2_c main2_a, headings(A B C)
		
estadd matrix RIse = RIse2


# delimit ;
esttab main1 main2
	using "${TABLE_OUTPUT}\tex\input\supervisory_infocontrol_input.tex", 
	keep(_impl_s_t _impl_c_t _impl_cs_t _impl_s_c _impl_c_c _impl_cs_c _impl_s_a _impl_c_a _impl_cs_a)
	order(_impl_s_t _impl_c_t _impl_cs_t _impl_s_c _impl_c_c _impl_cs_c _impl_s_a _impl_c_a _impl_cs_a)
	
	cells(b(fmt(3) star pval(RIse)) RIse(par([ ])))
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	nomtitles
	
	eqlabels(
		//Embed latex code into the labels (emphasis)
		"\emph{Panel A: Total Revenue}"
		"\emph{Panel B: Current Revenue}"
		"\emph{Panel C: Arrears Revenue}"
		//prefix is added before every eqlabel, and suffix after every exlabel. 
		//Span forces column to span across rows, and @span is the width of the table
		// \addlinespace[1mm] adds extra space before table row. 
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
		
	//nonumbers // No column numbers
	
	stats(N3,
		labels(
			"N"
		)	
		fmt(
			"%12.0f"
		)
	)
	
	label // Use Variable Labels
	
	booktabs // a nicer version of tables
	substitute("                    &      b/RIse   &      b/RIse   \\" "")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

local file supervisory_infocontrol

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Circle-level 2SLS regressions of log total revenue collection on the interaction between circle and supervisory treatments."
file write tablenote " The different panels separate the margins of collection."
file write tablenote " Outcomes are shown as of the end of FY 2013. Controls include division fixed effects and baseline values."
file write tablenote " Supervisory treatment is defined as the fraction of treated staff in a circle,"
file write tablenote " instrumented by the original randomization result."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Randomized inference based p-values in brackets."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
