set more off
clear all

* Kunal Directory
cap cd "C:/Users/Kunal/Dropbox/Pakistan Property Tax Project Analysis"
cap cd "C:/Users/kmangal/Dropbox/Pakistan Property Tax Project Analysis"

* Wayne Directory
cap cd "C:/Users/Wayne/Dropbox/Olken/Pakistan Property Tax Project/Analysis"
cap cd "C:/Users/wsandhol/Dropbox/Olken/Pakistan Property Tax Project/Analysis"

cap cd "${PAKTAX_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

********************************************************************************

set matsize 800

use "Data/Cleaned Data/Field Survey/Round 3/all_noid_data_clean_2014.dta", clear

qui tab circle_id, generate(circles)

// Make Sec 9 Interactions
foreach var of varlist _select_c_xw _impl_c_xw  {
	gen SEC9`var' = SEC9 * `var'
}

label var SEC9 "Reassess"			
label var SEC9_impl_c_xw "Reassess * Treatment"

gen short_dummy = source == "short"
 
#delimit ;
local vars
	GARV
	floors
	last_renovation2
	land_area
	tot_cov_area
	main_road
	category_scale
	pctrent
	tax_liability
	;
#delimit cr

gen residential = SEC7_q4 == 1
gen commercial = SEC7_q4 == 2
gen both = SEC7_q4 == 3

foreach yvar of varlist `vars' {
		
	* Regress
	eststo `yvar'_A : ivreg `yvar' (SEC9_impl_c_xw = SEC9_select_c_xw) SEC9 short_dummy circles* if residential == 1, ///
	    cluster(cluster_c)
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar meany = `r(mean)'
	
	eststo `yvar'_B : ivreg `yvar' (SEC9_impl_c_xw = SEC9_select_c_xw) SEC9 short_dummy circles* if commercial == 1, ///
	    cluster(cluster_c)
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar meany = `r(mean)'
	
	eststo `yvar'_C : ivreg `yvar' (SEC9_impl_c_xw = SEC9_select_c_xw) SEC9 short_dummy circles* if both == 1, ///
	    cluster(cluster_c)
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar meany = `r(mean)'
	
	eststo `yvar' : combine_models2 `yvar'_A `yvar'_B `yvar'_C, headings(A B C)
		
}


# delimit ;
esttab `vars'
	using "Tables\tex\input\who_reassess_property_infocontrol_input.tex",
	keep(SEC9_impl_c_xw SEC9)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{GARV}"
		"\specialcell{Number of \\ floors}"
		"\specialcell{Last \\ renovation \\ was $\leq$ 2 \\ years ago}"
		"\specialcell{Land area \\ (sq. feet)}"
		"\specialcell{Total \\ covered area, \\ all uses}"
		"\specialcell{Main \\ Road}"
		"\specialcell{Category}"
		"\specialcell{Percent of \\ property \\ rented}"
		"\specialcell{Tax \\ Liability}"
		) // Column headings
	
	mgroups(" " "Components of GARV" "",
		pattern(1 0 0 1 0 0 0 0 1)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)
	
	nonumbers // No column numbers
	
	stats(N1 N2 N3 meany1 meany2 meany3,
		labels(
			"N - Residential" "N - Commercial" "N - Mixed" 
			"Mean of control group in random sample - R" 
			"Mean of control group in random sample - C" 
			"Mean of control group in random sample - M"
		)	
		fmt(
			"%12.0f" "%12.0f" "%12.0f" "%12.3f" "%12.3f" "%12.3f"
		)
	)
	
	eqlabels(
		//Embed latex code into the labels (emphasis)
		"\emph{Panel A: Residential Properties}"
		"\emph{Panel B: Commercial Properties}"
		"\emph{Panel C: Mixed Properties}"
		//prefix is added before every eqlabel, and suffix after every exlabel. 
		//Span forces column to span across rows, and @span is the width of the table
		// \addlinespace[1mm] adds extra space before table row. 
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
	
	label // Use Variable Labels
	
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr

eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

local file who_reassess_property_infocontrol

** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "Property-level 2SLS regressions. Panels separate samples by property type, which reflects the surveyor's"
file write tablenote " independent assessment and not necessarily what the respondent said."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "Tables/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "Tables/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
****************************************
