/*******************************************************************************
WHO PAYS MORE - MAIN - DROP RENTERS

Kunal Mangal
22 April 2014

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Coded Data/survey_coded_data.dta", clear

label var _impl_c_xw "Treatment"
label var SEC9_impl_c_xw "Re-assessed * Treatment"
label var SEC9 "Re-assessed"

drop if owned == 2 // DROP RENTERS

** REGRESSIONS *****************************************************************

// Objective Outcome
foreach yvar of varlist tax_last_payment {
			
	* Regress - Random Sample - Panel A
	eststo `yvar'_A : ///
	  ivreg `yvar' (_impl_c_xw =_select_c_xw) short_dummy phase2 stratdum_c* tax_last_payment_1011 ///
	    if SEC9 == 0, cluster(cluster_c)
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'

	
	* Regress - Re-assessed - Panel B
	eststo `yvar'_B : ///
	  ivreg `yvar' (SEC9_impl_c_xw = SEC9_select_c_xw) SEC9 short_dummy ///
	    circlefe*, cluster(cluster_c)
		
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	
	estadd local samp = "Full"
	
}

// Subjective Outcomes
foreach yvar of varlist tax_payment_total tax_times_payment tax_corruption  {
			
	* Regress - Random Sample - Panel A
	eststo `yvar'_A : ///
	  ivreg `yvar' (_impl_c_xw =_select_c_xw) short_dummy stratdum_c* ///
	    if SEC9 == 0 & phase == 1, cluster(cluster_c)
		
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	
	* Regress - Re-assessed - Panel B
	eststo `yvar'_B : ///
	  ivreg `yvar' (SEC9_impl_c_xw = SEC9_select_c_xw) SEC9 short_dummy ///
	    circlefe* if phase == 1, cluster(cluster_c)

	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)' 
	
	estadd local samp = "Phase 1"
			
}


** TeX OUTPUT - RANDOM SAMPLE **************************************************

# delimit ;
esttab tax_last_payment_A tax_payment_total_A tax_times_payment_A 
  tax_corruption_A 
	using "${TABLE_OUTPUT}/tex/input/who_pays_more_main_infocontrol_droprenter_input.tex" , 
	keep(_impl_c_xw)
	
	b(%6.0g)
	se(%6.0g)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("\specialcell{Self- \\ reported \\ Tax \\ Payment}"
	  "\specialcell{Bribe \\ Payment}"
	  "\specialcell{Frequency \\ of Bribe \\ Payment}"
	  "\specialcell{Perception \\ of \\ Corruption}") // Column headings

	refcat(
	  _impl_c_xw "\emph{Panel A: General Population Sample Only}", nolabel
	)
	stats(N ysumm,
	  labels("N" "Mean of control group")
	  fmt("%12.0f" "%12.3f")
	)
	//nonumbers // No column numbers
	label // Use Variable Labels	
	nonotes
	booktabs // a nicer version of tables
	fragment
	replace
	;
# delimit cr
	
** TeX OUTPUT - RE-ASSESSED PROPERTIES *****************************************
	
# delimit ;	
esttab tax_last_payment_B tax_payment_total_B tax_times_payment_B 
  tax_corruption_B 
	using "${TABLE_OUTPUT}/tex/input/who_pays_more_main_infocontrol_droprenter_input.tex" , 
	keep(SEC9_impl_c_xw SEC9)
	
	b(%6.0g)
	se(%6.0g)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	refcat(
		SEC9_impl_c_xw "\emph{Panel B: Re-assessed and General Population Sample}", nolabel
	)
	stats(N samp ysumm,
	  labels("N" "Sample" "Mean of control group in gen. pop. sample")
	  fmt("%12.0f" "a3" "%12.3f")
	)
	nomtitles // No model numbers	
	nonumbers // No column numbers
	label // Use Variable Labels
	nonotes
	booktabs // a nicer version of tables
	fragment
	append
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file who_pays_more_main_infocontrol_droprenter

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table re-estimates Table 6 from the main text, dropping rental properties. See Notes to Table 6 for additional information."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"
file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
cap log close
