/*******************************************************************************
WHO PAYS MORE - SUBS
Impacts on Tax Payments and Corruption, by Subtreatment

Wayne Aaron Sandholtz
24 January 2014

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Coded Data/survey_coded_data.dta", clear

label var _impl_c_xw "Any treatment"
label var REV_impl_xw "Revenue"
label var REVPLS_impl_xw "Revenue Plus"
label var CFW_impl_xw "Flexible Bonus"
label var SEC9 "Re-assessed"
label var SEC9_impl_c_xw "Re-assessed * Treatment"
label var SEC9REV_impl_xw "Re-assessed * Revenue"
label var SEC9REVPLS_impl_xw "Re-assessed * Revenue Plus"
label var SEC9CFW_impl_xw "Re-assessed * Flexible Bonus"

// Objective outcomes - tax payment
foreach yvar of varlist tax_last_payment {
			
	* Revenue
	eststo `yvar'_A : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw = ///
	    REV_sel_xw REVPLS_sel_xw CFW_sel_xw) tax_last_payment_1011 phase2 short_dummy stratdum_c* ///
	    if SEC9 == 0, cluster(cluster_c)
	estadd ysumm : `yvar'_A
	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'_A
	estadd equivalence REV_impl REVPLS_impl CFW_impl : `yvar'_A
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_) : `yvar'_A
		// revenue vs. multitasking (rev+, cfw)
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_)  : `yvar'_A
		// subjective (CFW) vs. objective (Rev, Rev+)

	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
				
	eststo `yvar'_B : ///
	  ivreg `yvar' (SEC9REV_impl_xw SEC9REVPLS_impl_xw SEC9CFW_impl_xw = ///
	    SEC9REV_sel_xw SEC9REVPLS_sel_xw SEC9CFW_sel_xw) SEC9 short_dummy ///
	    circlefe*, cluster(cluster_c)
	estadd ysumm : `yvar'_B
	estadd joint SEC9REV_impl SEC9REVPLS_impl SEC9CFW_impl : `yvar'_B
	estadd equivalence SEC9REV_impl SEC9REVPLS_impl SEC9CFW_impl : `yvar'_B
	estadd eqavg SEC9REV_impl SEC9REVPLS_impl SEC9CFW_impl, prefix(rvm_) : `yvar'_B
		// revenue vs. multitasking (rev+, cfw)
	estadd eqavg SEC9CFW_impl SEC9REV_impl SEC9REVPLS_impl, prefix(ovs_)  : `yvar'_B
		// subjective (CFW) vs. objective (Rev, Rev+)

	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	
	estadd local samp = "Full"
			
}

foreach yvar of varlist tax_payment_total ///
  tax_times_payment tax_corruption {
			
	* Revenue
	eststo `yvar'_A : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw = ///
	    REV_sel_xw REVPLS_sel_xw CFW_sel_xw) short_dummy stratdum_c* ///
	    if SEC9 == 0 & phase == 1, cluster(cluster_c)
	estadd ysumm : `yvar'_A
	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'_A
	estadd equivalence REV_impl REVPLS_impl CFW_impl : `yvar'_A
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_) : `yvar'_A
		// revenue vs. multitasking (rev+, cfw)
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_)  : `yvar'_A
		// subjective (CFW) vs. objective (Rev, Rev+)

	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	
	eststo `yvar'_B : ///
	  ivreg `yvar' (SEC9REV_impl_xw SEC9REVPLS_impl_xw SEC9CFW_impl_xw = ///
	    SEC9REV_sel_xw SEC9REVPLS_sel_xw SEC9CFW_sel_xw) SEC9 short_dummy ///
	    circlefe* if phase == 1, cluster(cluster_c)
	estadd ysumm : `yvar'_B
	estadd joint SEC9REV_impl SEC9REVPLS_impl SEC9CFW_impl : `yvar'_B
	estadd equivalence SEC9REV_impl SEC9REVPLS_impl SEC9CFW_impl : `yvar'_B
	estadd eqavg SEC9REV_impl SEC9REVPLS_impl SEC9CFW_impl, prefix(rvm_) : `yvar'_B
		// revenue vs. multitasking (rev+, cfw)
	estadd eqavg SEC9CFW_impl SEC9REV_impl SEC9REVPLS_impl, prefix(ovs_)  : `yvar'_B
		// subjective (CFW) vs. objective (Rev, Rev+)
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	
	estadd local samp = "Phase 1"
			
}

** TeX OUTPUT - RANDOM SAMPLE **************************************************
# delimit ;
esttab tax_last_payment_A tax_payment_total_A tax_times_payment_A 
  tax_corruption_A
	using "${TABLE_OUTPUT}/tex/input/who_pays_more_subs_infocontrol_input.tex" , 
	keep(REV_impl_xw REVPLS_impl_xw CFW_impl_xw)
	
	b(%12.3g)
	se(%12.3g)
		
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("\specialcell{Self- \\ reported \\ Tax \\ Payment}"
	  "\specialcell{Bribe \\ Payment}"
	  "\specialcell{Frequency \\ of Bribe \\ Payment}"
	  "\specialcell{Perception \\ of \\ Corruption}") // Column headings

	refcat(
	  REV_impl_xw "\emph{Panel A: General Population Sample Only}", nolabel
	)
	
	stats(N ysumm rvm_eqavg ovs_eqavg equivalence joint, 
	  labels("N" 
			"Mean of control group" 
			"Rev. vs. Multitasking p."
			"Objective vs. Subjective p."
			"Equality of Schemes"
			"Joint significance"
	  )
	  fmt(
			"%12.0f" "%12.1f" "%12.3f" "%12.3f" "%12.3f" "%12.3f"
		)
	)
	nonumbers // No column numbers
	label // Use Variable Labels
	nonotes	  
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr

** TeX OUTPUT - RANDOM SAMPLE **************************************************
# delimit ;
esttab tax_last_payment_B tax_payment_total_B tax_times_payment_B 
  tax_corruption_B
	using "${TABLE_OUTPUT}/tex/input/who_pays_more_subs_infocontrol_input.tex" , 
	keep(SEC9REV_impl_xw SEC9REVPLS_impl_xw SEC9CFW_impl_xw SEC9)
	
	b(%12.3g)
	se(%12.3g)
		
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	nomtitles
	
	refcat(
	  SEC9REV_impl_xw "\emph{Panel B: Re-assessed and General Population Sample}", nolabel
	)
	
	stats(N samp ysumm rvm_eqavg ovs_eqavg equivalence joint, 
	  labels("N" 
			"Sample"
			"Mean of control group in gen. pop. sample" 
			"Rev. vs. Multitasking p."
			"Objective vs. Subjective p."
			"Equality of Schemes"
			"Joint significance"
	  )
	  fmt(
			"%12.0f" "a3" "%12.1f" "%12.3f" "%12.3f" "%12.3f"
		)
	)
	
	nonumbers // No column numbers	
	label // Use Variable Labels
	nonotes	  
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	append
	;

# delimit cr

eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file who_pays_more_subs_infocontrol

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table re-estimates Table 6 from the main text, estimating impacts separately by subtreatment. See Notes to Table 6 for additional information."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
  
cap log close
exit
