/*******************************************************************************
2014 PAPER TABLES - MARGINS - SUBTREATMENTS
\\Pakistan Property Tax Project\Analysis\Do Files\Regressions\Phase III\Analysis\
	2014_paper\XXXXXX_margins_subs.do
Kunal Mangal
April 8 2014
SUMMARY: 
OUTLINE:
NOTES:  This file should produce each table in LaTeX, .csv, .rtf, and .txt.

*******************************************************************************/
version 12
clear all
set more off

cap cd "C:\Users\kmangal\Dropbox\Pakistan Property Tax Project Analysis/"
cap cd "C:\Users\Kunal\Dropbox\Pakistan Property Tax Project Analysis/"

cap cd "${PAKTAX_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Data/Coded Data/Phase III Analysis Data.dta", clear

forv z = 1/3 {
	local x : word `z' of t c a
	
	label var ln_gross_dem_`x' "Gross Demand"
	label var ln_nonexemptrate_`x' "Non-exemption Rate"
	label var ln_net_dem_`x' "Net Demand"
	label var ln_recoveryrate_`x' "Recovery Rate"
	label var ln_recov_tot_`x' "Revenue"
}

label var REV_impl "Revenue"
label var REVPLS_impl "Revenue Plus"
label var CFW_impl "Flexible Bonus"
label var INFO_impl "Information"

forv y = 1/2 {

	local year : word `y' of 2012 2013
	local phase : word `y' of II III
	
	forv z = 1/4 {
	
		local yvar : word `z' of ln_recov_tot_ ln_gross_dem_ ln_nonexemptrate_ ln_recoveryrate_ 
		local w : word `z' of Recovery GrossDemand NonExempt RecoveryRate
		
		if `y' == 2 {
			local a = "INFO_impl"
			local b = "INFO_sel"
		}
		else {
			local a = ""
			local b = ""
		}
		
		foreach x in t c a {
		
			* Regress
			eststo `x' : ivreg `yvar'`x' base_ln_gross_dem_`x' base_ln_net_dem_`x' base_ln_recov_tot_`x' ///
				(REV_impl REVPLS_impl CFW_impl `a' = REV_sel REVPLS_sel  ///
				CFW_sel `b') stratdum_c* if qtr== 4 & fyear==`year', cluster(cluster_c)
			qui sum `yvar'`x' if e(sample) == 1 & subtreatment == . & INFO_sel == 0
			estadd scalar ymean = `r(mean)'
		}
		
		eststo `phase'_`w' : combine_models2 t c a, headings(A B C)
		
	}
}

** TeX OUTPUT ******************************************************************
# delimit ;
esttab II_Recovery II_GrossDemand II_NonExempt II_RecoveryRate III_Recovery 
  III_GrossDemand III_NonExempt III_RecoveryRate
	using "Tables\tex/input/margins_subs_infoout_input.tex" , 
	keep(REV_impl REVPLS_impl CFW_impl INFO_impl)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
	  "Revenue"
	  "Tax Base"
	  "\specialcell{Non- \\ Exemption \\ Rate}"
	  "\specialcell{Recovery \\ Rate}"
	  "Revenue"
	  "Tax Base"
	  "\specialcell{Non- \\ Exemption \\ Rate}"
	  "\specialcell{Recovery \\ Rate}"
	) // Column headings
	
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Total}"
			"\emph{Panel B: Current}"
			"\emph{Panel C: Arrears}"
			
			//prefix is added before every eqlabel, and suffix after every exlabel. 
			//Span forces column to span across rows, and @span is the width of the table
			// \addlinespace[1mm] adds extra space before table row. 
			prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
		)
			
	mgroups("Year 1" "Year 2", pattern(1 0 0 0 1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))

	stats(
		N1	ymean1,
		  labels("N (Total)" "Mean of control group (Total)")	
		fmt("%12.0f" "%12.3f")
	)
	
	label // Use Variable Labels
	
	nonotes
	  
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

local file margins_subs_infoout

** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "Table decomposes the treatment effect on revenue collection (Columns 1, 5)"
file write tablenote " into the effect on three components: 1) changes in the Tax Base (Columns 2, 6);"
file write tablenote " 2) changes in the Non-Exemption Rate (Columns 3, 7); and 3) changes in the Recovery Rate"
file write tablenote " (Columns 4, 8). Rows estimate impacts separately for subtreatments. Panels separate relevant margins of collection."
file write tablenote " Controls include baseline tax base, non-exemption rate, and recovery rate values. Outcome variables"
file write tablenote " and controls in logs. All values are crosswalked to randomization circles. Specification includes stratum fixed effects."
file write tablenote " N and means of control group shown for total collections only."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "Tables/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "Tables/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
