/*******************************************************************************
INSPECTOR EFFORT

Impact of supervisory treatments on self-reported inspector effort form
the Inspector phone survey

Kunal Mangal
18 April 2014

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"
do "Do Files/Paper/programs/all_programs.do"

** USE DATA
u "${DATA}/Cleaned Data/Inspector Survey/Inspector Survey Clean.dta", clear
	// from "Do Files\Cleaning\Third Party Survey\131007 Inspector Survey Cleaning.do"

merge 1:1 circle_id using "Coded Data/Inspector Supervisory Treatment Variables"
list circle_id if _merge == 1, clean
count if _merge == 1
keep if _m == 3
drop _m

merge 1:1 circle_id using "Coded Data/Inspector Treatment Variables"
list circle_id if _merge == 1, clean
count if _merge == 1
keep if _m == 3
drop _m

** MAIN EFFECT *****************************************************************

#delimit ;
local variables
	pressure_scale
	monit_scale
	;
#delimit cr

gen _impl_cs = _impl_c_xw * _impl_s
gen _select_cs = _select_c_xw * _select_s_xw

label var _impl_s "Supervisory Treatment"
label var _impl_c_xw "Circle Treatment"
label var _impl_cs "Supervisory * Circle Treatment"

tab division_id, generate(divdum)

foreach var in `variables' {
	** Estout - TeX
	eststo `var'_A: ///
	  ivreg `var' (_impl_s = _select_s_xw) stratdum_s*, cl(ETO_clus)
	 
	qui sum `var' if _select_s_xw == 0
	estadd scalar ymean = `r(mean)'

	eststo `var'_B: ///
	  ivreg `var' (_impl_cs _impl_c_xw _impl_s = _select_cs _select_c_xw _select_s_xw) divdum*, cl(ETO_clus)

	qui sum `var' if _select_s_xw == 0 & _select_c_xw == 0
	estadd scalar ymean = `r(mean)'
	
	eststo `var' : combine_models2 `var'_A `var'_B, headings(A B)

}


** TeX OUTPUT ******************************************************************
# delimit ;
esttab pressure_scale_A monit_scale_A
	using "${TABLE_OUTPUT}/tex/input/inspector_effort_supervisors_input.tex", 
	keep(_impl_s)
	
	b(%12.3g)
	se(%12.3g)
		
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
	"\specialcell{Pressure from \\ supervisors}"
	"\specialcell{Level of \\ monitoring}"
	  ) // Column headings
		
	/*
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Main Treatment}"
			"\emph{Panel B: Interaction Effects}"

			// //prefix is added before every eqlabel, and suffix after every eqlabel. 
			// //Span forces column to span across rows, and @span is the width of the table
			 \addlinespace[1mm] adds extra space before table row. 
			 prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
		)
	*/
	
	stats(N ymean, 
	  labels("N" "Mean of supervisory control group")
	)
	// varwidth(45) wrap // this wraps cells automatically -- doesn't work well
	// width(1.0\hsize) // this makes the table fill the page.
		
	label // Use Variable Labels
	
	nonotes
	  
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear
	
******************************************************************

set more off
local file inspector_effort_supervisors


** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table presents effects on inspector effort due to the supervsiory treatment. Instrumental variables regressions, where treatment status is instrumented with randomization results."
file write tablenote " The unit of observation is a circle, as defined at the end of Year 2."
file write tablenote " Pressure from supervisors was assessed on a 5-point Likert scale. Level of monitoring was assessed on a 4 point scale."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by ETO,"
file write tablenote " i.e. the group of circles under the ETO's charge."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

cap log close
