/*******************************************************************************
INSPECTOR KNOWLEDGE OF TREATMENTS

Tabulation of the treatment that inspectors thought they were in vs. the treatments
they were actually in.

22 July 2014
Kunal Mangal

*******************************************************************************/

version 12
clear all
pr drop _all
cap log close
set more off

cap cd "${PAPER_ANALYSIS}"
do "Do Files/Paper/programs/all_programs.do"

*******************************************************************************/

u "${DATA}/Cleaned Data/Inspector Survey/Inspector Survey Clean.dta", clear
	// from "Do Files\Cleaning\Third Party Survey\131007 Inspector Survey Cleaning.do"

gen control_s_dummy = rev_s_dummy != 1 & revplus_s_dummy != 1 & cfw_s_dummy != 1 & info_s_dummy != 1

* variables we care about.
#delimit ;
local vars
	rev_s_dummy
	revplus_s_dummy
	cfw_s_dummy
	info_s_dummy
	control_s_dummy
	;
#delimit cr

keep if status == 1

collapse (mean) rev_s_dummy revplus_s_dummy cfw_s_dummy info_s_dummy control_s_dummy (count) circle_id, by(subtreatment)

gen treatment = 1 if subtreatment == "Revenue"
replace treatment = 2 if subtreatment == "Revenue PLUS"
replace treatment = 3 if subtreatment == "Cond. Fixed Wage"
replace treatment = 4 if subtreatment == "Information"
replace treatment = 5 if subtreatment == ""

label def treatment 1 "   Revenue" 2 "   Revenue Plus" 3 "   Flexible Bonus" 4 "   Information" 5 "   Control"
label values treatment treatment

drop subtreatment 
order treatment, first
sort treatment

lab var rev_s_dummy "Revenue"
lab var revplus_s_dummy "Revenue Plus"
lab var cfw_s_dummy "Flexible Bonus"
lab var info_s_dummy "Information"

ren circle_id NumObs
label var NumObs "   N"

estpost tabstat rev_s_dummy revplus_s_dummy cfw_s_dummy info_s_dummy control_s_dummy NumObs, by(treatment) nototal
esttab using "${TABLE_OUTPUT}/tex/input/inspector_knowledge_input.tex",  ///
	cells("rev_s_dummy(fmt(%12.2f)) revplus_s_dummy(fmt(%12.2f)) cfw_s_dummy(fmt(%12.2f)) info_s_dummy(fmt(%12.2f)) control_s_dummy(fmt(%12.2f)) NumObs(fmt(%12.0f))")  ///
	style(tex) booktabs label compress ///
	noobs nonum nonote ///
	collabels("\specialcell{Revenue}" "\specialcell{Revenue Plus}" "\specialcell{Flexible Bonus}" "\specialcell{Information}" "Control" "N", lhs("\emph{Perceived Treatment}")) ///
	substitute("\midrule" "\midrule \emph{Actual Treatment} \\") fragment replace


* WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file inspector_knowledge

/*
** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Tabulation of inspector's understanding of their own treatment status."
file write tablenote " Rows list inspector's actual treatment status."
file write tablenote " Columns list inspector's perceived treatment status."
file write tablenote " Cells list the fraction of inspectors in the treatment given by the row"
file write tablenote " who believe themselves to be in the treatment specified in the column."
file write tablenote " Revenue N = 51, Revenue Plus N = 54, Flexible Bonus N = 56, Information N = 50, Control N = 159."

file close tablenote 
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")
  
compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
	
