*! Version 1 10feb2014 Wayne Aaron Sandholtz
/*
SUMMARY:
	Give compiletex the name `name' of a .tex file (optionally preceded by
	the path which describes its location relative to Stata's working
	directory),	and compiletex will call pdflatex from the shell to create a
	file called `name'.pdf.
  
OPTIONS:
	AUXdir tells compiletex where to create the auxiliary files, relative to the
	  directory which contains the .tex file being compiled.  The default is
	  the same directory as the .tex file.
	
	OUTdir tells compiletex where to create the output pdf, relative to the
	  directory which contains the .tex file being compiled.  The default is
	  the same directory as the .tex file. 
 */

********************************************************************************

cap pr drop compiletex
pr define compiletex, rclass
	version 12
	
	syntax anything [, OUTdir(string) AUXdir(string)]
	
	local cmdline `"`0'"'

	** Find the number of \/-separated elements of the user input
	tokenize `"`1'"', parse("/\")
	local tokenlen = 0
	local i = 1
	while `tokenlen' == 0{
		if "``i''" == "" local tokenlen = `i' - 1
		local ++i
	}
	
	** Put together the path
	local mydir
	forv i = 1/`= `tokenlen' - 1'{
		if "``i''" == "\" local `i' = "/"
		local mydir `mydir'``i''
	}
	
	** Isolate the part of the user input that is just the filename (no path)
	local myfile = "``tokenlen''"
		
		
	** Take file extension off myfile if it's there
	gettoken myfile ext : myfile, parse(.)
		
		
	** COMPILE THE LaTeX DOCUMENT **************************************************
	** Take note of working directory
	local origdir "`c(pwd)'"
	
	** pdflatex seems to have less trouble when we just choose the directory
	** rather than try and feed it paths.  We'll choose it back to here later.
	qui cd "`mydir'"
	cap rm "`myfile'.pdf"

	**************detect OS and compile:
	*run pdflatex twice for hyperref
	if "`c(os)'" == "Windows"{
		!pdflatex  -aux-directory="`auxdir'" -output-directory="`outdir'" "`myfile'.tex" 
		!pdflatex  -aux-directory="`auxdir'" -output-directory="`outdir'" "`myfile'.tex" 
	}
	if "`c(os)'" == "MacOSX" {
		!/usr/texbin/pdflatex  -aux-directory="`auxdir'" -output-directory="`outdir'" "`myfile'.tex" 
		!/usr/texbin/pdflatex  -aux-directory="`auxdir'" -output-directory="`outdir'" "`myfile'.tex" 
	}
	*************

	** Return working directory to where it was when the user called compiletex
	qui cd "`origdir'"

	** Return list.
	return local cmdline `"`cmdline'"'
	return local myfile "`myfile'"
	return local mydir "`mydir'"
	return local outdir "`outdir'"
	return local auxdir "`auxdir'"
end
