/*******************************************************************************
RANDOMIZATION BALANCE
Balance check on Year 2 treatments

Kunal Mangal
April 21 2014

IMPORTANT NOTE: After running this file you will still need to make some manual
				edits in order to make the formatting in the final document
				look right, but the numbers will all be there, and in the proper place.
				Instructions at the bottom of the do file
				
*******************************************************************************/

version 12
clear all
set more off

pr drop _all
cap log close
set mem 300m

set trace off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

*******************************************************************

**********************************
* 1. Coding for Table Formatting
**********************************

cap program drop ri_se
program define ri_se, eclass

	syntax namelist

	foreach var of varlist _all {
		destring `var', ignore("[]") replace
	}

	keep treatment_c revenue revplus cfw information v9 treatment_s

	rename treatment_c treat_se_rip
	rename revenue rev_se_rip
	rename revplus revpls_se_rip
	rename cfw cfw_se_rip
	
	rename v9 treat_i_se_rip
	
	rename treatment_s treat_s_se_rip

	mkmat treat_se_rip rev_se_rip revpls_se_rip cfw_se_rip treat_i_se_rip treat_s_se_rip

	foreach matname in treat_se_rip rev_se_rip revpls_se_rip cfw_se_rip treat_i_se_rip treat_s_se_rip {
		mat `matname' = `matname''
		mat coln `matname' = `namelist'
		eret mat `matname' = `matname'
	}

end program

cap program drop balance_table
program define balance_table, eclass

	syntax varlist

	/* Main Treatment */
	tempname control_c treat treat_se treat_p rev rev_se rev_p revpls revpls_se revpls_p cfw cfw_se cfw_p info info_se info_p
	
	local i 0
	foreach var of local varlist {
		local ++i
		
		qui sum `var' if _select_c2==0
		mat `control_c' = nullmat(`control_c'), r(mean)
		
		qui reg `var' _select_c2all stratdum_c*, robust
		
		mat `treat' = nullmat(`treat'), _b[_select_c2all]'
		mat `treat_se' = nullmat(`treat_se'), _se[_select_c2all]'
		
		qui test _select_c2all
		mat `treat_p' = nullmat(`treat_p'), r(p)
		
		qui reg `var' _select_c2all stratdum_c*
		est sto treatreg`i'
	}
	
	suest treatreg*, robust cl(circle_id)

	local final = `i'

	test _b[treatreg1_mean: _select_c2all] = 0, notest
	forval j=2/`final' {
		qui test _b[treatreg`j'_mean: _select_c2all] = 0, accum
	}
	
	local treat_p_joint = `r(p)'
	mat `treat' = nullmat(`treat'), `treat_p_joint', RIp[1,1]
	
	local i 0
	foreach var of local varlist {
		local ++i
		
		qui reg `var' REV_sel2all REVPLS_sel2all CFW_sel2all stratdum_c*, robust
		est sto subreg`i'
		
		mat `rev' = nullmat(`rev'), _b[REV_sel2all]'
		mat `rev_se' = nullmat(`rev_se'), _se[REV_sel2all]'
		
		qui test REV_sel2all
		mat `rev_p' = nullmat(`rev_p'), r(p)
		
		mat `revpls' = nullmat(`revpls'), _b[REVPLS_sel2all]'
		mat `revpls_se' = nullmat(`revpls_se'), _se[REVPLS_sel2all]'
		
		qui test REVPLS_sel2all
		mat `revpls_p' = nullmat(`revpls_p'), r(p)

		mat `cfw' = nullmat(`cfw'), _b[CFW_sel2all]'
		mat `cfw_se' = nullmat(`cfw_se'), _se[CFW_sel2all]'
		
		qui test CFW_sel2all
		mat `cfw_p' = nullmat(`cfw_p'), r(p)
		
		qui reg `var' REV_sel2all REVPLS_sel2all CFW_sel2all stratdum_c*
		est sto subreg`i'
	}
	
	local final = `i'
	
	suest subreg*, robust cl(circle_id)
	
	foreach var in REV_sel2all REVPLS_sel2all CFW_sel2all {
		test _b[subreg1_mean: `var'] = 0, notest
		forval j=2/`final' {
			qui test _b[subreg`j'_mean: `var'] = 0, accum
		}
		local `var'_p_joint = `r(p)'
	}
	
	mat `rev' = nullmat(`rev'), `REV_sel2all_p_joint', RIp[1,2]
	mat `revpls' = nullmat(`revpls'), `REVPLS_sel2all_p_joint', RIp[1,3]
	mat `cfw' = nullmat(`cfw'), `CFW_sel2all_p_joint', RIp[1,4]
	
	/* Information Treatment */
	tempname control_i treat_i treat_i_se treat_i_p
	
	gen marker = _select_c2==0 | INFO_sel2 ==1

	local i 0
	foreach var of local varlist {
		local ++i
		
		qui sum `var' if _select_c2==0 & INFO_sel2==0
		mat `control_i' = nullmat(`control_i'), r(mean)
		
		qui reg `var' INFO_sel2 stratdum_c* if marker == 1, robust
		
		mat `treat_i' = nullmat(`treat_i'), _b[INFO_sel2]'
		mat `treat_i_se' = nullmat(`treat_i_se'), _se[INFO_sel2]'
		
		qui test INFO_sel2
		mat `treat_i_p' = nullmat(`treat_i_p'), r(p)
		
		qui reg `var' INFO_sel2 stratdum_c* if marker == 1
		est sto treatireg`i'		
	}
	
	suest treatireg*, robust cl(circle_id)

	local final = `i'

	test _b[treatireg1_mean: INFO_sel2] = 0, notest
	forval j=2/`final' {
		qui test _b[treatireg`j'_mean: INFO_sel2] = 0, accum
	}	
	
	local treat_p_joint = `r(p)'
	mat `treat_i' = nullmat(`treat_i'), `treat_p_joint', RIp[1,5]
	
	/* Supervisory Treatment */
	tempname control_s treat_s treat_s_se treat_s_p
	
	local i 0
	foreach var of local varlist {
		local ++i
		
		qui sum `var' if _select_s==0
		mat `control_s' = nullmat(`control_s'), r(mean)
		
		qui reg `var' _select_s stratdum_s*, robust cl(ETO_clus_rand)
			
		mat `treat_s' = nullmat(`treat_s'), _b[_select_s]'
		mat `treat_s_se' = nullmat(`treat_s_se'), _se[_select_s]'
		
		qui test _select_s
		mat `treat_s_p' = nullmat(`treat_s_p'), r(p)
		
		qui reg `var' _select_s stratdum_s*
		est sto treatsreg`i'
	}
	
	suest treatsreg*, robust cl(circle_id)

	local final = `i'

	test _b[treatsreg1_mean: _select_s] = 0, notest
	forval j=2/`final' {
		qui test _b[treatsreg`j'_mean: _select_s] = 0, accum
	}
	
	local treat_p_joint = `r(p)'
	mat `treat_s' = nullmat(`treat_s'), `treat_p_joint', RIp[1,7]
	
	foreach mat in control_c control_s control_i treat_se treat_p rev_se rev_p revpls_se revpls_p cfw_se cfw_p treat_i_se treat_i_p treat_s_se treat_s_p {
		mat coln ``mat'' = `varlist'
	}
	
	foreach mat in treat rev revpls cfw treat_s treat_i {
		mat coln ``mat'' = `varlist' pvaljoint pvalrijoint
	}
	
	tempname b V
	mat `b' = `control_c'*0
	mat `V' = `b''*`b'
	eret post `b' `V'
	eret local cmd "balance_table"
	
	foreach mat in control_c control_s control_i treat treat_se treat_p rev rev_se rev_p revpls revpls_se revpls_p cfw cfw_se cfw_p treat_s treat_s_se treat_s_p treat_i treat_i_se treat_i_p {
		eret mat `mat' = ``mat''
	}
	
	foreach mat in treat_se_rip rev_se_rip revpls_se_rip cfw_se_rip treat_i_se_rip treat_s_se_rip {
		eret mat `mat' = `mat'
	}
	
end program

* GET RI P VALUES, 1
insheet using "${RI_OUTPUT}/Randomization Balance Year 2_RI.csv", comma clear
keep if variables == ""
ri_se recov_tot_t recovrate nonexemptrate NumStaff PosFilled bench growthrate

foreach mat in treat_se_rip rev_se_rip revpls_se_rip cfw_se_rip treat_i_se_rip treat_s_se_rip {
	mat `mat' = e(`mat')
}
	
	
* GET RI P VALUES, 2
insheet using "${RI_OUTPUT}/Randomization Balance Year 2_RI.csv", comma clear
keep if variables == "P-Value"
foreach var of varlist _all {
	destring `var', ignore("[]") replace
}

keep treatment_c revenue revplus cfw information v9 treatment_s
mkmat treatment_c revenue revplus cfw information v9 treatment_s, matrix(RIp) 

* MAIN DATA
u "Coded Data/Phase III Analysis Data.dta", clear

* RECODE _SELECT VARIABLES FOR THIS PURPOSE: supervisors
foreach v of varlist _select_s ETO_clus_rand stratdum_s* {		// they're not selected in fy2012, but we want to use that data
	bys circle_id: egen temp = max(`v')
	replace `v' = temp
	drop temp
	}

* circles
drop *2all
g _select_c2all = _select_c1==1 | _select_c2==1		// we want _select_c2all to be all treated in year 2, not just year 2 circles!
g REV_sel2all = REV_sel1==1 | REV_sel2==1
g REVPLS_sel2all = REVPLS_sel1==1 | REVPLS_sel2==1
g CFW_sel2all = CFW_sel1==1 | CFW_sel2==1

* KEEP WHAT WE NEED
keep fyear qtr circle_id ETO_clus_rand _select_c1 _select_c2 *2all _select_s INFO_sel2 REV_sel? REVPLS_sel? CFW_sel? base_ln_recov_tot_t base_ln_nonexemptrate_t base_ln_recoveryrate_t base_ln_growthrate_t NumStaff PosFilled bench stratum_c stratum_s stratdum_c* stratdum_s*	// note that NumStaff and PosFilled are only defined at baseline
keep if fyear==2012 & qtr==4
replace bench = ln(bench)

* RENAME
ren base_ln_recov_tot_t recov_tot_t
ren base_ln_nonexemptrate_t nonexemptrate
ren base_ln_recoveryrate_t recovrate
ren base_ln_growthrate_t growthrate
	
label var recov_tot_t "\addlinespace Log Revenue"
label var recovrate "\addlinespace Log Recovery Rate"
label var nonexemptrate " \addlinespace Log Non-exemption Rate"
label var NumStaff "\addlinespace Number of staff posted"
label var PosFilled "\addlinespace All positions filled"
label var bench "\addlinespace Log benchmark"
label var growthrate "\addlinespace FY 10-11 log growth rate"

gen pvaljoint = .
label var pvaljoint "\midrule P-val, joint sig."

gen pvalrijoint = .
label var pvalrijoint "P-val, from RI"

balance_table recov_tot_t recovrate nonexemptrate NumStaff PosFilled bench growthrate


# delimit ;
local to_replace "                    &   control_c&treat/treat_se/treat_se_rip         &rev/rev_se/rev_se_rip         &revpls/revpls_se/revpls_se_rip         &cfw/cfw_se/cfw_se_rip         &   control_i&treat_i/treat_i_se/treat_i_se_rip         &   control_s&treat_s/treat_s_se/treat_s_se_rip         \\";
local replace_with "&\multicolumn{5}{c}{Main Treatment} & \multicolumn{2}{c}{Information Treatment}   & \multicolumn{2}{c}{Supervisory Treatment}\\\cmidrule(lr){2-6}\cmidrule(lr){7-8}\cmidrule(lr){9-10} &\multicolumn{1}{c}{Control} &\multicolumn{1}{c}{Treatment} &\multicolumn{1}{c}{Revenue} &\multicolumn{1}{c}{Revenue Plus} &\multicolumn{1}{c}{Flexible Bonus} &\multicolumn{1}{c}{Control} &\multicolumn{1}{c}{Treatment} &\multicolumn{1}{c}{Control} &\multicolumn{1}{c}{Treatment} \\";

esttab using "${TABLE_OUTPUT}/tex/input/randomization_balance_input.tex",  
	nonumbers
	label
	noobs
	nomtitles
	cells("control_c(fmt(a3)) treat(star pvalue(treat_p) fmt(%12.3f)) rev(star pvalue(rev_p) fmt(%12.3f)) revpls(star pvalue(revpls_p) fmt(%12.3f)) cfw(star pvalue(cfw_p) fmt(%12.3f)) control_i treat_i(star pvalue(treat_i_p) fmt(%12.3f)) control_s treat_s(star pvalue(treat_s_p) fmt(%12.3f))" ///
			". treat_se(par fmt(%12.3f)) rev_se(par fmt(%12.3f)) revpls_se(par fmt(%12.3f)) cfw_se(par fmt(%12.3f)) . treat_i_se(par fmt(%12.3f)) . treat_s_se(par fmt(%12.3f))" ///
			". treat_se_rip(par([ ])) rev_se_rip(par([ ])) revpls_se_rip(par([ ])) cfw_se_rip(par([ ])) . treat_i_se_rip(par([ ])) . treat_s_se_rip(par([ ]))")
substitute("`to_replace'" "`replace_with'")
fragment
replace
;
# delimit cr;



** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

** WAIT! NEED TO ADJUST FOOTER MANUALLY (DELETE EXTRA SPACE AROUND PVALUES)
** ALSO, STARS ARE NOT BEING ADDED, SO DO IT MANUALLY. TO ADD TO NON-EXEMPTION FOR FLEX BONUS
pause on
pause

pause off

set more off
local file randomization_balance

/*
** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Randomization balance test. Columns labeled Control reflect control group means."
file write tablenote " Values in the treatment columns are the coefficients of a regression of the baseline value of the variable"
file write tablenote " indicated in the row on a treatment dummy (or the set of subtreatments dummies), controlling for "
file write tablenote " the relevant randomization strata. In the Main Treatment tests, the Information treatment is included in the controls."
file write tablenote " In the Information Treatment tests, the Information treatment group is compared against pure controls."
file write tablenote " The Supervisory Treatment test compares without regard to Main Treatment or Information Treatment status."
file write tablenote " Robust standard errors in parentheses. Randomization inference (RI)"
file write tablenote " based p-values in brackets. RI statistics are based on 1000 re-randomization iterations."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01. Stars reflect randomization inference based p-values."

file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
****************************************


