***********************************
* SPILLOVERS
***********************************

clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

*********************************************

use "Coded Data/Inspector Treatment Variables", clear
keep circle_id

tempfile circlelist
save `circlelist'

insheet using "${DATA}/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep if missing(rand_circle_id)
keep q4_2013_circle_id 
duplicates drop
drop if missing(q4_2013_circle_id)

ren q4_2013_circle_id circle_id
gen near_circle_id = circle_id

tempfile todrop
save `todrop'

use "Coded Data/proximity.dta", clear

// Drop circles that weren't randomized
merge m:1 circle_id using `todrop'
keep if _merge == 1
drop _merge

merge m:1 near_circle_id using `todrop'
keep if _merge == 1
drop _merge

// Trick to deal with isolated circles
append using `circlelist', generate(extra)

// Merge in treatment - Circle IDs in terms of Q4 2013 (for the most part)
ren circle_id circle_id_temp
ren near_circle_id circle_id

merge m:1 circle_id using "Coded Data/Inspector Treatment Variables", keepusing(_select_c_xw _impl_c_xw)
drop if _merge == 2
drop _merge

ren circle_id near_circle_id
ren circle_id_temp circle_id

// Filter to neighbors within 1 km or loners
drop if near_dist > 1 & extra != 1

collapse (count) total_circles = near_circle_id (mean) avg_treat_sel = _select_c_xw avg_treat_impl = _impl_c_xw (sum) total_treat_sel = _select_c_xw total_treat_impl = _impl_c_xw, by(circle_id)

merge 1:1 circle_id using "Coded Data/Inspector Circle Clusters"
assert _merge == 3
drop _merge

merge 1:1 circle_id using "Coded Data/Inspector Treatment Variables"
assert _merge == 3
drop _merge

merge 1:1 circle_id using "${DATA}/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2013_q4_crosswalk"
keep if _merge == 3
drop _merge

gen ln_recov_tot_c = log(q4_2013_recov_tot_c)
gen base_ln_recov_tot_c = log(q4_2011_recov_tot_c)

gen ln_recov_tot_a = log(q4_2013_recov_tot_a)
gen base_ln_recov_tot_a = log(q4_2011_recov_tot_a)

gen ln_recov_tot_t = log(q4_2013_recov_tot_c + q4_2013_recov_tot_a)
gen base_ln_recov_tot_t = log(q4_2011_recov_tot_c + q4_2011_recov_tot_a)

label var avg_treat_sel "Average Neighbor Treatment"
label var _impl_c_xw "Treatment"
label var total_circles "Total No. of Neighboring Circles"

gen spillover = avg_treat_sel >= 0.5 & avg_treat_sel < . & _select_c_xw == 0

label var spillover "Spillover Control"
 
eststo mod1 : ivreg ln_recov_tot_t base_ln_recov_tot_t spillover (_impl_c_xw = _select_c_xw) stratdum_c*, cluster(cluster_c)
eststo mod2 : ivreg ln_recov_tot_c base_ln_recov_tot_c spillover (_impl_c_xw = _select_c_xw) stratdum_c*, cluster(cluster_c)
eststo mod3 : ivreg ln_recov_tot_a base_ln_recov_tot_a spillover (_impl_c_xw = _select_c_xw) stratdum_c*, cluster(cluster_c)

# delimit ;
esttab mod1 mod2 mod3
	using "${TABLE_OUTPUT}/tex/input/spillovers_input.tex", 
	keep(_impl_c_xw spillover)
	order(_impl_c_xw spillover)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Total" "Current" "Arrears")
	
	stats(N,
		labels(
			"N"
		)	
		fmt(
			"%12.0f"
		)
	)
	
	nonotes
	label
	
	booktabs // a nicer version of tables
	fragment
	replace
	;
	
# delimit cr
eststo clear


** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

local file spillovers

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table examines possible geographic spillover effects."
file write tablenote " We present instrumental variable regressions, with (own-circle) randomization results instrumenting for (own-circle) implementation."
file write tablenote " The unit of observations is a circle, as defined in FY 2013 Q4."
file write tablenote " The dependent variable is log recovery; columns seperate margins of collection."
file write tablenote " A spillover control circle is a control circle for which more than half of circles within 1km are treatment circles."
file write tablenote " Treatment is own circle treatment status. Specifications control for baseline log recovery, and include stratum fixed effects."
file write tablenote " Information treatment is included in the controls."
file write tablenote " Standard errors are clustered by robust partition of circles,"
file write tablenote " i.e. the group of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

