/*******************************************************************************
SUMMARY STATS

Table of summary statistics from admin data and survey data

Kunal Mangal
25 April 2014

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

*******************************************************************************

/* Admin Data */

# delimit ;
local vars1 
	ln_recov_tot_t
	ln_recov_tot_c
	ln_recov_tot_a
	
	ln_gross_dem_t
	ln_gross_dem_c
	ln_gross_dem_a
	
	ln_recoveryrate_t
	ln_recoveryrate_c
	ln_recoveryrate_a
	
	ln_nonexemptrate_t
	ln_nonexemptrate_c
	ln_nonexemptrate_a
;
# delimit cr


use "Coded Data/Phase III Analysis Data.dta", clear
keep if fyear == 2013 & qtr == 4
keep circle_id `vars1'

forval z =1/3 {
	local x : word `z' of t c a
	local y : word `z' of Total Current Arrears
		
	label var ln_recov_tot_`x'`year' "Log Revenue (`y')"
	label var ln_gross_dem_`x'`year' "Log Tax Base (`y')"
	label var ln_recoveryrate_`x'`year' "Log Recovery Rate (`y')"
	label var ln_nonexemptrate_`x'`year' "Log Non-Exemption Rate (`y')"
}

order circle_id ln_recov_tot_t ln_recov_tot_c ln_recov_tot_a ///
				ln_gross_dem_t ln_gross_dem_c ln_gross_dem_a ///
				ln_nonexemptrate_t ln_nonexemptrate_c ln_nonexemptrate_a ///
				ln_recoveryrate_t ln_recoveryrate_c ln_recoveryrate_a
				
ds circle_id, not
eststo admin: estpost tabstat `r(varlist)', statistics(mean sd N) columns(statistics)
esttab admin using "${TABLE_OUTPUT}/tex/input/summary_stats_input.tex", ///
	cells("mean(label(Mean) fmt(%12.2fc)) sd(label(SD) fmt(%12.2fc)) count(label(N) fmt(0))") ///
	nostar noobs nonumbers nomtitles nonote label booktabs fragment ///
	substitute("\midrule" "\midrule \emph{Panel A: Administrative Data}\\ \midrule") ///
	replace

/* Survey Data */
use "Coded Data/survey_coded_data.dta", clear

# delimit ;
local vars
	BM_match
	tax_quality
	tax_satisfied
	
	diff_GARV
	diff_pct_GARV
	
	GARV
	tax_last_payment
	
	tax_payment_total2
	tax_times_payment
;
# delimit cr

egen tax_payment_total2 = rowmean(tax_unofficial_payment_short?) if source == "short"
replace tax_payment_total2 = tax_payment_total if source ! = "short"

label var BM_match "Property successfully found in administrative records (dummy)"

label var tax_quality "Quality of Tax Department [0-1]"
label var tax_satisfied "Satisfaction with Tax Department [0-1]"

label var diff_GARV "Inaccuracy"
label var diff_pct_GARV "Tax Gap"
label var GARV "GARV"

label var tax_last_payment "Self-reported tax payment in FY 2013"

label var tax_payment_total2 "Bribe Payment"
label var tax_times_payment "Frequency of Bribe Payment"

* Drop sample for Phase 1 variables
foreach var of varlist tax_payment_total2 tax_quality tax_satisfied tax_times_payment tax_corruption {
	replace `var' = . if phase != 1
}


eststo random : estpost tabstat `vars' if SEC9 == 0, statistics(mean sd count) columns(statistics)
esttab random using "${TABLE_OUTPUT}/tex/input/summary_stats_input.tex", ///
	cells("mean(label(Mean) fmt(%012.2gc)) sd(label(SD) fmt(%12.2gc)) count(label(N) fmt(%12.0gc))") nostar noobs nonumbers nomtitles nonote label booktabs fragment append lz ///
	substitute("                    &        Mean&          SD&           N\\" "\\ \emph{Panel B: Survey Data} \\")

*******************************************

**** REMEMBER: NEED TO ADD MANUALLY ZEROS IN FRONT OF THE DECIMAL POINT FOR THE SURVEY DATA SECTION

set more off
local file summary_stats

/*
** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Panel A statistics from administrative data are shown at the end of Year 2 of teh study (FY 2012-2013). Each observation is one of the 482 circles as defined at the time of randomization."
file write tablenote " Panel B statistics from the property survey are for randomly sample properties only. Subjective variables - i.e., Quality, Satisfaction, Bribe Payment,"
file write tablenote " and Frequency of Bribe Payment - are reported for Phase 1 circles only (see text for more details)."
	
file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
