/*******************************************************************************
2014 PAPER TABLES - WHO PAYS MORE - MAIN
\\Pakistan Property Tax Project\Analysis\Do Files\Regressions\Phase III\Analysis\
	2014_paper\XXXXXX_who_pays_more_main.do
Kunal Mangal
22 April 2014
SUMMARY: 
OUTLINE:
NOTES:  This file should produce each table in LaTeX, .csv, .rtf, and .txt.

THIS VERSION INCLUDES A CONTROL FOR THE TAX REGRESSION IN THE RANDOM SAMPLE.
*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "C:\Users\kmangal\Dropbox\Pakistan Property Tax Project Analysis/"
cap cd "C:\Users\Kunal\Dropbox\Pakistan Property Tax Project Analysis/"

cap cd "C:/Users/wsandhol/Dropbox/Olken/Pakistan Property Tax Project/Analysis/"
cap cd "C:/Users/Wayne/Dropbox/Olken/Pakistan Property Tax Project/Analysis/"

cap cd "${PAKTAX_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Data/Cleaned Data/Field Survey/Round 3/all_noid_data_clean_2014.dta", clear

gen short_dummy = source == "short"

egen tax_payment_total2 = rowmean(tax_unofficial_payment_short?) if source == "short"
replace tax_payment_total2 = tax_payment_total if source ! = "short"

label var _impl_c_xw "Treatment"

* Define controls
do "Do Files\Paper\controls.do"


** REGRESSIONS *****************************************************************

// Objective Outcome
foreach yvar of varlist tax_last_payment {
			
	* Regress - Random Sample
	eststo `yvar' : ///
	  ivreg `yvar' (_impl_c_xw =_select_c_xw) short_dummy phase2 stratdum_c* tax_last_payment_1011 ${controls} ///
	    if SEC9 == 0, cluster(cluster_c)
	
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	estadd local samp = "Full"
	
}

// Subjective Outcomes
foreach yvar of varlist tax_payment_total2 tax_times_payment tax_corruption  {
			
	* Regress - Random Sample - Panel A
	eststo `yvar' : ///
	  ivreg `yvar' (_impl_c_xw =_select_c_xw) short_dummy ${controls} stratdum_c* ///
	    if SEC9 == 0 & phase == 1, cluster(cluster_c)
		
	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	estadd local samp = "Phase 1"
}


** TeX OUTPUT - RANDOM SAMPLE **************************************************

# delimit ;
esttab tax_last_payment tax_payment_total2 tax_times_payment
  tax_corruption
	using "Tables/tex/input\who_pays_more_main_infocontrol_controls_input.tex" , 
	keep(_impl_c_xw)
	
	b(%6.0g)
	se(%6.0g)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("\specialcell{Self- \\ reported \\ Tax \\ Payment}"
	  "\specialcell{Bribe \\ Payment}"
	  "\specialcell{Frequency \\ of Bribe \\ Payment}"
	  "\specialcell{Perception \\ of \\ Corruption}") // Column headings

	stats(N ysumm samp,
	  labels("N" "Mean of control group" "Sample")
	  fmt("%12.0f" "%12.3f" "a3")
	)
	//nonumbers // No column numbers
	label // Use Variable Labels	
	nonotes
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;
# delimit cr

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file who_pays_more_main_infocontrol_controls


** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table re-estimates Panel A of Table 7 from the main text, including controls for property and owner/tenant characteristics."
file write tablenote " Owner/tenant controls include: age of owner, education of owner, per-capita wages"
file write tablenote " of tenants, and predicted expenditure per capita of tenants given assets owned."
file write tablenote " Property controls include: land area, total covered area, a dummy for whether the"
file write tablenote " property was located on a main road, number of floors, a dummy for whether the property"
file write tablenote " had a renovation in the past 2 years, and the percent of covered area dedicated to"
file write tablenote " each of the four main usage categories (residential vs. commercial, owner occupied vs. rented)."
file write tablenote " See Notes to Table 7 for additional information."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"
file close tablenote

texout2 "Tables/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "Tables/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
