/*******************************************************************************
2014 PAPER TABLES - WHO PAYS MORE - SUBS
\\Pakistan Property Tax Project\Analysis\Do Files\Regressions\Phase III\Analysis\
	2014_paper\XXXXXX_who_pays_more_subs.do
Wayne Aaron Sandholtz
24 January 2014
SUMMARY: 
OUTLINE:
NOTES:  This file should produce each table in LaTeX, .csv, .rtf, and .txt.

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "C:\Users\kmangal\Dropbox\Pakistan Property Tax Project Analysis/"
cap cd "C:\Users\Kunal\Dropbox\Pakistan Property Tax Project Analysis/"

cap cd "C:/Users/wsandhol/Dropbox/Olken/Pakistan Property Tax Project/Analysis/"
cap cd "C:/Users/Wayne/Dropbox/Olken/Pakistan Property Tax Project/Analysis/"

cap cd "${PAKTAX_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Data/Cleaned Data/Field Survey/Round 3/all_noid_data_clean_2014.dta", clear

gen short_dummy = source == "short"

* Note on variables
// tax_payment_total = bribe payment (NOTE: CALCULATED DIFFERNTLY FOR SHORT AND LONG SURVEY)

egen tax_payment_total2 = rowmean(tax_unofficial_payment_short?) if source == "short"
replace tax_payment_total = tax_payment_total2 if source == "short"

gen tax_total = tax_last_payment + tax_payment_total

* Define controls
do "Do Files\Paper\140616\controls.do"

label var _impl_c_xw "Any treatment"
label var REV_impl_xw "Revenue"
label var REVPLS_impl_xw "Revenue Plus"
label var CFW_impl_xw "Flexible Bonus"

** REGRESSIONS *****************************************************************


// Objective outcomes - tax payment
foreach yvar of varlist tax_last_payment {
			
	* Revenue
	eststo `yvar' : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw = ///
	    REV_sel_xw REVPLS_sel_xw CFW_sel_xw) tax_last_payment_1011 phase2 short_dummy ${controls} stratdum_c* ///
	    if SEC9 == 0, cluster(cluster_c)

	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'
	estadd equivalence REV_impl REVPLS_impl CFW_impl : `yvar'
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_) : `yvar'
		// revenue vs. multitasking (rev+, cfw)
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_)  : `yvar'
		// subjective (CFW) vs. objective (Rev, Rev+)

	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	estadd local samp = "Full"
		
}

foreach yvar of varlist tax_payment_total ///
  tax_times_payment tax_corruption {
			
	* Revenue
	eststo `yvar' : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw = ///
	    REV_sel_xw REVPLS_sel_xw CFW_sel_xw) short_dummy ${controls} stratdum_c* ///
	    if SEC9 == 0 & phase == 1, cluster(cluster_c)

	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'
	estadd equivalence REV_impl REVPLS_impl CFW_impl : `yvar'
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_) : `yvar'
		// revenue vs. multitasking (rev+, cfw)
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_)  : `yvar'
		// subjective (CFW) vs. objective (Rev, Rev+)

	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	estadd local samp = "Phase 1"

}

foreach yvar of varlist tax_total {
			
	* Revenue
	eststo `yvar' : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw = ///
	    REV_sel_xw REVPLS_sel_xw CFW_sel_xw) tax_last_payment_1011 short_dummy ${controls} stratdum_c* ///
	    if SEC9 == 0 & phase == 1, cluster(cluster_c)

	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'
	estadd equivalence REV_impl REVPLS_impl CFW_impl : `yvar'
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_) : `yvar'
		// revenue vs. multitasking (rev+, cfw)
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_)  : `yvar'
		// subjective (CFW) vs. objective (Rev, Rev+)

	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
	estadd scalar ysumm = `r(mean)'
	estadd local samp = "Phase 1"

}

** TeX OUTPUT - RANDOM SAMPLE **************************************************
# delimit ;
esttab tax_last_payment tax_payment_total tax_times_payment 
  tax_corruption tax_total
	using "Tables/tex/input/who_pays_more_subs_infocontrol_controls_input.tex" , 
	keep(REV_impl_xw REVPLS_impl_xw CFW_impl_xw)
	
	b(%12.3g)
	se(%12.3g)
		
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("\specialcell{Self- \\ reported \\ Tax \\ Payment}"
	  "\specialcell{Bribe \\ Payment}"
	  "\specialcell{Frequency \\ of Bribe \\ Payment}"
	  "\specialcell{Perception \\ of \\ Corruption}"
	  "\specialcell{Total \\ payment \\ to tax \\ dept. \\ (Tax + \\ Bribe)}") // Column headings

	stats(N ysumm rvm_eqavg ovs_eqavg equivalence joint, 
	  labels("N" 
			"Mean of control group" 
			"Rev. vs. Multitasking p."
			"Objective vs. Subjective p."
			"Equality of Schemes"
			"Joint significance"
	  )
	  fmt(
			"%12.0f" "%12.1f" "%12.3f" "%12.3f" "%12.3f" "%12.3f"
		)
	)
	nonumbers // No column numbers
	label // Use Variable Labels
	nonotes	  
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	replace
	;

# delimit cr

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

local file who_pays_more_subs_infocontrol_controls

texout "Tables/tex/`file'", ///
  input("input/`file'_input")

compiletex "Tables/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
  
cap log close
exit
