/*
	Compile Current Circles
	
	Compiles admin data so that we get a panel on tax circles IN TERMS OF THEIR current / present
	circle IDs. That is, circles in the dataset will be identified in terms of the IDs set in the 
	locals [ynow] and [qnow].
	
	This do file essentially takes the do file and converts it to long format.

	Globals referenced here defined in Master Compile.do
*/

clear all
set more off

cap cd "C:/Users/Kunal/Dropbox (CID)/Pakistan Property Tax Project 2/"
cap cd "${PAKTAX_ANALYSIS}"

*******************************

********************************
* SET QUARTER OF LATEST ANALYSIS
if "$ynow" == "" {
	display "Enter the latest fiscal year: " _request(ynow)
	}
if "$qnow" == "" {
	display "Enter the latest quarter: " _request(qnow)
	}
local ynow = $ynow
local qnow = $qnow
********************************

** STEP 1 : CONVERT TO LONG ** 

use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`ynow'_q`qnow'_crosswalk", clear

reshape long @gross_dem_c @gross_dem_a @net_dem_c @net_dem_a @recov_tot_c @recov_tot_a, i(circle_id) j(qtrstring) string

gen qtr = substr(qtrstring, 2, 1)
destring qtr, replace

gen fyear = substr(qtrstring, 4, 4)
destring fyear, replace

drop qtrstring

foreach var in gross_dem net_dem recov_tot {
	gen `var'_t = `var'_c + `var'_a
}

tempfile data
save `data'

** STEP 2 : MERGE IN ANCILLARY INFORMATION ** 
* Information will be pulled in from the first time the circles show up in the admin data

forval y = 2008/`ynow' {
	forval q = 1/4 {
		if (`y' < `ynow') | (`y' == `ynow' & `q' <= `qnow') {
		
			use "Data/Cleaned Data/Administrative Data/Quarterly/FY`y' Q`q'/FY`y' Q`q'.dta", clear
			keep division_id division_name district_id district_name zone_id zone_name circle_id circle_name hr_id hr_name eto* aeto*
			
			gen fyear = `y'
			gen qtr = `q'
			
			merge 1:1 circle_id fyear qtr using `data'
			drop if _merge == 1
			drop _merge
			
			save `data', replace
			
		}
	}
}

order fyear qtr division_id division_name district_id district_name ///
	 zone_id zone_name circle_id circle_name hr_id hr_name, first
	
sort circle_id fyear qtr

saveold "Data/Cleaned Data/Administrative Data/Punjab Crosswalked - Current Circles.dta", replace
