**********************************************
* Calculate transition matrix for
* 
* 504911 505101 505102 -> 504910
* 505101 505102 -> 505100
*
* This is a special case because we have duplicate splits (505101 and 505102)
* and so we need additional information in order to determine the system.
*
* Note that the split above has been coded in reverse: in reality, as we move 
* from Q4 2013 to Q1 2014, the the total of 2 circles becomes 3 circles
* 
******************************************************************

cap cd "${PAKTAX_ANALYSIS}"

set trace off

/* 
Coeff on 505102 express in terms of coefficient on 505101, to make system
easier to solve
*/
local net_dem_t_q1_2014_505101 = 7367564
local net_dem_t_q1_2014_505102 = 7134299
local coeff = 1.06 * `net_dem_t_q1_2014_505101' / `net_dem_t_q1_2014_505102'

mata

M0 = 1, 0, 0\0, 1, 1
M0

M = 0, 1, `coeff'\0, -1, -`coeff'
M
end

local y 2014
local q 1

local y2 2013
local q2 4

local type t

global circles "504911, 505101, 505102"

use "Data/Cleaned Data/Administrative Data/Quarterly/FY`y' Q`q'/FY`y' Q`q'.dta", clear
keep circle_id net_dem_`type'
keep if inlist(circle_id, ${circles})

order circle_id net_dem_`type'
rename circle_id q`q'_`y'_circle_id
duplicates drop

sort q`q'_`y'_circle_id 
list
keep net_dem_`type'

*Make sure we have everyone
qui count
*assert `r(N)' == `n'

mata : a = st_data(., 1)

* Get "b" vector -- list of ending current net demand
use "Data/Cleaned Data/Administrative Data/Punjab Compiled - Quarterly.dta", clear

keep if fyear == `y2' & qtr == `q2'
rename circle_id q`q2'_`y2'_circle_id
duplicates drop

keep if inlist(q`q2'_`y2'_circle_id, 504910, 505100)
sort q`q2'_`y2'_circle_id
list
keep net_dem_`type'
	
*Make sure we have everyone
qui count
*assert `r(N)' == `m'

mata : b = st_data(., 1)
	
// Assign transition matrix; solve if necessary
mata : calculateT(3, 1, M0, M, a, b, T=.)


mata : T
