/*******************************************************************************
*** Cleaning Inspector Survey ***
*** Obeid Rehman 		      ***
*** July 2013				  ***
*********************************

OUTLINE
*** i. Workspace
*** ii. Cleaning typos & Lables
*** iii. Saving

*******************************************************************************/


* i. Workspace
*******************************************************************************************

clear all
set more off

cap cd "${PAKTAX_ANALYSIS}"

insheet using "Data/Raw Data/Inspector Data/Inspector Phone Survey.csv", c clear

* ii. Cleaning typos & Lables
********************************************************************************
*** Cleaning some values

replace q6_d_others="" if q6_d_others == "-"
replace q14_1=. if inlist(q14_1,4,5)
destring q8,replace


*** Setting up Variable lables ans names
label variable q1 "For the whole or most of FY2013 you were posted as inspector in this tax circle"
label variable q2 "In which circle were you posted for FY 2013 if not ONLY in the above-listed circle?"
label variable q3 "How would you score your circle team effort in your duties?"
label variable q4_field "In a typical work day how many hours did you spend in the field"
label variable q4_office "In a typical work day how many hours did you spend in the office"
label variable q5 "How would you describe the pressure from your supervisors for tax collection in the last fiscal year?"
label variable q6_a "Meetings"
label variable q6_b "Visits"
label variable q6_c "Disciplinary Actions"
label variable q6_d "Other"
label variable q6_d_others ""
label variable q7 "Were you ever selected in any ballot in the past two years "
label variable q8 "What scheme were you selected in through the ballot"
label variable q9 "What circle were you balloted for treatment in?"
label variable q10 "Are you still part of this treatment circle/eligible for honorarium payment?"
label variable q11 "How would you rate the level of monitoring during the FY 2012-201?3"
label variable q13 "If there is an additional ballot in July 2013 what chance do you think you may be selected?"
label variable q15 "Right after the ballot in July 2012 did you think there was still a chance that your performance may be rewarded in some manner?"
label variable q16 "How satisfied are you with your current circle posting?"
label variable q12_1 "Level of monitoring you faced compared to Incentive Schemes"
label variable q12_2 "Level of monitoring you faced compared to Information"
label variable q12_3 "Level of monitoring you faced compared to Controls"
label variable q14_1 "Chance compared to Incentive Schemes"
label variable q14_2 "Chance compared to Information"
label variable q14_3 "Chance compared to Controls"
label variable q18_1 "First Choice - Including cities"
label variable q18_2 "Second Choice - Including cities"
label variable q18_3 "Third Choice - Including cities"


label define comparison 1 "Higher" 2 "Same" 3 "Lower"
label values q12* q14* comparison

label define yesno 1 "Yes" 2 "No"
label values q1 q10 yesno

label define pressure 1 "VERY HIGH PRESSURE" 2 "HIGH PRESSURE" 3 "SOME PRESSURE" 4 "LITTLE PRESSURE" 5 "NO PRESSURE AT ALL" 6 "DONT KNOW"
label values q5 pressure

label define ballot 1 "July 2011" 2 "July 2012" 3 "NO"
label values q7 ballot

label define scheme 1 "REVENUE" 2 "REVENUE PLUS" 3 "CFW" 4 "INFORMATION"
label values q8 scheme

label define monitoring 1 "VERY LIGHT MONITORING" 2 "LIGHT MONITORING" 3 "MEDIUM MONITORING" 4 "INTENSE MONITORING" 5 "DONT KNOW"
label values q11 monitoring

label define likely 1 "NOT LIKELY AT ALL (0 chance)" 2 "A BIT LIKELY" 3 "LIKELY (50-50)" 4 "VERY LIKELY" 5 "DEFINITELY (100% chance)" 6 "DONT KNOW"
label values q13 q15 likely

label define satisfaction 1 "VERY UNSATISFIED" 2 "UNSATISFIED" 3 "INDIFFERENT" 4 "SATISFIED" 5 "VERY SATISFIED" 6 "DONT KNOW"
label values q16 satisfaction

label variable q17 "Would you be willing/interested in being posted to a different circle"
label define transfer 1 "Yes" 2 "No" 3 "Indifferent" 4 "Dont Know"
label values q17 transfer


***Renaming Variables

rename q1 postincircle
rename q2 circle_post
rename q3 effort
rename q4_field hrs_field
rename q4_office hrs_office
rename q5 pressure
rename q6_a pres_meet
rename q6_b pres_visit
rename q6_c pres_disc
rename q6_d pres_other
rename q6_d_others pres_other_desc
rename q7 ballot
rename q8 treatment_s
rename q9 circle_ballot
rename q10 eligible
rename q11 monit
rename q12_1 monit_inc
rename q12_2 monit_inf
rename q12_3 monit_con
rename q13 chance
rename q14_1 chance_inc
rename q14_2 chance_inf
rename q14_3 chance_con
rename q15 reward_chance
rename q16 satis
rename status1done2refused3notdone status
rename q17 transfer
rename q18_1 choice_1_
rename q18_2 choice_2_
rename q18_3 choice_3_
encode ifnotdonereason,gen (notdonereason)
order notdonereason,after(ifnotdonereason)
drop ifnotdonereason

label variable choice_1 "First Choice"
label variable choice_2 "Second Choice"
label variable choice_3 "Third Choice"

** CLEANING ADDED BY WAYNE, 7 OCTOBER 2013

gen hrs_total = hrs_field + hrs_office
la var hrs_total "Total hours worked in a typical day (field + office)"

** MISSINGS
replace pressure = . if pressure == 6
replace monit = . if monit == 5
replace chance = . if chance == 6
replace satis = . if satis == 6

replace notdonereason = 9 if effort == . & notdonereason == .

** RESCALINGS
gen pressure_scale  = (pressure - 1) / 4
la var pressure_scale "Pressure from supervisors"
gen monit_scale = (monit - 1) / 3
la var monit_scale "Level of monitoring"
gen chance_scale = (chance - 1) / 4
la var chance_scale "Chance you may be selected in next ballot"
gen satis_scale = (satis - 1) / 4
la var satis_scale "How satisfied with current circle posting"

** DUMMIES
gen eligible_dummy = eligible != 2 if !mi(eligible)
la var eligible_dummy "Are you still part of this treatment circle/eligible for hon. payment?"

/* WAS: the dummies with an _s in the middle are dummies for whether the 
	inspector answered the survey question by saying he was in the treatment,
	not whether or not he actually was.  The _s_ is for "survey". */
gen ballot_s_dummy = ballot != 3 if !mi(ballot) & notdonereason == .
la var ballot_s_dummy "Ever selected for treatment (survey)"
gen treatment_s_dummy = !mi(treatment_s) if notdonereason == .
la var treatment_s_dummy "Reports a subtreatment (survey)"
gen rev_s_dummy = treatment_s == 1 if !mi(treatment_s_dummy)
la var rev_s_dummy "Revenue subtreatment (survey)"
gen revplus_s_dummy = treatment_s == 2 if !mi(treatment_s_dummy)
la var revplus_s_dummy "Revenue plus subtreatment (survey)"
gen cfw_s_dummy = treatment_s == 3 if !mi(treatment_s_dummy)
la var cfw_s_dummy "CFW subtreatment (survey)"
gen info_s_dummy = treatment_s == 4 if !mi(treatment_s_dummy)
la var info_s_dummy "Information subtreatment (survey)"
gen done_dummy = notdonereason != .
la var done_dummy "Survey was done" 

/* WAS: I think the variable subtreatment refers to the treatments actually
	assigned to the inspector */
gen treatment = !mi(subtreatment)
gen rev = subtreatment == "Revenue"
gen revplus = subtreatment == "Revenue PLUS"
gen cfw = subtreatment == "Cond. Fixed Wage"
gen info = subtreatment == "Information"

* iii. Saving
******************************************************************************************************************************************

saveold "Data/Cleaned Data/Inspector Survey/Inspector Survey Clean.dta", replace
