/*************************************************************************************************
	Clean Year 2 Randomization
	------------------------------
	
	NOTES: Requires Year 1 Randomization data to be cleaned first (i.e. Data/Cleaned Data/Randomization/121116 Cleaned Phase II Randomization.dta)
		   needs to be up to date). This is generated by "121116 Clean Year 1 Randomization.do"
		   
	TASKS: Generate treatment dummies; generate strata dummies; fix errors in output; drop extraneous variables.
	
***************************************************************************************************/

version 12
clear all
pr drop _all
cap log close
set more off
set mem 300m
pause on

cap cd "${PAKTAX_ANALYSIS}"

************
* 1. Circle treat
************

* INPUT RANDOMIZATION RESULTS
u "Data/Cleaned Data/Randomization/121116 Cleaned Phase II Randomization.dta", clear
keep circle_id treatment subtreatment stratum rewardrate
ren treatment treatment1
ren subtreatment subtreatment1
replace rewardrate = rewardrate/10
merge 1:1 circle_id using "${PAKTAX_RANDOMIZATION}/Phase III/120707 Randomization Output 7214.dta", keepusing(treatment treatment_p3 treatment_p3_info subtreatment_p3)
assert _m==3
drop _m
replace treatment=1 if circle_id==105100	// these were flipped in the output, but not in the reality
replace treatment=0 if circle_id==105200	// these were flipped in the output, but not in the reality
assert treatment==treatment1
drop treatment
ren treatment_p3 _select_c2
ren subtreatment_p3 subtreatment2
ren treatment_p3_info infotreat2


* NAME VARIABLES AND CLEAN UP
g _select_c1 = treatment1
drop treatment1
forv x = 1/3 {
	local a : word `x' of REV REVPLS CFW
	forv y = 1/2 {
		g `a'_sel`y' = subtreatment`y'==`x' & _select_c`y'==1
		}
	}
g INFO_sel1 = 0
g INFO_sel2 = infotreat2


* GET CROSS-YEAR STUFF CORRECT
expand 2, gen(fyear)
replace fyear = fyear+2012
foreach v in _select_c REV_sel REVPLS_sel CFW_sel INFO_sel {
	g `v' = `v'1 if fyear==2012
	replace `v' = `v'1==1|`v'2==1 if fyear==2013
	}
	
* GET _1all _2all VARIABLES; THESE ARE ALL CIRCLES TREATED IN THE YEAR, NOT BASED ON SELECTION
foreach v in _select_c REV_sel REVPLS_sel CFW_sel INFO_sel {
	g `v'1all = `v' if fyear==2012
	replace `v'1all = 0 if fyear==2013
	g `v'2all = `v' if fyear==2013
	replace `v'2all = 0 if fyear==2012
	}

* SUBTREATMENT VARIABLE
g subtreatment = subtreatment1 if subtreatment1!=.
replace subtreatment = subtreatment2 if subtreatment==. & fyear==2013
foreach v of varlist subtreatment* {
	replace `v' = . if `v'==0
	}
la val subtreatment subtreat



* STRATA
ta stratum, gen(stratdum_c)
drop stratdum_c1
ren stratum stratum_c


* CLEAN UP AND TEMPFILE
order circle_id fyear
so circle_id fyear
tempfile circlelevel
sa `circlelevel'



************
* 2. Supervisory treat
************

u "${PAKTAX_RANDOMIZATION}/ETO & AETO/120707 ETO Randomization Output 6465 - New List - Randomization Circles.dta" 
keep rand_circle_id eto_name treat_eto
ren rand_circle_id circle_id
g div = floor(circle_id/100000)
egen ETO_clus_rand = group(eto_name div)
ren treat_eto _select_s
g fyear=2013

* MAKE SUPERVISORY STRATA
preserve
	u "${PAKTAX_RANDOMIZATION}/ETO & AETO/120707 ETO Randomization Output 6465.dta", clear
	keep eto_name stratum
	duplicates drop
	drop if eto_name==""
	tempfile etostrat
	sa `etostrat'
restore
merge m:1 eto_name using `etostrat'
assert _m==3
drop _m
ta stratumeto, gen(stratdum_s)
drop stratdum_s1
ren stratumeto stratum_s
drop eto_name



************
* 3. Merge & Save
************

merge 1:1 circle_id fyear using `circlelevel'
assert _m!=1
replace _select_s = 0 if _m==2
assert _select_s!=.
drop _m

saveold "Data/Cleaned Data/Randomization/130506 Cleaned Phase III Randomization.dta", replace

