version 12
cap log close

clear all
set more off

pause on

cap cd "${PAKTAX_ANALYSIS}"

**************************************************************************

use "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Backmatch.dta", clear

keep prop_id circle_id cluster_id prop_no category

drop if missing(category)

contract circle_id cluster_id category

egen total = total(_freq), by(circle_id cluster_id)

gen weight = _freq / total
drop _freq total

bys circle_id cluster_id : gen j = _n
reshape wide category weight, i(circle_id cluster_id) j(j)

tempfile categories
save `categories'


********************************************************************************
* 1 Input data and drop observations that we're missing data for
* or which we cannot compute
********************************************************************************

use "Data/Cleaned Data/Field Survey/Round 3/survey_cleaned_data.dta", clear

* COVERED AREA / GROUND COVERED AREA
forval i = 1/5 {
	foreach a in cov gr_cov BM_cov {
			di "`i' `a'"
			cap confirm variable `a'_area`i'
			if _rc {
				di "Does not exist"
			}
			else {
				list prop_id `a'_area_un`i' `a'_area_typ`i' `a'_area`i' ///
					if `a'_area`i' != . & ///
					(`a'_area_un`i' == . | `a'_area_typ`i' == .)
				** KM 140129 : WE HAVE TO DROP THESE OBSERVATIONS IF WE'RE MISSING THE TYPE
				if "`a'" != "BM_cov" drop if `a'_area`i' != . & ///
					(`a'_area_un`i' == . | `a'_area_typ`i' == .)
			}
		}
	}
	

* PATCH FOR TYPES
* We didn't separate use 8 (office in res area) into self vs rented.
/* WAS: Simplifying assumption: use 8 (office in residential area) is assumed
	self-owned (since the majority of properties are) unless it is the only 
	use of the property and the surveyor thinks the	property is rented (in the
	"owned" variable) */
gen use8rented = 0 if inlist(8,cov_area_typ1,cov_area_typ2,cov_area_typ3, ///
	cov_area_typ4,cov_area_typ5)
replace use8rented = 1 if cov_area_typ1 == 8 & cov_area2 == . & owned == 2

/* KM 120202: IN PHASE 2 OF THE SURVEY WE INCLUDED A CATEGORY 11 FOR RENTED OFFICE
              IN A RESIDENTIAL AREA. THERE ARE 4 PROPERTIES, AND THIS IS THEIR
			  ONLY USE.
*/
*assert cov_area2 == . if cov_area_typ1 == 11
replace use8rented = 1 if cov_area_typ1 == 11
replace cov_area_typ1 = 8 if cov_area_typ1 == 11

//THE QUESTION IS CODED SO THAT MULTIPLE USES ARE ARE NOTED IN DIFFERENT QUESTIONS   

forval i=1/5 {
	drop if SEC4_q11_`i' == 4 // Hotel
	drop if SEC4_q11_`i' == 7 // Agricultural Land
}
** KM 131024: DROPPING BECAUSE WE DO NOT HAVE THE INFORMATION TO DEAL WITH THIS CASE
**              AND ONLY COMPRISES A SMALL FRACTION OF THE SAMPLE

** NEED TO CHECK IF TAX IS APPLICABLE HERE TO AGRICULTURAL LAND, EXEMPTION DOCUMENT SUGGESTS NOT

********************************************************************************
* (2) Calculate proportions of area
********************************************************************************

/* We want to break up the total land area of the property (land_area) into the 
	appropriate uses. Uses are defined as proportions of ground-floor area  */
	
** KM 131023: NOTE FROM OBEID AND ZAHIR -- IGNORE OPEN AREA	
	
* CONSISTENCY CHECK
/* WAS 131004: FIX ME! THE BELOW ASSERT IS WHAT WE REALLY WANT! */
* assert open_area_typ!=. if open_area != . & open_area > 0
** KM 131021: There is only 1 contradiction here, and it is a 1 story property
*             where the rest of the uses have all been noted as Commercial
*             Self-Occupied, so I think it's safe to assume that here.
gen to_fix = 1 if open_area_typ ==. & open_area != . & open_area > 0
count if to_fix == 1
assert `r(N)' == 1
replace open_area_typ = 3 if to_fix == 1
drop to_fix

forv i = 1/10 {
	g prop_gr_cov_area`i' = 0
	forv j=1/5 {
		replace prop_gr_cov_area`i' = gr_cov_area`j' + prop_gr_cov_area`i' if gr_cov_area_typ`j'==`i'
	}
	
	replace prop_gr_cov_area`i' = prop_gr_cov_area`i' / tot_gr_cov_area
}

egen prop = rowtotal(prop_gr_cov_area*)
replace prop = round(prop)
*assert prop == 1
** 140129 KM: 6 CONTRADICTIONS, BECAUSE ALL GROUND AREA == 0
drop if prop == 0

forv i = 1/10 {
	g land_area`i' = land_area * prop_gr_cov_area`i'
}

forv i = 1/10 {
	g prop_cov_area`i' = 0
	forv j=1/5 {
		replace prop_cov_area`i' = cov_area`j' + prop_cov_area`i' if cov_area_typ`j'==`i'
	}
	
	replace prop_cov_area`i' = prop_cov_area`i' / tot_cov_area
}

forv i = 1/10 {
	g BM_prop_cov_area`i' = 0
	forv j=1/3 {
		replace BM_prop_cov_area`i' = BM_cov_area`j' + BM_prop_cov_area`i' if BM_cov_area_typ`j'==`i'
	}
	
	replace BM_prop_cov_area`i' = BM_prop_cov_area`i' / BM_tot_cov_area
}

********************************************************************************
* (5) Apply Multipliers
********************************************************************************

* MERGE MULTIPLIERS
preserve
	insheet using "Data/Raw Data/Survey Data/Property Multipliers.csv", comma clear
	tempfile multipliers
	sa `multipliers'
restore

merge m:1 category main_road using `multipliers'

	**------ THIS IS WHERE WE START IMPUTING -------**
	
keep if _merge == 1
keep if SEC9 == 0
drop _merge

drop category

merge m:1 circle_id cluster_id using `categories'
keep if _merge == 3
drop _merge

reshape long category weight, i(prop_id) j(j)
drop j

drop if missing(category)

egen s = total(weight), by(prop_id)
assert s == 1
drop s

merge m:1 category main_road using `multipliers', update
assert _merge == 4
drop _merge

* DEFINE MULTI-USE
g use = cov_area_typ1
g mult_use = 0
forv i = 2/5 {
	replace mult_use = 1 if cov_area_typ`i'!=use & cov_area_typ`i'!=.
	}
replace use = . if mult_use==1


forval i = 1/10 {
	gen covered_area`i' = 0
	
	forval j = 1/5 {
		replace covered_area`i' = covered_area`i' + cov_area`j' if cov_area_typ`j' == `i'
	}
}


gen plaza = 1 if (SEC4_q11_1 == 1 | SEC4_q11_2 == 1 | SEC4_q11_3 == 1 | SEC4_q11_4 == 1 | SEC4_q11_5 == 1)
preserve
	keep if plaza == 1
	tempfile plaza
	save `plaza'
restore

drop if plaza == 1 // Plaza and multi-story building
** WE WILL CIRCLE BACK TO THIS CASE LATER
** EVEN THOUGH WE DO NOT HAVE COMPLETE INFORMATION TO COMPUTE THIS
** (NAMELY AREA BY FLOOR) THERE ARE MANY PROPERTIES OF THIS TYPE IN SOME CIRCLES

gen AV_cov1 = min(covered_area1, 3000) * cov_area_first3000selfres + max(0, covered_area1 - 3000) * cov_area_extselfres 
gen AV_cov2 = min(covered_area2, 3000) * cov_area_first3000rentres + max(0, covered_area2 - 3000) * cov_area_extrentres
gen AV_cov3 = min(covered_area3,1500) * cov_area_first1500selfcomm + max(0,min(covered_area3-1500,1500)) * cov_area_1500_3000selfcomm + max(0,covered_area3-3000) * cov_area_extselfcomm
gen AV_cov4 = min(covered_area4,1500) * cov_area_first1500rentcomm + max(0,min(covered_area4-1500,1500)) * cov_area_1500_3000rentcomm + max(0,covered_area4-3000) * cov_area_extrentcomm

// Use 5 and 6, industrial properties, with exemptions
gen AV_cov5 = min(covered_area5,3000) * cov_area_first3000selfres + max(0, min(43560, covered_area5-3000)) * cov_area_extselfres // First acre
replace AV_cov5 = AV_cov5 + max(0, min(174240, covered_area5 - 43560)) * 0.8 * cov_area_extselfres  // Next 4 acres, 20% reduction
replace AV_cov5 = AV_cov5 + max(0, covered_area5 - 174240) * 0.64 * cov_area_extselfres  // Past 5 acres, additional 20% reduction

gen AV_cov6 = min(covered_area6,3000) * cov_area_first3000rentres + max(0,min(43560, covered_area6-3000)) * cov_area_extrentres // First acre
replace AV_cov6 = AV_cov6 + max(0,min(174240, covered_area6 - 43560)) * 0.8* cov_area_extrentres // Next 4 acres, 20% reduction
replace AV_cov6 = AV_cov6 + max(0, covered_area6 - 174240)* 0.64 * cov_area_extrentres // Over 5 acres, additional 20% reduction

gen AV_cov7 = 0 // Public use, tax exempt

// Office in residential area is 50% more
gen AV_cov8 = 1.5 * (min(covered_area8,3000) * cov_area_first3000rentres + max(0,covered_area8-3000) * cov_area_extrentres) if use8rented == 1 
replace AV_cov8 = 1.5 * (min(covered_area8,3000) * cov_area_first3000selfres + max(0,covered_area8-3000) * cov_area_extselfres) if use8rented != 1

gen AV_cov9 = 0.5 * (min(covered_area9,1500) * cov_area_first1500selfcomm ///
		+ max(0,min(covered_area9-1500,1500)) * cov_area_1500_3000selfcomm ///
		+ max(0,covered_area9-3000) * cov_area_extselfcomm) ///
		if owned == 1
replace AV_cov9 = 0.5 *(min(covered_area9,1500) * cov_area_first1500rentcomm ///
		+ max(0,min(covered_area9-1500,1500)) * cov_area_1500_3000rentcomm ///
		+ max(0,covered_area9-3000) * cov_area_extrentcomm) ///
		if owned != 1
gen AV_cov10 = 1.5 * (min(covered_area10,3000) * cov_area_first3000selfres ///
		+ max(0,covered_area10-3000) * cov_area_extselfres) if owned == 1
replace AV_cov10 = 1.5 * (min(covered_area10,3000) * cov_area_first3000rentres ///
		+ max(0,covered_area10-3000) * cov_area_extrentres) if owned != 1


** DO THE PLAZA CASE
preserve
	use `plaza', clear
	
	forval i = 1/10 {
		replace covered_area`i' = covered_area`i' / floors
	}
	
	gen AV_cov1 = min(covered_area1, 3000) * cov_area_first3000selfres + max(0, covered_area1 - 3000) * cov_area_extselfres 
	gen AV_cov2 = min(covered_area2, 3000) * cov_area_first3000rentres + max(0, covered_area2 - 3000) * cov_area_extrentres
	gen AV_cov3 = min(covered_area3,1500) * cov_area_first1500selfcomm + max(0,min(covered_area3-1500,1500)) * cov_area_1500_3000selfcomm + max(0,covered_area3-3000) * cov_area_extselfcomm
	gen AV_cov4 = min(covered_area4,1500) * cov_area_first1500rentcomm + max(0,min(covered_area4-1500,1500)) * cov_area_1500_3000rentcomm + max(0,covered_area4-3000) * cov_area_extrentcomm
	
	gen AV_cov5 = min(covered_area5,3000) * cov_area_first3000selfres + max(0, min(43560, covered_area5-3000)) * cov_area_extselfres // First acre
	replace AV_cov5 = AV_cov5 + max(0, min(174240, covered_area5-3000 - 43560)) * 0.8 * cov_area_extselfres  // Next 4 acres, 20% reduction
	replace AV_cov5 = AV_cov5 + max(0, covered_area5-3000-174240) * 0.64 * cov_area_extselfres  // Past 5 acres, additional 20% reduction

	gen AV_cov6 = min(covered_area6,3000) * cov_area_first3000rentres + max(0,min(43560, covered_area6-3000)) * cov_area_extrentres // First acre
	replace AV_cov6 = AV_cov6 + max(0,min(174240, covered_area6 - 43560)) * 0.8 * cov_area_extrentres // Next 4 acres, 20% reduction
	replace AV_cov6 = AV_cov6 + max(0, covered_area6-174240)* 0.64 * cov_area_extrentres // Over 5 acres, additional 20% reduction

	gen AV_cov7 = 0
	
	gen AV_cov8 = 1.5 * (min(covered_area8,3000) * cov_area_first3000rentres + max(0,covered_area8-3000) * cov_area_extrentres) if use8rented == 1
	replace AV_cov8 = 1.5 * (min(covered_area8,3000) * cov_area_first3000selfres + max(0,covered_area8-3000) * cov_area_extselfres) if use8rented != 1
	
	gen AV_cov9 = 0.5 * (min(covered_area9,1500) * cov_area_first1500selfcomm ///
			+ max(0,min(covered_area9-1500,1500)) * cov_area_1500_3000selfcomm ///
			+ max(0,covered_area9-3000) * cov_area_extselfcomm) ///
			if owned == 1
	replace AV_cov9 = 0.5 * (min(covered_area9,1500) * cov_area_first1500rentcomm ///
			+ max(0,min(covered_area9-1500,1500)) * cov_area_1500_3000rentcomm ///
			+ max(0,covered_area9-3000) * cov_area_extrentcomm) ///
			if owned != 1
	gen AV_cov10 = 1.5 * (min(covered_area10,3000) * cov_area_first3000selfres ///
			+ max(0,covered_area10-3000) * cov_area_extselfres) if owned == 1
	replace AV_cov10 = 1.5 * (min(covered_area10,3000) * cov_area_first3000rentres ///
			+ max(0,covered_area10-3000) * cov_area_extrentres) if owned != 1
	
	forval i=1/10 {
		replace AV_cov`i' = floors * AV_cov`i'
	}
	
	save `plaza', replace
restore

append using `plaza'

* LAND AREA, FOR ALL
g AV_land1 = min(land_area1,500)*land_area_first500selfres + max(0,land_area1-500)*land_area_extselfres	// self, res
g AV_land2 = min(land_area2,500)*land_area_first500rentres + max(0,land_area2-500)*land_area_extrentres // rent, res
g AV_land3 = min(land_area3,500)*land_area_first500selfcomm + max(0,land_area3-500)*land_area_extselfcomm	// self, comm
g AV_land4 = min(land_area4,500)*land_area_first500rentcomm + max(0,land_area4-500)*land_area_extrentcomm	// rent, comm


g AV_land5 = min(land_area5,500)*land_area_first500selfres + max(0,min(4840, land_area5-500))* land_area_extselfres	// First acre; self, indus
replace AV_land5 = AV_land5 +  max(0, min(24200, land_area5 - 4840)) * 0.8 * land_area_extselfres // Next 4 acres
replace AV_land5 = AV_land5 + max(0, land_area5 - 24200) * 0.64 * land_area_extselfres // Past 5 acres

g AV_land6 = min(land_area6,500)*land_area_first500rentres + max(0,min(4840, land_area6-500))*land_area_extrentres	// First acre; self, indus
replace AV_land6 = AV_land6 +  max(0, min(24200, land_area6 - 4840)) * 0.8 * land_area_extrentres // Next 4 acres
replace AV_land6 = AV_land6 + max(0, land_area6 - 24200) * 0.64 * land_area_extrentres // Past 5 acres

g AV_land7 = 0

g AV_land8 = 1.5*(min(land_area8,500)*land_area_first500rentres + max(0,land_area8-500)*land_area_extrentres) if use8rented == 1
replace AV_land8 = 1.5*(min(land_area8,500)*land_area_first500selfres + max(0,land_area8-500)*land_area_extselfres) if use8rented != 1

g AV_land9 = 0.5 * (min(land_area9,500)*land_area_first500selfcomm + max(0,land_area9-500)*land_area_extselfcomm) if owned == 1
replace AV_land9 = 0.5 * (min(land_area9,500)*land_area_first500rentcomm + max(0,land_area9-500)*land_area_extrentcomm) if owned != 1
g AV_land10 = 1.5* (min(land_area10,500)*land_area_first500selfres + max(0,land_area10-500)*land_area_extselfres) if owned == 1
replace AV_land10 = 1.5*(min(land_area10,500)*land_area_first500rentres + max(0,land_area10-500)*land_area_extrentres) if owned != 1

* GARV
egen rent_value = rowtotal(AV_land* AV_cov*)
label var rent_value "GARV / 12"

gen BM_rent_value = BM_GARV / 12
label var BM_rent_value "BM GARV / 12"

gen tax_density = rent_value / (tot_cov_area + land_area)
gen BM_tax_density = BM_rent_value / (BM_tot_cov_area + BM_land_area)

gen area = tot_cov_area + land_area
gen BM_area = BM_tot_cov_area + BM_land_area

gen GARV = 12 * rent_value
forv i = 1/10 {
	gen GARV`i' = 12 * (AV_land`i' + AV_cov`i')
}



*** KM 1401201: OBEID HAS POINTED OUT THAT IT LOOKS LIKE INSPECTORS ARE APPLYING THE WIDOW, DISABLED EXEMPTION ONLY AFTER
*               REPORTING GARV. SO IN OUR ACCURACY CALCULTION WE SHOULDN'T PENALIZE THEM FOR IT. THEREFORE THE EXEMPTION
*               IS ONLY INCLUDED IN THE GARV`I', AND NOT IN THE MAIN GARV, WHICH WILL BE USED IN THE ACCURACY CALCULATION.

* EXEMPTION
/*
(g) buildings and lands annual value of which does not exceed rupees forty eight tho
hundred belonging to a widow, disabled person or a minor orphan :
Provided that where the annual value is more than rupees forty eight thousand a
the tax shall be levied on the amount in excess of the said amount; and
*/

cap drop widow

gen retired_official = SEC1_q15 == 2
gen widow = SEC1_q15 == 7
gen disabled = SEC1_q15 == 8
gen minor_orphan = SEC1_q15 == 9

gen exemption = (widow == 1 | minor_orphan == 1 | disabled == 1)

** APPLY THE EXEMPTION FOR WIDOW / ORPHAN / DISABLED
* SPREAD THE 48600 BONUS EVENLY ACROSS THE USES

// Replace GARV = 0 if total GARV <= 48600
forval i=1/10 {
	replace GARV`i' = 0 if GARV <= 48600 & exemption == 1
}

// Replace GARV proportional to the value of each unit usage if GARV > 48600
forval i=1/10 {
	replace GARV`i' = GARV`i' / GARV * (GARV - 48600) if GARV > 48600 & exemption == 1
}


** PROPERTY AGE EXEMPTION

replace SEC4_q9 = . if SEC4_q9 == 9999
gen property_age = 2013 - SEC4_q9

* Net ARV
forval i=1/10 {
	gen NetARV`i' = .
	replace NetARV`i' = 0.9 * GARV`i' if property_age <= 30 | missing(property_age)
	replace NetARV`i' = 0.85 * NetARV`i' if property_age > 30 & !missing(property_age)
}


* Tax Liable
forval i=1/10 {
	gen tax_liability`i' = 0.2 * NetARV`i' if NetARV`i' <= 20000
	replace tax_liability`i' = 0.25 * NetARV`i' if NetARV`i' > 20000
}


********************************************************************************
* (6) Apply Exemptions
********************************************************************************

** FULL EXEMPTIONS

*(a) Buildings and lands other than those leased in perpetuity, owned by the Federal Government
*(b) building and lands other than those leased in perpetuity owned and administered by the Government 
* of the Punjab or a local government as defined in Section 2 Clause (xvi) 
* if the Punjab Local Government Ordinance, 2001 (XIII of 2001);

* NOTE: THIS IS ALREADY TAKEN CARE OF IN THE GARV CALCULATION (USE CODE 7).

/*
(c) (i) buildings and lands, the annual value of which does not exceed one thousand and eighty rupees ; or
	(ii) one building occupied by an owner for his residences, the annual value of which does not exceed one thousand and six hundred and twenty rupees.
	Subject to the condition that the owner or any member of his family does not own any other property in that Rating Area such other conditions as may be prescribed:
	Provided that if such building or land is in the ownership of a person who owns any other building or land in the same Rating Area the annual value of such building or land, shall, for the purposes of this clause; be deemed to be the aggregate value of all buildings and lands owned by him in that area:
	Provided further that nothing in clause (c)(i) shall apply to an assessment made under Section 3-B or this Act.
*/

egen commercial_sum = rowtotal(NetARV3 NetARV4 NetARV5 NetARV6 NetARV8 NetARV9 NetARV10) // for commercial-type properties; includes godowns / warehouses
egen residential_sum = rowtotal(NetARV1 NetARV2) // for residential-type properties; includes industrial units, offices, schools

* KM 140201: NOTE -- WE NEED TO INCLUDE EXEMPTION != 1 RESTRICTION TO MAKE SURE THAT PEOPLE WHO RECEIVED THE GARV EXEMPTION
*                    ARE GETTING DOUBLE EXEMPTED

foreach i in 3 4 5 6 8 9 10 {
	replace tax_liability`i' = 0 if commercial_sum <= 1080 & exemption != 1
}

* NOTE: WE CANNOT DETERMINE WHETHER A PROPERTY OWNER WITH GARV <= 1620 OWNS ANOTHER PROPERTY, SO WE'LL
* JUST ASSUME HE DOES.

foreach i in 1 2  {
	replace tax_liability`i' = 0 if residential_sum <= 1620 & exemption != 1
} 

/*
(d) Any school owned by the Government. Completely Exempt
(e) Public Parks, Play grounds and Libraries. Completely Exempt 
(f) Religious institutions, Graveyards, etc. Completely Exempt
*/

forval i=1/10 {
	replace tax_liability`i' = 0 if inlist(SEC4_q11_1, 9, 10, 11)
	// 9 = government owned, 10 = parks, 11 = religious
} 

/*
(g) buildings and lands annual value of which does not exceed rupees forty eight tho
hundred belonging to a widow, disabled person or a minor orphan :
Provided that where the annual value is more than rupees forty eight thousand a
the tax shall be levied on the amount in excess of the said amount; and
*/

** NOTE THAT THIS IS ALREADY DONE IN THE GARV CALCULATION ABOVE.

/*
(gg) one residential house measuring an area upto one kanal owned and occupied for 
his residence by a retired Government Servant of the Federation or a Province ; 
Provided that in this clause Government Servant shall not be include a service of a 
body corporate owned, established or controlled by the Federal or Provincial Government. 
*/

foreach i in 1 {
	replace tax_liability`i' = 0 if sft_land_area <= 4500 & retired_official == 1 & marla_def == 1
	replace tax_liability`i' = 0 if sft_land_area <= 5445 & retired_official == 1 & marla_def == 2
}	
** SET ALL RESIDENTIAL UNITS TAX LIABILITY TO ZERO

/*
(i) On self-occupied residential house having an area not exceeding 5 Marlas in Katchi Abadi notified under the law relating to Katchi Abadis.
*/

/*
merge 1:1 prop_id using "Data/Cleaned Data/Field Survey/Round 3/Section 8.dta", keepusing(SEC8_q1)
drop if _merge == 2
drop _merge

gen katchi_abadi = SEC8_q1 == 4
*/

/* 
** NOTE: THIS IS NO LONGER NECESSARY, IT SEEMS THE 5 MARLA EXEMPTION APPLIES IN NON
   KATCHI-ABADI AS WELL. 
   
   KM 140201: ALSO, DESPITE THE LANGUAGE OF THE TEXT, OBEID AND ZAHIR
   HAVE CONFIRMED THAT THE EXEMPTION APPLIES TO ALL RESIDENTIAL PROPERTIES, NOT
   JUST OWNER-OCCUPIED.
   
   LASTLY, IF THE PROPERTY IS MIXED USE, THEN THE EXEMPTION ONLY APPLIES TO THE
   RESIDENTIAL PART
*/

foreach i in 1 2 {
	replace tax_liability`i' = 0 if sft_land_area <= 1125 & marla_def == 1
	replace tax_liability`i' = 0 if sft_land_area <= 1361.25 & marla_def == 2
}


** PARTIAL EXEMPTIONS

* 1) Godown / warehouse reduction
* 50% reduction on tax liable
** NOTE: THIS IS APPLIED AT GARV

cap drop tax_liability
egen tax_liability = rowtotal(tax_liability1-tax_liability10)

* 2) Multi-story Plaza Adjustment
qui sum floors if plaza == 1
forval f = 1/`r(max)' {
	gen tax_floor`f' = tax_liability / floors * (1.1 - 0.1 * min(`f', 6)) if floors >= `f' & plaza == 1 // maximum of 50% off
}
egen tax_floor_total = rowtotal(tax_floor*)
replace tax_liability = tax_floor_total if plaza == 1

* 3) Seasonal Adjustment

gen seasonal = SEC8_q6 == 1

replace tax_liability = 0.5 * tax_liability if seasonal == 1

* 3) First quarter payment 5% reducation
** KM 131023: IGNORE THIS EXEMPTION, BECAUSE INSPECTORS DON'T ACTUALLY RECORD
**            THIS EXEMPTION WHEN THEY NOTE TAX LIABLE. IT'S JUST IMPLICILTY
**            UNDERSTOOD WHEN THE PROPERTY OWNER SENDS THE CHECK


***********************************
* -- Construct the weighted average

keep prop_id GARV tax_liability tax_density category weight

encode category, generate(category_scale)
replace category_scale = 8 - category_scale

foreach var of varlist GARV tax_liability tax_density category_scale {
	replace `var' = `var' * weight
}

collapse (sum) GARV tax_liability tax_density category_scale, by(prop_id)

gen imputed = 1
label var imputed "= 1 if tax variables are imputed because category not available"

save "Data/Cleaned Data/Field Survey/Round 3/Imputed Tax.dta", replace
